Class: Google::Cloud::Chronicle::V1::BigQueryExportService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::BigQueryExportService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb
Overview
REST client for the BigQueryExportService service.
Service for managing BigQuery export configurations for Chronicle instances.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the BigQueryExportService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the BigQueryExportService Client instance.
-
#get_big_query_export(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Get the BigQuery export configuration for a Chronicle instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new BigQueryExportService REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#provision_big_query_export(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Provision the BigQuery export for a Chronicle instance.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_big_query_export(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Update the BigQuery export configuration for a Chronicle instance.
Methods included from Paths
#big_query_export_path, #instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new BigQueryExportService REST client object.
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 141 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @big_query_export_service_stub = ::Google::Cloud::Chronicle::V1::BigQueryExportService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @big_query_export_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the BigQueryExportService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_big_query_export.timeout = 120.0 default_config.rpcs.get_big_query_export.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_big_query_export.timeout = 120.0 default_config.rpcs.update_big_query_export.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.provision_big_query_export.timeout = 120.0 default_config.rpcs.provision_big_query_export.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the BigQueryExportService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
111 112 113 114 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 111 def configure yield @config if block_given? @config end |
#get_big_query_export(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport #get_big_query_export(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Get the BigQuery export configuration for a Chronicle instance.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 239 def get_big_query_export request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetBigQueryExportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_big_query_export..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_big_query_export.timeout, metadata: , retry_policy: @config.rpcs.get_big_query_export.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @big_query_export_service_stub.get_big_query_export request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
188 189 190 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 188 def logger @big_query_export_service_stub.logger end |
#provision_big_query_export(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport #provision_big_query_export(parent: nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Provision the BigQuery export for a Chronicle instance. This will create {\{gcp_name}} resources like {\{storage_name}} buckets, BigQuery datasets and set default export settings for each data source.
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 402 def provision_big_query_export request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ProvisionBigQueryExportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.provision_big_query_export..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.provision_big_query_export.timeout, metadata: , retry_policy: @config.rpcs.provision_big_query_export.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @big_query_export_service_stub.provision_big_query_export request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
121 122 123 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 121 def universe_domain @big_query_export_service_stub.universe_domain end |
#update_big_query_export(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport #update_big_query_export(big_query_export: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExport
Update the BigQuery export configuration for a Chronicle instance.
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/google/cloud/chronicle/v1/big_query_export_service/rest/client.rb', line 321 def update_big_query_export request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateBigQueryExportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_big_query_export..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_big_query_export.timeout, metadata: , retry_policy: @config.rpcs.update_big_query_export.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @big_query_export_service_stub.update_big_query_export request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |