Class: Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

Request to replace data table rows in bulk.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The resource id of the data table. Format: /projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}.

Returns:

  • (::String)

    Required. The resource id of the data table. Format: /projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}



282
283
284
285
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 282

class BulkReplaceDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#requests::Array<::Google::Cloud::Chronicle::V1::CreateDataTableRowRequest>

Returns Required. Data table rows to replace the existing data table rows. A maximum of 1000 rows (for sync requests) or 2000 rows (for async requests) can be replaced in a single request. Total size of the rows should be less than 4MB.

Returns:

  • (::Array<::Google::Cloud::Chronicle::V1::CreateDataTableRowRequest>)

    Required. Data table rows to replace the existing data table rows. A maximum of 1000 rows (for sync requests) or 2000 rows (for async requests) can be replaced in a single request. Total size of the rows should be less than 4MB.



282
283
284
285
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 282

class BulkReplaceDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end