Class: Google::Cloud::Chronicle::V1::Button

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb

Overview

Button config for a chart.

Defined Under Namespace

Classes: Properties

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns:

  • (::String)


657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 657

class Button
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] color
  #   @return [::String]
  # @!attribute [rw] button_style
  #   @return [::Google::Cloud::Chronicle::V1::ButtonStyle]
  class Properties
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

Returns:

  • (::String)


657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 657

class Button
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] color
  #   @return [::String]
  # @!attribute [rw] button_style
  #   @return [::Google::Cloud::Chronicle::V1::ButtonStyle]
  class Properties
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#label::String

Returns:

  • (::String)


657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 657

class Button
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] color
  #   @return [::String]
  # @!attribute [rw] button_style
  #   @return [::Google::Cloud::Chronicle::V1::ButtonStyle]
  class Properties
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#new_tab::Boolean

Returns Optional. Whether to open the link in a new tab.

Returns:

  • (::Boolean)

    Optional. Whether to open the link in a new tab.



657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 657

class Button
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] color
  #   @return [::String]
  # @!attribute [rw] button_style
  #   @return [::Google::Cloud::Chronicle::V1::ButtonStyle]
  class Properties
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#properties::Google::Cloud::Chronicle::V1::Button::Properties



657
658
659
660
661
662
663
664
665
666
667
668
669
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 657

class Button
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] color
  #   @return [::String]
  # @!attribute [rw] button_style
  #   @return [::Google::Cloud::Chronicle::V1::ButtonStyle]
  class Properties
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end