Class: Google::Cloud::Chronicle::V1::ColumnMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

Metadata of the column.

Instance Attribute Summary collapse

Instance Attribute Details

#column::String

Returns Name of the column.

Returns:

  • (::String)

    Name of the column.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_source::Google::Cloud::Chronicle::V1::DataSource

Returns Data source queried.

Returns:



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#field_path::String

Returns Field path of the queried field, if any.

Returns:

  • (::String)

    Field path of the queried field, if any.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#function_module::String

Returns Module of the function used to query the field, if any.

Returns:

  • (::String)

    Module of the function used to query the field, if any.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#function_name::String

Returns Name of the function used to query the field, if any.

Returns:

  • (::String)

    Name of the function used to query the field, if any.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#latitude::Boolean

Returns Whether the column is a latitude field.

Returns:

  • (::Boolean)

    Whether the column is a latitude field.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#longitude::Boolean

Returns Whether the column is a longitude field.

Returns:

  • (::Boolean)

    Whether the column is a longitude field.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#selected::Boolean

Returns Whether the column is selected in the final response.

Returns:

  • (::Boolean)

    Whether the column is selected in the final response.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#timestamp_metadata::Google::Cloud::Chronicle::V1::TimestampMetadata

Returns Timestamp Metadata.

Returns:



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unselected::Boolean

Returns Whether the column is unselected in the final response.

Returns:

  • (::Boolean)

    Whether the column is unselected in the final response.



499
500
501
502
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 499

class ColumnMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end