Class: Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_access_control.rb

Overview

Request message for CreateDataAccessLabel.

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_label::Google::Cloud::Chronicle::V1::DataAccessLabel

Returns Required. Data access label to create.

Returns:



38
39
40
41
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 38

class CreateDataAccessLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_access_label_id::String

Returns Required. The ID to use for the data access label, which will become the label's display name and the final component of the label's resource name. The maximum number of characters should be 63. Regex pattern is as per AIP: https://google.aip.dev/122#resource-id-segments.

Returns:

  • (::String)

    Required. The ID to use for the data access label, which will become the label's display name and the final component of the label's resource name. The maximum number of characters should be 63. Regex pattern is as per AIP: https://google.aip.dev/122#resource-id-segments



38
39
40
41
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 38

class CreateDataAccessLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this Data Access Label will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this Data Access Label will be created. Format: projects/{project}/locations/{location}/instances/{instance}



38
39
40
41
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 38

class CreateDataAccessLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end