Class: Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_access_control.rb

Overview

Request message for CreateDataAccessScope.

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_scope::Google::Cloud::Chronicle::V1::DataAccessScope

Returns Required. Data access scope to create.

Returns:



137
138
139
140
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 137

class CreateDataAccessScopeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_access_scope_id::String

Returns Required. The user provided scope id which will become the last part of the name of the scope resource. Needs to be compliant with https://google.aip.dev/122.

Returns:

  • (::String)

    Required. The user provided scope id which will become the last part of the name of the scope resource. Needs to be compliant with https://google.aip.dev/122



137
138
139
140
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 137

class CreateDataAccessScopeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this Data Access Scope will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this Data Access Scope will be created. Format: projects/{project}/locations/{location}/instances/{instance}



137
138
139
140
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 137

class CreateDataAccessScopeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end