Class: Google::Cloud::Chronicle::V1::CreateDataTableRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

A request to create DataTable.

Instance Attribute Summary collapse

Instance Attribute Details

#data_table::Google::Cloud::Chronicle::V1::DataTable

Returns Required. The data table being created.

Returns:



39
40
41
42
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 39

class CreateDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_table_id::String

Returns Required. The ID to use for the data table. This is also the display name for the data table. It must satisfy the following requirements:

  • Starts with letter.
  • Contains only letters, numbers and underscore.
  • Must be unique and has length < 256.

Returns:

  • (::String)

    Required. The ID to use for the data table. This is also the display name for the data table. It must satisfy the following requirements:

    • Starts with letter.
    • Contains only letters, numbers and underscore.
    • Must be unique and has length < 256.


39
40
41
42
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 39

class CreateDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this data table will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this data table will be created. Format: projects/{project}/locations/{location}/instances/{instance}



39
40
41
42
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 39

class CreateDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end