Class: Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Request message for CreateFindingsRefinement method.

Instance Attribute Summary collapse

Instance Attribute Details

#findings_refinement::Google::Cloud::Chronicle::V1::FindingsRefinement

Returns Required. The findings refinement to create.

Returns:



243
244
245
246
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 243

class CreateFindingsRefinementRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this findings refinement will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this findings refinement will be created. Format: projects/{project}/locations/{location}/instances/{instance}



243
244
245
246
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 243

class CreateFindingsRefinementRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end