Class: Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Request message to create a dashboard.

Instance Attribute Summary collapse

Instance Attribute Details

#native_dashboard::Google::Cloud::Chronicle::V1::NativeDashboard

Returns Required. The dashboard to create.

Returns:



172
173
174
175
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 172

class CreateNativeDashboardRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}



172
173
174
175
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 172

class CreateNativeDashboardRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end