Class: Google::Cloud::Chronicle::V1::CreateReferenceListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

A request to create a reference list.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource where this reference list will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this reference list will be created. Format: projects/{project}/locations/{location}/instances/{instance}



117
118
119
120
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 117

class CreateReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reference_list::Google::Cloud::Chronicle::V1::ReferenceList

Returns Required. The reference list to create.

Returns:



117
118
119
120
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 117

class CreateReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#reference_list_id::String

Returns Required. The ID to use for the reference list. This is also the display name for the reference list. It must satisfy the following requirements:

  • Starts with letter.
  • Contains only letters, numbers and underscore.
  • Has length less than 256.
  • Must be unique.

Returns:

  • (::String)

    Required. The ID to use for the reference list. This is also the display name for the reference list. It must satisfy the following requirements:

    • Starts with letter.
    • Contains only letters, numbers and underscore.
    • Has length less than 256.
    • Must be unique.


117
118
119
120
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 117

class CreateReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end