Class: Google::Cloud::Chronicle::V1::DashboardChart::ChartDatasource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb

Overview

Datasource of the chart including the query reference and source name.

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard_query::String

Returns Reference to dashboard query resource used in the chart.

Returns:

  • (::String)

    Reference to dashboard query resource used in the chart.



73
74
75
76
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 73

class ChartDatasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_sources::Array<::Google::Cloud::Chronicle::V1::DataSource>

Returns Name of the datasource used in the chart.

Returns:



73
74
75
76
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 73

class ChartDatasource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end