Class: Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownExternalLink

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb

Overview

Drill down external link config.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Optional. Description of the external link.

Returns:

  • (::String)

    Optional. Description of the external link.



636
637
638
639
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 636

class DrillDownExternalLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

Returns Required. External link the drill down action should redirect to.

Returns:

  • (::String)

    Required. External link the drill down action should redirect to.



636
637
638
639
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 636

class DrillDownExternalLink
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end