Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::GoogleMapsConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb

Overview

Google Maps config for a chart if chart type is map.

Defined Under Namespace

Classes: DataSettings, MapPosition, PointSettings

Instance Attribute Summary collapse

Instance Attribute Details

#data_settings::Google::Cloud::Chronicle::V1::DashboardChart::Visualization::GoogleMapsConfig::DataSettings

Returns Optional. Data settings for the map.



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 442

class GoogleMapsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Data settings for the map.
  # @!attribute [rw] latitude_column
  #   @return [::String]
  #     Optional. Latitude column.
  # @!attribute [rw] longitude_column
  #   @return [::String]
  #     Optional. Longitude column.
  # @!attribute [rw] count_column
  #   @return [::String]
  #     Optional. Field to count.
  class DataSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Map position settings for the map.
  # @!attribute [rw] fit_data
  #   @return [::Boolean]
  #     Optional. Whether to fit the map to the data.
  #     If true, the map will be resized to fit the data.
  #     If false, langitude and longitude will be used to set the map size.
  # @!attribute [rw] latitude_value
  #   @return [::Float]
  #     Optional. Latitude of the map.
  # @!attribute [rw] longitude_value
  #   @return [::Float]
  #     Optional. Longitude of the map.
  # @!attribute [rw] zoom_scale_value
  #   @return [::Float]
  #     Optional. Scale of the map.
  class MapPosition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Point settings for the map.
  # @!attribute [rw] point_size_type
  #   @return [::Google::Cloud::Chronicle::V1::PointSizeType]
  #     Optional. Point size type for the map. This is used to
  #     determine the size of the points on the map.
  # @!attribute [rw] color
  #   @return [::String]
  #     Optional. Color for the point on the map.
  class PointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#map_position::Google::Cloud::Chronicle::V1::DashboardChart::Visualization::GoogleMapsConfig::MapPosition

Returns Optional. Map position settings for the map.

Returns:



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 442

class GoogleMapsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Data settings for the map.
  # @!attribute [rw] latitude_column
  #   @return [::String]
  #     Optional. Latitude column.
  # @!attribute [rw] longitude_column
  #   @return [::String]
  #     Optional. Longitude column.
  # @!attribute [rw] count_column
  #   @return [::String]
  #     Optional. Field to count.
  class DataSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Map position settings for the map.
  # @!attribute [rw] fit_data
  #   @return [::Boolean]
  #     Optional. Whether to fit the map to the data.
  #     If true, the map will be resized to fit the data.
  #     If false, langitude and longitude will be used to set the map size.
  # @!attribute [rw] latitude_value
  #   @return [::Float]
  #     Optional. Latitude of the map.
  # @!attribute [rw] longitude_value
  #   @return [::Float]
  #     Optional. Longitude of the map.
  # @!attribute [rw] zoom_scale_value
  #   @return [::Float]
  #     Optional. Scale of the map.
  class MapPosition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Point settings for the map.
  # @!attribute [rw] point_size_type
  #   @return [::Google::Cloud::Chronicle::V1::PointSizeType]
  #     Optional. Point size type for the map. This is used to
  #     determine the size of the points on the map.
  # @!attribute [rw] color
  #   @return [::String]
  #     Optional. Color for the point on the map.
  class PointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#plot_mode::Google::Cloud::Chronicle::V1::PlotMode

Returns Optional. Plot mode for the map. This is used to determine whether to show points, heatmap or both.

Returns:



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 442

class GoogleMapsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Data settings for the map.
  # @!attribute [rw] latitude_column
  #   @return [::String]
  #     Optional. Latitude column.
  # @!attribute [rw] longitude_column
  #   @return [::String]
  #     Optional. Longitude column.
  # @!attribute [rw] count_column
  #   @return [::String]
  #     Optional. Field to count.
  class DataSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Map position settings for the map.
  # @!attribute [rw] fit_data
  #   @return [::Boolean]
  #     Optional. Whether to fit the map to the data.
  #     If true, the map will be resized to fit the data.
  #     If false, langitude and longitude will be used to set the map size.
  # @!attribute [rw] latitude_value
  #   @return [::Float]
  #     Optional. Latitude of the map.
  # @!attribute [rw] longitude_value
  #   @return [::Float]
  #     Optional. Longitude of the map.
  # @!attribute [rw] zoom_scale_value
  #   @return [::Float]
  #     Optional. Scale of the map.
  class MapPosition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Point settings for the map.
  # @!attribute [rw] point_size_type
  #   @return [::Google::Cloud::Chronicle::V1::PointSizeType]
  #     Optional. Point size type for the map. This is used to
  #     determine the size of the points on the map.
  # @!attribute [rw] color
  #   @return [::String]
  #     Optional. Color for the point on the map.
  class PointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#point_settings::Google::Cloud::Chronicle::V1::DashboardChart::Visualization::GoogleMapsConfig::PointSettings

Returns Optional. Point settings for the map.



442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 442

class GoogleMapsConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Data settings for the map.
  # @!attribute [rw] latitude_column
  #   @return [::String]
  #     Optional. Latitude column.
  # @!attribute [rw] longitude_column
  #   @return [::String]
  #     Optional. Longitude column.
  # @!attribute [rw] count_column
  #   @return [::String]
  #     Optional. Field to count.
  class DataSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Map position settings for the map.
  # @!attribute [rw] fit_data
  #   @return [::Boolean]
  #     Optional. Whether to fit the map to the data.
  #     If true, the map will be resized to fit the data.
  #     If false, langitude and longitude will be used to set the map size.
  # @!attribute [rw] latitude_value
  #   @return [::Float]
  #     Optional. Latitude of the map.
  # @!attribute [rw] longitude_value
  #   @return [::Float]
  #     Optional. Longitude of the map.
  # @!attribute [rw] zoom_scale_value
  #   @return [::Float]
  #     Optional. Scale of the map.
  class MapPosition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Point settings for the map.
  # @!attribute [rw] point_size_type
  #   @return [::Google::Cloud::Chronicle::V1::PointSizeType]
  #     Optional. Point size type for the map. This is used to
  #     determine the size of the points on the map.
  # @!attribute [rw] color
  #   @return [::String]
  #     Optional. Color for the point on the map.
  class PointSettings
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end