Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::GoogleMapsConfig::MapPosition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb

Overview

Map position settings for the map.

Instance Attribute Summary collapse

Instance Attribute Details

#fit_data::Boolean

Returns Optional. Whether to fit the map to the data. If true, the map will be resized to fit the data. If false, langitude and longitude will be used to set the map size.

Returns:

  • (::Boolean)

    Optional. Whether to fit the map to the data. If true, the map will be resized to fit the data. If false, langitude and longitude will be used to set the map size.



476
477
478
479
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 476

class MapPosition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#latitude_value::Float

Returns Optional. Latitude of the map.

Returns:

  • (::Float)

    Optional. Latitude of the map.



476
477
478
479
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 476

class MapPosition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#longitude_value::Float

Returns Optional. Longitude of the map.

Returns:

  • (::Float)

    Optional. Longitude of the map.



476
477
478
479
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 476

class MapPosition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#zoom_scale_value::Float

Returns Optional. Scale of the map.

Returns:

  • (::Float)

    Optional. Scale of the map.



476
477
478
479
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 476

class MapPosition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end