Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::Series::Encode
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::Visualization::Series::Encode
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Instance Attribute Summary collapse
-
#item_name ⇒ ::String
This is useful in charts like 'pie', where data item name can be displayed in legend.
-
#value ⇒ ::String
For some type of series that are not in any coordinate system, like 'pie'.
- #x ⇒ ::String
- #y ⇒ ::String
Instance Attribute Details
#item_name ⇒ ::String
Returns This is useful in charts like 'pie', where data item name can be displayed in legend.
200 201 202 203 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 200 class Encode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::String
Returns For some type of series that are not in any coordinate system, like 'pie'.
200 201 202 203 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 200 class Encode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |