Class: Google::Cloud::Chronicle::V1::DashboardFilter

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

Dashboard level filter that can be used in native dashboards as well as inputs to execute query.

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_filter_config::Google::Cloud::Chronicle::V1::AdvancedFilterConfig

Returns Optional. Advanced filter configuration for the filter widget.

Returns:



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#chart_ids::Array<::String>

Returns Chart IDs the filter is applicable for.

Returns:

  • (::Array<::String>)

    Chart IDs the filter is applicable for.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_source::Google::Cloud::Chronicle::V1::DataSource

Returns Datasource the filter is applicable for.

Returns:



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String

Returns Display name of the filter.

Returns:

  • (::String)

    Display name of the filter.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#field_path::String

Returns Filter field path.

Returns:

  • (::String)

    Filter field path.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter_operator_and_field_values::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>

Returns Operator and values. Can include multiple modifiers.

Returns:



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#id::String

Returns ID of the filter.

Returns:

  • (::String)

    ID of the filter.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_mandatory::Boolean

Returns Optional. Whether this filter is required to be populated by the dashboard consumer prior to the dashboard loading.

Returns:

  • (::Boolean)

    Optional. Whether this filter is required to be populated by the dashboard consumer prior to the dashboard loading.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_standard_time_range_filter::Boolean

Returns Optional. Whether the filter is a standard time range filter, meaning that it has to be used as the query time range, and not as a predicate in the query. A chart can have at most one standard time range filter applied.

Returns:

  • (::Boolean)

    Optional. Whether the filter is a standard time range filter, meaning that it has to be used as the query time range, and not as a predicate in the query. A chart can have at most one standard time range filter applied.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_standard_time_range_filter_enabled::Boolean

Returns Optional. Whether this standard time range filter is enabled.

Returns:

  • (::Boolean)

    Optional. Whether this standard time range filter is enabled.



352
353
354
355
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 352

class DashboardFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end