Class: Google::Cloud::Chronicle::V1::DashboardQuery::Input

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

Input to the query like time window.

Defined Under Namespace

Classes: RelativeTime

Instance Attribute Summary collapse

Instance Attribute Details

#relative_time::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime

Returns time range for last x units.

Note: The following fields are mutually exclusive: relative_time, time_window. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 57

class Input
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # time representation for last x units.
  # @!attribute [rw] time_unit
  #   @return [::Google::Cloud::Chronicle::V1::TimeUnit]
  # @!attribute [rw] start_time_val
  #   @return [::Integer]
  class RelativeTime
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#time_window::Google::Type::Interval

Returns time range to fetch the data for.

Note: The following fields are mutually exclusive: time_window, relative_time. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Type::Interval)

    time range to fetch the data for.

    Note: The following fields are mutually exclusive: time_window, relative_time. If a field in that set is populated, all other fields in the set will automatically be cleared.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 57

class Input
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # time representation for last x units.
  # @!attribute [rw] time_unit
  #   @return [::Google::Cloud::Chronicle::V1::TimeUnit]
  # @!attribute [rw] start_time_val
  #   @return [::Integer]
  class RelativeTime
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end