Class: Google::Cloud::Chronicle::V1::DataAccessControlService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/data_access_control_service/client.rb

Overview

Client for the DataAccessControlService service.

DataAccessControlService exposes resources and endpoints related to data access control.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#data_access_label_path, #data_access_scope_path, #instance_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new DataAccessControlService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the DataAccessControlService client.

Yield Parameters:



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 157

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/data_access_control_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @data_access_control_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::DataAccessControlService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @data_access_control_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the DataAccessControlService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all DataAccessControlService clients
::Google::Cloud::Chronicle::V1::DataAccessControlService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_data_access_label.timeout = 60.0

    default_config.rpcs.get_data_access_label.timeout = 60.0
    default_config.rpcs.get_data_access_label.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_data_access_labels.timeout = 60.0
    default_config.rpcs.list_data_access_labels.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_data_access_label.timeout = 60.0

    default_config.rpcs.delete_data_access_label.timeout = 60.0

    default_config.rpcs.create_data_access_scope.timeout = 60.0

    default_config.rpcs.get_data_access_scope.timeout = 60.0
    default_config.rpcs.get_data_access_scope.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_data_access_scopes.timeout = 60.0
    default_config.rpcs.list_data_access_scopes.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_data_access_scope.timeout = 60.0

    default_config.rpcs.delete_data_access_scope.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the DataAccessControlService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



127
128
129
130
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 127

def configure
  yield @config if block_given?
  @config
end

#create_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #create_data_access_label(parent: nil, data_access_label: nil, data_access_label_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

Creates a data access label. Data access labels are applied to incoming event data and selected in data access scopes (another resource), and only users with scopes containing the label can see data with that label. Currently, the data access label resource only includes custom labels, which are labels that correspond to UDM queries over event data.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest.new

# Call the create_data_access_label method.
result = client.create_data_access_label request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessLabel.
p result

Overloads:

  • #create_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to create_data_access_label via a request object, either of type CreateDataAccessLabelRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_data_access_label(parent: nil, data_access_label: nil, data_access_label_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to create_data_access_label via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this Data Access Label will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • data_access_label (::Google::Cloud::Chronicle::V1::DataAccessLabel, ::Hash) (defaults to: nil)

      Required. Data access label to create.

    • data_access_label_id (::String) (defaults to: nil)

      Required. The ID to use for the data access label, which will become the label's display name and the final component of the label's resource name. The maximum number of characters should be 63. Regex pattern is as per AIP: https://google.aip.dev/122#resource-id-segments

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 276

def create_data_access_label request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_data_access_label..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_data_access_label.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_data_access_label.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :create_data_access_label, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #create_data_access_scope(parent: nil, data_access_scope: nil, data_access_scope_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

Creates a data access scope. Data access scope is a combination of allowed and denied labels attached to a permission group. If a scope has allowed labels A and B and denied labels C and D, then the group of people attached to the scope will have permissions to see all events labeled with A or B (or both) and not labeled with either C or D.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest.new

# Call the create_data_access_scope method.
result = client.create_data_access_scope request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessScope.
p result

Overloads:

  • #create_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to create_data_access_scope via a request object, either of type CreateDataAccessScopeRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_data_access_scope(parent: nil, data_access_scope: nil, data_access_scope_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to create_data_access_scope via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this Data Access Scope will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • data_access_scope (::Google::Cloud::Chronicle::V1::DataAccessScope, ::Hash) (defaults to: nil)

      Required. Data access scope to create.

    • data_access_scope_id (::String) (defaults to: nil)

      Required. The user provided scope id which will become the last part of the name of the scope resource. Needs to be compliant with https://google.aip.dev/122

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 749

def create_data_access_scope request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_data_access_scope..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_data_access_scope.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_data_access_scope.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :create_data_access_scope, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_data_access_label(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_label(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a data access label. When a label is deleted, new data that enters in the system will not receive the label, but the label will not be removed from old data that still refers to it.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest.new

# Call the delete_data_access_label method.
result = client.delete_data_access_label request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_data_access_label(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_access_label via a request object, either of type Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_data_access_label(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_access_label via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The ID of the data access label to delete. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessLabels/{data_access_label}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 652

def delete_data_access_label request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_data_access_label..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_data_access_label.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_data_access_label.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :delete_data_access_label, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_data_access_scope(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_scope(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes a data access scope.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest.new

# Call the delete_data_access_scope method.
result = client.delete_data_access_scope request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_data_access_scope(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_access_scope via a request object, either of type Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_data_access_scope(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_data_access_scope via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The ID of the data access scope to delete. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 1124

def delete_data_access_scope request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_data_access_scope..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_data_access_scope.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_data_access_scope.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :delete_data_access_scope, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #get_data_access_label(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

Gets a data access label.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetDataAccessLabelRequest.new

# Call the get_data_access_label method.
result = client.get_data_access_label request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessLabel.
p result

Overloads:

  • #get_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to get_data_access_label via a request object, either of type GetDataAccessLabelRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetDataAccessLabelRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_data_access_label(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to get_data_access_label via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The ID of the data access label to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessLabels/{data_access_label}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 363

def get_data_access_label request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessLabelRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_data_access_label..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_data_access_label.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_data_access_label.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :get_data_access_label, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #get_data_access_scope(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

Retrieves an existing data access scope.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetDataAccessScopeRequest.new

# Call the get_data_access_scope method.
result = client.get_data_access_scope request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessScope.
p result

Overloads:

  • #get_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to get_data_access_scope via a request object, either of type GetDataAccessScopeRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetDataAccessScopeRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_data_access_scope(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to get_data_access_scope via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The ID of the data access scope to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 836

def get_data_access_scope request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessScopeRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_data_access_scope..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_data_access_scope.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_data_access_scope.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :get_data_access_scope, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_data_access_labels(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel> #list_data_access_labels(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>

Lists all data access labels for the customer.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest.new

# Call the list_data_access_labels method.
result = client.list_data_access_labels request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::DataAccessLabel.
  p item
end

Overloads:

  • #list_data_access_labels(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>

    Pass arguments to list_data_access_labels via a request object, either of type ListDataAccessLabelsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_data_access_labels(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>

    Pass arguments to list_data_access_labels via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this data access label will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of data access labels to return. The service may return fewer than this value. If unspecified, at most 100 data access labels will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListDataAccessLabelsRequest call. Provide this to retrieve the subsequent page.

    • filter (::String) (defaults to: nil)

      Optional. A filter which should follow the guidelines of AIP-160. Supports filtering on all fieds of DataAccessLabel and all operations as mentioned in https://google.aip.dev/160. example filter: "create_time greater than \"2023-04-21T11:30:00-04:00\" OR display_name:\"-21-1\"".

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 467

def list_data_access_labels request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_data_access_labels..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_data_access_labels.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_data_access_labels.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :list_data_access_labels, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_labels, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_data_access_scopes(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope> #list_data_access_scopes(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>

Lists all existing data access scopes for the customer.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListDataAccessScopesRequest.new

# Call the list_data_access_scopes method.
result = client.list_data_access_scopes request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::DataAccessScope.
  p item
end

Overloads:

  • #list_data_access_scopes(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>

    Pass arguments to list_data_access_scopes via a request object, either of type ListDataAccessScopesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListDataAccessScopesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_data_access_scopes(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>

    Pass arguments to list_data_access_scopes via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this data access scope will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of data access scopes to return. The service may return fewer than this value. If unspecified, at most 100 data access scopes will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListDataAccessScopesRequest call. Provide this to retrieve the subsequent page.

    • filter (::String) (defaults to: nil)

      Optional. A filter which should follow the guidelines of AIP-160. Supports filtering on all fieds of DataAccessScope and all operations as mentioned in https://google.aip.dev/160. example filter: "create_time greater than \"2023-04-21T11:30:00-04:00\" OR display_name:\"-21-1\"".

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 940

def list_data_access_scopes request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessScopesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_data_access_scopes..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_data_access_scopes.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_data_access_scopes.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :list_data_access_scopes, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_scopes, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


213
214
215
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 213

def logger
  @data_access_control_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


137
138
139
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 137

def universe_domain
  @data_access_control_service_stub.universe_domain
end

#update_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #update_data_access_label(data_access_label: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

Updates a data access label.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest.new

# Call the update_data_access_label method.
result = client.update_data_access_label request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessLabel.
p result

Overloads:

  • #update_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to update_data_access_label via a request object, either of type UpdateDataAccessLabelRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_data_access_label(data_access_label: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel

    Pass arguments to update_data_access_label via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • data_access_label (::Google::Cloud::Chronicle::V1::DataAccessLabel, ::Hash) (defaults to: nil)

      Required. The data access label to update.

      The label's name field is used to identify the label to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessLabels/{data_access_label}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description and definition fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 563

def update_data_access_label request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_data_access_label..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.data_access_label&.name
    header_params["data_access_label.name"] = request.data_access_label.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_data_access_label.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_data_access_label.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :update_data_access_label, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #update_data_access_scope(data_access_scope: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

Updates a data access scope.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::DataAccessControlService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest.new

# Call the update_data_access_scope method.
result = client.update_data_access_scope request

# The returned object is of type Google::Cloud::Chronicle::V1::DataAccessScope.
p result

Overloads:

  • #update_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to update_data_access_scope via a request object, either of type UpdateDataAccessScopeRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_data_access_scope(data_access_scope: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope

    Pass arguments to update_data_access_scope via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • data_access_scope (::Google::Cloud::Chronicle::V1::DataAccessScope, ::Hash) (defaults to: nil)

      Required. The data access scope to update.

      The scope's name field is used to identify the scope to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description, the allowed and denied labels list fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 1037

def update_data_access_scope request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_data_access_scope..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.data_access_scope&.name
    header_params["data_access_scope.name"] = request.data_access_scope.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_data_access_scope.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_data_access_scope.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @data_access_control_service_stub.call_rpc :update_data_access_scope, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end