Class: Google::Cloud::Chronicle::V1::DataAccessLabelReference

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_access_control.rb

Overview

Reference object to a data access label.

Instance Attribute Summary collapse

Instance Attribute Details

#asset_namespace::String

Returns The asset namespace configured in the forwarder of the customer's events.

Note: The following fields are mutually exclusive: asset_namespace, data_access_label, log_type, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The asset namespace configured in the forwarder of the customer's events.

    Note: The following fields are mutually exclusive: asset_namespace, data_access_label, log_type, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.



343
344
345
346
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 343

class DataAccessLabelReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_access_label::String

Returns The name of the data access label.

Note: The following fields are mutually exclusive: data_access_label, log_type, asset_namespace, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The name of the data access label.

    Note: The following fields are mutually exclusive: data_access_label, log_type, asset_namespace, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.



343
344
345
346
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 343

class DataAccessLabelReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The display name of the label. Data access label and log types's name will match the display name of the resource. The asset namespace will match the namespace itself. The ingestion key value pair will match the key of the tuple.

Returns:

  • (::String)

    Output only. The display name of the label. Data access label and log types's name will match the display name of the resource. The asset namespace will match the namespace itself. The ingestion key value pair will match the key of the tuple.



343
344
345
346
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 343

class DataAccessLabelReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ingestion_label::Google::Cloud::Chronicle::V1::IngestionLabel

Returns The ingestion label configured in the forwarder of the customer's events.

Note: The following fields are mutually exclusive: ingestion_label, data_access_label, log_type, asset_namespace. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Chronicle::V1::IngestionLabel)

    The ingestion label configured in the forwarder of the customer's events.

    Note: The following fields are mutually exclusive: ingestion_label, data_access_label, log_type, asset_namespace. If a field in that set is populated, all other fields in the set will automatically be cleared.



343
344
345
346
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 343

class DataAccessLabelReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#log_type::String

Returns The name of the log type.

Note: The following fields are mutually exclusive: log_type, data_access_label, asset_namespace, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The name of the log type.

    Note: The following fields are mutually exclusive: log_type, data_access_label, asset_namespace, ingestion_label. If a field in that set is populated, all other fields in the set will automatically be cleared.



343
344
345
346
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 343

class DataAccessLabelReference
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end