Class: Google::Cloud::Chronicle::V1::DataAccessScope
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataAccessScope
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
A DataAccessScope is a boolean expression of data access labels used to restrict access to data for users.
Instance Attribute Summary collapse
-
#allow_all ⇒ ::Boolean
Optional.
-
#allowed_data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabelReference>
Optional.
-
#author ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#denied_data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabelReference>
Optional.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
readonly
Output only.
-
#last_editor ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#allow_all ⇒ ::Boolean
Returns Optional. Whether or not the scope allows all labels, allow_all and allowed_data_access_labels are mutually exclusive and one of them must be present. denied_data_access_labels can still be used along with allow_all. When combined with denied_data_access_labels, access will be granted to all data that doesn't have labels mentioned in denied_data_access_labels. E.g.: A customer with scope with denied labels A and B and allow_all will be able to see all data except data labeled with A and data labeled with B and data with labels A and B.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#allowed_data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabelReference>
Returns Optional. The allowed labels for the scope. Either allow_all or allowed_data_access_labels needs to be provided. When provided, there has to be at least one label allowed for the scope to be valid. The logical operator for evaluation of the allowed labels is OR. E.g.: A customer with scope with allowed labels A and B will be able to see data with labeled with A or B or (A and B).
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#author ⇒ ::String (readonly)
Returns Output only. The user who created the data access scope.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the data access scope was created.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#denied_data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabelReference>
Returns Optional. The denied labels for the scope. The logical operator for evaluation of the denied labels is AND. E.g.: A customer with scope with denied labels A and B won't be able to see data labeled with A and data labeled with B and data with labels A and B.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. A description of the data access scope for a human reader.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String (readonly)
Returns Output only. The name to be used for display to customers of the data access scope.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_editor ⇒ ::String (readonly)
Returns Output only. The user who last updated the data access scope.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The unique full name of the data access scope. The name should comply with https://google.aip.dev/122 standards.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the data access scope was last updated.
309 310 311 312 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 309 class DataAccessScope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |