Class: Google::Cloud::Chronicle::V1::DataTable

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

DataTable represents the data table resource.

Instance Attribute Summary collapse

Instance Attribute Details

#approximate_row_count::Integer (readonly)

Returns Output only. The count of rows in the data table.

Returns:

  • (::Integer)

    Output only. The count of rows in the data table.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#column_info::Array<::Google::Cloud::Chronicle::V1::DataTableColumnInfo>

Returns Immutable. Details of all the columns in the table.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Table create time.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#data_table_uuid::String (readonly)

Returns Output only. Data table unique id.

Returns:

  • (::String)

    Output only. Data table unique id



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns Required. A user-provided description of the data table.

Returns:

  • (::String)

    Required. A user-provided description of the data table.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The unique display name of the data table.

Returns:

  • (::String)

    Output only. The unique display name of the data table.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the data table Format: "{project}/locations/{location}/instances/{instance}/dataTables/{data_table}".

Returns:

  • (::String)

    Identifier. The resource name of the data table Format: "{project}/locations/{location}/instances/{instance}/dataTables/{data_table}"



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#row_time_to_live::String

Returns Optional. User-provided TTL of the data table.

Returns:

  • (::String)

    Optional. User-provided TTL of the data table.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#row_time_to_live_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Last update time of the TTL of the data table.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_associations_count::Integer (readonly)

Returns Output only. The count of rules using the data table.

Returns:

  • (::Integer)

    Output only. The count of rules using the data table.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rules::Array<::String> (readonly)

Returns Output only. The resource names for the associated Rules that use this data table. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}. {rule} here refers to the rule id.

Returns:

  • (::Array<::String>)

    Output only. The resource names for the associated Rules that use this data table. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}. {rule} here refers to the rule id.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_info::Google::Cloud::Chronicle::V1::DataTableScopeInfo

Returns Optional. The scope info of the data table. During data table creation, if this field is not set, the data table without scopes (an unscoped table) will be created for a global user. For a scoped user, this field must be set. During data table update, if scope_info is requested to be updated, this field must be set.

Returns:

  • (::Google::Cloud::Chronicle::V1::DataTableScopeInfo)

    Optional. The scope info of the data table. During data table creation, if this field is not set, the data table without scopes (an unscoped table) will be created for a global user. For a scoped user, this field must be set. During data table update, if scope_info is requested to be updated, this field must be set.



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_source::Google::Cloud::Chronicle::V1::DataTableUpdateSource (readonly)

Returns Output only. Source of the data table update.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Table update time.

Returns:



384
385
386
387
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 384

class DataTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end