Class: Google::Cloud::Chronicle::V1::DataTableRow

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

DataTableRow represents a single row in a data table.

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. DataTableRow create time.

Returns:



408
409
410
411
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 408

class DataTableRow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the data table Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}.

Returns:

  • (::String)

    Identifier. The resource name of the data table Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}



408
409
410
411
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 408

class DataTableRow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#row_time_to_live::String

Returns Optional. User-provided TTL of the data table row.

Returns:

  • (::String)

    Optional. User-provided TTL of the data table row.



408
409
410
411
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 408

class DataTableRow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. DataTableRow update time.

Returns:



408
409
410
411
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 408

class DataTableRow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#values::Array<::String>

Returns Required. All column values for a single row. The values should be in the same order as the columns of the data tables.

Returns:

  • (::Array<::String>)

    Required. All column values for a single row. The values should be in the same order as the columns of the data tables.



408
409
410
411
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 408

class DataTableRow
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end