Class: Google::Cloud::Chronicle::V1::DataTableScopeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

DataTableScopeInfo specifies the scope info of the data table.

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_scopes::Array<::String>

Returns Required. Contains the list of scope names of the data table. If the list is empty, the data table is treated as unscoped. The scope names should be full resource names and should be of the format: "projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}".

Returns:

  • (::Array<::String>)

    Required. Contains the list of scope names of the data table. If the list is empty, the data table is treated as unscoped. The scope names should be full resource names and should be of the format: "projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}"



327
328
329
330
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 327

class DataTableScopeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end