Class: Google::Cloud::Chronicle::V1::DataTableService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataTableService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/data_table_service/client.rb
Overview
Client for the DataTableService service.
DataTableManager provides an interface for managing data tables.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client class.
Instance Method Summary collapse
-
#bulk_create_data_table_rows(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse
Create data table rows in bulk.
-
#bulk_get_data_table_rows(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse
Get data table rows in bulk.
-
#bulk_replace_data_table_rows(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse
Replace all existing data table rows with new data table rows.
-
#bulk_update_data_table_rows(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse
Update data table rows in bulk.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client instance.
-
#create_data_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Create a new data table.
-
#create_data_table_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Create a new data table row.
-
#delete_data_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Delete data table.
-
#delete_data_table_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Delete data table row.
-
#get_data_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Get data table info.
-
#get_data_table_operation_errors(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors
Get the error for a data table operation.
-
#get_data_table_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Get data table row.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new DataTableService client object.
-
#list_data_table_rows(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow>
List data table rows.
-
#list_data_tables(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable>
List data tables.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_data_table(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Update data table.
-
#update_data_table_row(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Update data table row.
Methods included from Paths
#data_access_scope_path, #data_table_operation_errors_path, #data_table_path, #data_table_row_path, #instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new DataTableService client object.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 172 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/chronicle/v1/data_table_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @data_table_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Chronicle::V1::DataTableService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @data_table_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_data_table.timeout = 600.0 default_config.rpcs.list_data_tables.timeout = 600.0 default_config.rpcs.list_data_tables.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_data_table.timeout = 600.0 default_config.rpcs.get_data_table.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_table.timeout = 600.0 default_config.rpcs.delete_data_table.timeout = 600.0 default_config.rpcs.create_data_table_row.timeout = 600.0 default_config.rpcs.update_data_table_row.timeout = 600.0 default_config.rpcs.list_data_table_rows.timeout = 600.0 default_config.rpcs.list_data_table_rows.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_data_table_row.timeout = 600.0 default_config.rpcs.get_data_table_row.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.delete_data_table_row.timeout = 600.0 default_config.rpcs.bulk_create_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_get_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_get_data_table_rows.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.bulk_replace_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_update_data_table_rows.timeout = 600.0 default_config.rpcs.get_data_table_operation_errors.timeout = 600.0 default_config.rpcs.get_data_table_operation_errors.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#bulk_create_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse #bulk_create_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse
Create data table rows in bulk.
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1214 def bulk_create_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_create_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.bulk_create_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_create_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :bulk_create_data_table_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_get_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse #bulk_get_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse
Get data table rows in bulk.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1304 def bulk_get_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_get_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.bulk_get_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_get_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :bulk_get_data_table_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_replace_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse #bulk_replace_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse
Replace all existing data table rows with new data table rows.
1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1396 def bulk_replace_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_replace_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.bulk_replace_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_replace_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :bulk_replace_data_table_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_update_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse #bulk_update_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse
Update data table rows in bulk.
1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1486 def bulk_update_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_update_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.bulk_update_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_update_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :bulk_update_data_table_rows, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
142 143 144 145 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 142 def configure yield @config if block_given? @config end |
#create_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #create_data_table(parent: nil, data_table: nil, data_table_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Create a new data table.
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 287 def create_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_data_table.timeout, metadata: , retry_policy: @config.rpcs.create_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :create_data_table, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #create_data_table_row(parent: nil, data_table_row: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Create a new data table row.
752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 752 def create_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.create_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :create_data_table_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_table(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_table(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty
Delete data table.
663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 663 def delete_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_data_table.timeout, metadata: , retry_policy: @config.rpcs.delete_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :delete_data_table, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_table_row(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_table_row(name: nil) ⇒ ::Google::Protobuf::Empty
Delete data table row.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1123 def delete_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.delete_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :delete_data_table_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #get_data_table(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Get data table info.
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 480 def get_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_table.timeout, metadata: , retry_policy: @config.rpcs.get_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :get_data_table, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table_operation_errors(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors #get_data_table_operation_errors(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors
Get the error for a data table operation.
1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1573 def get_data_table_operation_errors request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableOperationErrorsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table_operation_errors..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_table_operation_errors.timeout, metadata: , retry_policy: @config.rpcs.get_data_table_operation_errors.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :get_data_table_operation_errors, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #get_data_table_row(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Get data table row
1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 1036 def get_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.get_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :get_data_table_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_table_rows(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow> #list_data_table_rows(parent: nil, page_size: nil, page_token: nil, order_by: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow>
List data table rows.
947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 947 def list_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.list_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :list_data_table_rows, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @data_table_service_stub, :list_data_table_rows, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_tables(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable> #list_data_tables(parent: nil, page_size: nil, page_token: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable>
List data tables.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 391 def list_data_tables request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataTablesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_tables..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_data_tables.timeout, metadata: , retry_policy: @config.rpcs.list_data_tables.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :list_data_tables, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @data_table_service_stub, :list_data_tables, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
228 229 230 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 228 def logger @data_table_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
152 153 154 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 152 def universe_domain @data_table_service_stub.universe_domain end |
#update_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #update_data_table(data_table: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Update data table.
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 572 def update_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.data_table&.name header_params["data_table.name"] = request.data_table.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_data_table.timeout, metadata: , retry_policy: @config.rpcs.update_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :update_data_table, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #update_data_table_row(data_table_row: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Update data table row
843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/client.rb', line 843 def update_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.data_table_row&.name header_params["data_table_row.name"] = request.data_table_row.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.update_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.call_rpc :update_data_table_row, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |