Class: Google::Cloud::Chronicle::V1::DataTableService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataTableService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb
Overview
REST client for the DataTableService service.
DataTableManager provides an interface for managing data tables.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client class.
Instance Method Summary collapse
-
#bulk_create_data_table_rows(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse
Create data table rows in bulk.
-
#bulk_get_data_table_rows(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse
Get data table rows in bulk.
-
#bulk_replace_data_table_rows(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse
Replace all existing data table rows with new data table rows.
-
#bulk_update_data_table_rows(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse
Update data table rows in bulk.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client instance.
-
#create_data_table(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Create a new data table.
-
#create_data_table_row(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Create a new data table row.
-
#delete_data_table(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Delete data table.
-
#delete_data_table_row(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Delete data table row.
-
#get_data_table(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Get data table info.
-
#get_data_table_operation_errors(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors
Get the error for a data table operation.
-
#get_data_table_row(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Get data table row.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new DataTableService REST client object.
-
#list_data_table_rows(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow>
List data table rows.
-
#list_data_tables(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable>
List data tables.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_data_table(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Update data table.
-
#update_data_table_row(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Update data table row.
Methods included from Paths
#data_access_scope_path, #data_table_operation_errors_path, #data_table_path, #data_table_row_path, #instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new DataTableService REST client object.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 174 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @data_table_service_stub = ::Google::Cloud::Chronicle::V1::DataTableService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @data_table_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_data_table.timeout = 600.0 default_config.rpcs.list_data_tables.timeout = 600.0 default_config.rpcs.list_data_tables.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_data_table.timeout = 600.0 default_config.rpcs.get_data_table.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_table.timeout = 600.0 default_config.rpcs.delete_data_table.timeout = 600.0 default_config.rpcs.create_data_table_row.timeout = 600.0 default_config.rpcs.update_data_table_row.timeout = 600.0 default_config.rpcs.list_data_table_rows.timeout = 600.0 default_config.rpcs.list_data_table_rows.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_data_table_row.timeout = 600.0 default_config.rpcs.get_data_table_row.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.delete_data_table_row.timeout = 600.0 default_config.rpcs.bulk_create_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_get_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_get_data_table_rows.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.bulk_replace_data_table_rows.timeout = 600.0 default_config.rpcs.bulk_update_data_table_rows.timeout = 600.0 default_config.rpcs.get_data_table_operation_errors.timeout = 600.0 default_config.rpcs.get_data_table_operation_errors.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#bulk_create_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse #bulk_create_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsResponse
Create data table rows in bulk.
1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1136 def bulk_create_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkCreateDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_create_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.bulk_create_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_create_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.bulk_create_data_table_rows request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_get_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse #bulk_get_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsResponse
Get data table rows in bulk.
1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1219 def bulk_get_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkGetDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_get_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.bulk_get_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_get_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.bulk_get_data_table_rows request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_replace_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse #bulk_replace_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsResponse
Replace all existing data table rows with new data table rows.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1304 def bulk_replace_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkReplaceDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_replace_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.bulk_replace_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_replace_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.bulk_replace_data_table_rows request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#bulk_update_data_table_rows(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse #bulk_update_data_table_rows(parent: nil, requests: nil) ⇒ ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsResponse
Update data table rows in bulk.
1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1387 def bulk_update_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::BulkUpdateDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.bulk_update_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.bulk_update_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.bulk_update_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.bulk_update_data_table_rows request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataTableService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
144 145 146 147 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 144 def configure yield @config if block_given? @config end |
#create_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #create_data_table(parent: nil, data_table: nil, data_table_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Create a new data table.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 279 def create_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_data_table.timeout, metadata: , retry_policy: @config.rpcs.create_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.create_data_table request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#create_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #create_data_table_row(parent: nil, data_table_row: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Create a new data table row.
709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 709 def create_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.create_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.create_data_table_row request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_table(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_table(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty
Delete data table.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 627 def delete_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_data_table.timeout, metadata: , retry_policy: @config.rpcs.delete_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.delete_data_table request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_table_row(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_table_row(name: nil) ⇒ ::Google::Protobuf::Empty
Delete data table row.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1052 def delete_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.delete_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.delete_data_table_row request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #get_data_table(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Get data table info.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 458 def get_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_data_table.timeout, metadata: , retry_policy: @config.rpcs.get_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.get_data_table request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table_operation_errors(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors #get_data_table_operation_errors(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableOperationErrors
Get the error for a data table operation.
1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 1467 def get_data_table_operation_errors request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableOperationErrorsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table_operation_errors..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_data_table_operation_errors.timeout, metadata: , retry_policy: @config.rpcs.get_data_table_operation_errors.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.get_data_table_operation_errors request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #get_data_table_row(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Get data table row
972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 972 def get_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.get_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.get_data_table_row request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_table_rows(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow> #list_data_table_rows(parent: nil, page_size: nil, page_token: nil, order_by: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTableRow>
List data table rows.
890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 890 def list_data_table_rows request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataTableRowsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_table_rows..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_data_table_rows.timeout, metadata: , retry_policy: @config.rpcs.list_data_table_rows.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.list_data_table_rows request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @data_table_service_stub, :list_data_table_rows, "data_table_rows", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_tables(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable> #list_data_tables(parent: nil, page_size: nil, page_token: nil, order_by: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataTable>
List data tables.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 376 def list_data_tables request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataTablesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_tables..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_data_tables.timeout, metadata: , retry_policy: @config.rpcs.list_data_tables.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.list_data_tables request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @data_table_service_stub, :list_data_tables, "data_tables", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
221 222 223 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 221 def logger @data_table_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
154 155 156 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 154 def universe_domain @data_table_service_stub.universe_domain end |
#update_data_table(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable #update_data_table(data_table: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTable
Update data table.
543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 543 def update_data_table request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataTableRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_table..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_data_table.timeout, metadata: , retry_policy: @config.rpcs.update_data_table.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.update_data_table request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_data_table_row(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow #update_data_table_row(data_table_row: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataTableRow
Update data table row
793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 |
# File 'lib/google/cloud/chronicle/v1/data_table_service/rest/client.rb', line 793 def update_data_table_row request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataTableRowRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_table_row..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_data_table_row.timeout, metadata: , retry_policy: @config.rpcs.update_data_table_row.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_table_service_stub.update_data_table_row request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |