Class: Google::Cloud::Chronicle::V1::DeleteDataTableRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

Request message for deleting data tables.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. If set to true, any rows under this data table will also be deleted. (Otherwise, the request will only work if the data table has no rows.).

Returns:

  • (::Boolean)

    Optional. If set to true, any rows under this data table will also be deleted. (Otherwise, the request will only work if the data table has no rows.)



110
111
112
113
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 110

class DeleteDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the data table to delete. Format projects/{project}/locations/{location}/instances/{instances}/dataTables/{data_table}.

Returns:

  • (::String)

    Required. The resource name of the data table to delete. Format projects/{project}/locations/{location}/instances/{instances}/dataTables/{data_table}



110
111
112
113
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 110

class DeleteDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end