Class: Google::Cloud::Chronicle::V1::DeleteDataTableRowRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

Request to delete data table row.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the data table row i,e row_id. Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}.

Returns:

  • (::String)

    Required. The resource name of the data table row i,e row_id. Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}



216
217
218
219
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 216

class DeleteDataTableRowRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end