Class: Google::Cloud::Chronicle::V1::DeleteWatchlistRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/entity.rb

Overview

Request message for deleting watchlist.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. If set to true, any entities under this watchlist will also be deleted. (Otherwise, the request will only work if the watchlist has no entities.).

Returns:

  • (::Boolean)

    Optional. If set to true, any entities under this watchlist will also be deleted. (Otherwise, the request will only work if the watchlist has no entities.)



203
204
205
206
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 203

class DeleteWatchlistRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the watchlist to delete. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}.

Returns:

  • (::String)

    Required. The name of the watchlist to delete. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}



203
204
205
206
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 203

class DeleteWatchlistRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end