Class: Google::Cloud::Chronicle::V1::DetectionExclusionActivity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

The activity for a findings refinement that is a detection exclusion. The activity is broken down per detector.

Defined Under Namespace

Classes: DetectionExclusionDetectorActivity

Instance Attribute Summary collapse

Instance Attribute Details

#detection_exclusion_detector_activities::Array<::Google::Cloud::Chronicle::V1::DetectionExclusionActivity::DetectionExclusionDetectorActivity>

Returns The activity for the detection exclusion broken down by detector.

Returns:



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 137

class DetectionExclusionActivity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The activity for a findings refinement that is a detection exclusion broken
  # down for one specific detector.
  # @!attribute [rw] curated_rule
  #   @return [::String]
  #     Full resource name for the curated rule this activity corresponds to.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/instances/\\{instance}/curatedRules/\\{rule}
  #
  #     Note: The following fields are mutually exclusive: `curated_rule`, `curated_rule_set`, `rule`, `deleted_curated_rule_set`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] curated_rule_set
  #   @return [::String]
  #     Full resource name for the curated rule set this activity corresponds
  #     to. This field will only be set if the customer has access to the
  #     curated rule set the exclusion is applied to.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/instances/\\{instance}/curatedRuleSetCategories/\\{curated_rule_set_category}/curatedRuleSets/\\{curated_rule_set}
  #
  #     Note: The following fields are mutually exclusive: `curated_rule_set`, `curated_rule`, `rule`, `deleted_curated_rule_set`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] rule
  #   @return [::String]
  #     Full resource name for the rule this activity corresponds to.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/instances/\\{instance}/rules/\\{rule}
  #
  #     Note: The following fields are mutually exclusive: `rule`, `curated_rule`, `curated_rule_set`, `deleted_curated_rule_set`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] deleted_curated_rule_set
  #   @return [::String]
  #     Full resource name for the deleted curated rule set this activity
  #     corresponds to. This field will only be set if the customer does
  #     not have access to the curated rule set the exclusion is applied to.
  #     Format:
  #     projects/\\{project}/locations/\\{location}/instances/\\{instance}/curatedRuleSetCategories/\\{curated_rule_set_category}/curatedRuleSets/\\{curated_rule_set}
  #
  #     Note: The following fields are mutually exclusive: `deleted_curated_rule_set`, `curated_rule`, `curated_rule_set`, `rule`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] excluded_detection_count
  #   @return [::Integer]
  #     The number of detections for the detector that were excluded by the
  #     detection exclusion.
  # @!attribute [rw] total_detection_count
  #   @return [::Integer]
  #     The total number of detections found by the detector. This includes both
  #     excluded detections and non-excluded detections.
  class DetectionExclusionDetectorActivity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end