Class: Google::Cloud::Chronicle::V1::EntityService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/entity_service/client.rb

Overview

Client for the EntityService service.

EntityService contains apis for finding entities.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path, #watchlist_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new EntityService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::EntityService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the EntityService client.

Yield Parameters:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 140

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/entity_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @entity_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::EntityService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @entity_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the EntityService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all EntityService clients
::Google::Cloud::Chronicle::V1::EntityService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_watchlist.timeout = 90.0
    default_config.rpcs.get_watchlist.retry_policy = {
      initial_delay: 1.0, max_delay: 90.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_watchlists.timeout = 90.0
    default_config.rpcs.list_watchlists.retry_policy = {
      initial_delay: 1.0, max_delay: 90.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_watchlist.timeout = 90.0

    default_config.rpcs.update_watchlist.timeout = 90.0

    default_config.rpcs.delete_watchlist.timeout = 90.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the EntityService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



110
111
112
113
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 110

def configure
  yield @config if block_given?
  @config
end

#create_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist #create_watchlist(parent: nil, watchlist_id: nil, watchlist: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

Creates a watchlist for the given instance. Note that there can be at most 200 watchlists per instance.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateWatchlistRequest.new

# Call the create_watchlist method.
result = client.create_watchlist request

# The returned object is of type Google::Cloud::Chronicle::V1::Watchlist.
p result

Overloads:

  • #create_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to create_watchlist via a request object, either of type CreateWatchlistRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateWatchlistRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_watchlist(parent: nil, watchlist_id: nil, watchlist: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to create_watchlist via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this watchlist will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • watchlist_id (::String) (defaults to: nil)

      Optional. The ID to use for the watchlist, which will become the final component of the watchlist's resource name.

      This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/.

    • watchlist (::Google::Cloud::Chronicle::V1::Watchlist, ::Hash) (defaults to: nil)

      Required. The watchlist to create.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 454

def create_watchlist request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateWatchlistRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_watchlist..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_watchlist.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_watchlist.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @entity_service_stub.call_rpc :create_watchlist, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_watchlist(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_watchlist(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

Deletes the watchlist for the given instance.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteWatchlistRequest.new

# Call the delete_watchlist method.
result = client.delete_watchlist request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_watchlist(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_watchlist via a request object, either of type DeleteWatchlistRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteWatchlistRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_watchlist(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_watchlist via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the watchlist to delete. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}

    • force (::Boolean) (defaults to: nil)

      Optional. If set to true, any entities under this watchlist will also be deleted. (Otherwise, the request will only work if the watchlist has no entities.)

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 636

def delete_watchlist request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteWatchlistRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_watchlist..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_watchlist.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_watchlist.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @entity_service_stub.call_rpc :delete_watchlist, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist #get_watchlist(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

Gets watchlist details for the given watchlist ID.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetWatchlistRequest.new

# Call the get_watchlist method.
result = client.get_watchlist request

# The returned object is of type Google::Cloud::Chronicle::V1::Watchlist.
p result

Overloads:

  • #get_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to get_watchlist via a request object, either of type GetWatchlistRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetWatchlistRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_watchlist(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to get_watchlist via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The parent, which owns this collection of watchlists. The name of the watchlist to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 249

def get_watchlist request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetWatchlistRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_watchlist..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_watchlist.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_watchlist.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @entity_service_stub.call_rpc :get_watchlist, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_watchlists(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::Watchlist> #list_watchlists(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::Watchlist>

Lists all watchlists for the given instance.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListWatchlistsRequest.new

# Call the list_watchlists method.
result = client.list_watchlists request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::Watchlist.
  p item
end

Overloads:

  • #list_watchlists(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::Watchlist>

    Pass arguments to list_watchlists via a request object, either of type ListWatchlistsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListWatchlistsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_watchlists(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::Watchlist>

    Pass arguments to list_watchlists via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of watchlists. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of watchlists to return. The service may return fewer than this value. If unspecified, at most 200 watchlists will be returned. The maximum value is 200; values above 200 will be coerced to 200.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListWatchlists call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListWatchlists must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      Optional. Which watchlist to return in aip.dev/160 form. Currently, only the following filters are supported:

      • watchlist_user_preferences.pinned=true
      • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE])
      • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE],[NAMESPACE])

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 357

def list_watchlists request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListWatchlistsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_watchlists..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_watchlists.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_watchlists.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @entity_service_stub.call_rpc :list_watchlists, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @entity_service_stub, :list_watchlists, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


196
197
198
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 196

def logger
  @entity_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


120
121
122
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 120

def universe_domain
  @entity_service_stub.universe_domain
end

#update_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist #update_watchlist(watchlist: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

Updates the watchlist for the given instance.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::EntityService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateWatchlistRequest.new

# Call the update_watchlist method.
result = client.update_watchlist request

# The returned object is of type Google::Cloud::Chronicle::V1::Watchlist.
p result

Overloads:

  • #update_watchlist(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to update_watchlist via a request object, either of type UpdateWatchlistRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateWatchlistRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_watchlist(watchlist: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::Watchlist

    Pass arguments to update_watchlist via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • watchlist (::Google::Cloud::Chronicle::V1::Watchlist, ::Hash) (defaults to: nil)

      Required. The watchlist to update.

      The watchlist's name field is used to identify the watchlist to update. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. The list of fields to update.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/google/cloud/chronicle/v1/entity_service/client.rb', line 545

def update_watchlist request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateWatchlistRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_watchlist..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.watchlist&.name
    header_params["watchlist.name"] = request.watchlist.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_watchlist.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_watchlist.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @entity_service_stub.call_rpc :update_watchlist, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end