Class: Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

LINT.IfChange(stats_data) Value of the column based on data type.

Defined Under Namespace

Classes: ValueMetadata

Instance Attribute Summary collapse

Instance Attribute Details

#bool_val::Boolean

Returns Boolean value.

Note: The following fields are mutually exclusive: bool_val, null_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Boolean value.

    Note: The following fields are mutually exclusive: bool_val, null_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#bytes_val::String

Returns Bytes value.

Note: The following fields are mutually exclusive: bytes_val, null_val, bool_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Bytes value.

    Note: The following fields are mutually exclusive: bytes_val, null_val, bool_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#date_val::Google::Type::Date

Returns Date values.

Note: The following fields are mutually exclusive: date_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Type::Date)

    Date values.

    Note: The following fields are mutually exclusive: date_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#double_val::Float

Returns Double value.

Note: The following fields are mutually exclusive: double_val, null_val, bool_val, bytes_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    Double value.

    Note: The following fields are mutually exclusive: double_val, null_val, bool_val, bytes_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#int64_val::Integer

Returns Integer value (signed).

Note: The following fields are mutually exclusive: int64_val, null_val, bool_val, bytes_val, double_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Integer value (signed).

    Note: The following fields are mutually exclusive: int64_val, null_val, bool_val, bytes_val, double_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#metadata::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#null_val::Boolean

Returns True if the value is NULL.

Note: The following fields are mutually exclusive: null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    True if the value is NULL.

    Note: The following fields are mutually exclusive: null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#proto_val::Google::Protobuf::Any

Returns For any proto values that are not any of the above.

Note: The following fields are mutually exclusive: proto_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Any)

    For any proto values that are not any of the above.

    Note: The following fields are mutually exclusive: proto_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, timestamp_val, date_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#string_val::String

Returns String value. Enum values are returned as strings.

Note: The following fields are mutually exclusive: string_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    String value. Enum values are returned as strings.

    Note: The following fields are mutually exclusive: string_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#timestamp_val::Google::Protobuf::Timestamp

Returns Timestamp values. Does not handle interval.

Note: The following fields are mutually exclusive: timestamp_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    Timestamp values. Does not handle interval.

    Note: The following fields are mutually exclusive: timestamp_val, null_val, bool_val, bytes_val, double_val, int64_val, uint64_val, string_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uint64_val::Integer

Returns Un-signed integer value.

Note: The following fields are mutually exclusive: uint64_val, null_val, bool_val, bytes_val, double_val, int64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Un-signed integer value.

    Note: The following fields are mutually exclusive: uint64_val, null_val, bool_val, bytes_val, double_val, int64_val, string_val, timestamp_val, date_val, proto_val. If a field in that set is populated, all other fields in the set will automatically be cleared.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 258

class ColumnValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] links
  #   @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>]
  #     "Auto" generated In-app links.
  # @!attribute [rw] field_paths
  #   @return [::Array<::String>]
  # @!attribute [rw] timestamp_val
  #   @return [::Google::Protobuf::Timestamp]
  #     Timestamp value to store the timestamp for the case of the date and
  #     time data type.
  class ValueMetadata
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end