Class: Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_query.rb
Instance Attribute Summary collapse
- #field_paths ⇒ ::Array<::String>
-
#links ⇒ ::Array<::Google::Cloud::Chronicle::V1::InAppLink>
"Auto" generated In-app links.
-
#timestamp_val ⇒ ::Google::Protobuf::Timestamp
Timestamp value to store the timestamp for the case of the date and time data type.
Instance Attribute Details
#field_paths ⇒ ::Array<::String>
271 272 273 274 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 271 class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#links ⇒ ::Array<::Google::Cloud::Chronicle::V1::InAppLink>
Returns "Auto" generated In-app links.
271 272 273 274 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 271 class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timestamp_val ⇒ ::Google::Protobuf::Timestamp
Returns Timestamp value to store the timestamp for the case of the date and time data type.
271 272 273 274 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 271 class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |