Class: Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Request message to export list of dashboard.

Instance Attribute Summary collapse

Instance Attribute Details

#names::Array<::String>

Returns Required. The resource names of the dashboards to export.

Returns:

  • (::Array<::String>)

    Required. The resource names of the dashboards to export.



32
33
34
35
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 32

class ExportNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource that the dashboards to be exported belong to. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource that the dashboards to be exported belong to. Format: projects/{project}/locations/{location}/instances/{instance}



32
33
34
35
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 32

class ExportNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end