Class: Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/native_dashboard.rb
Overview
Response message for exporting a dashboard.
Instance Attribute Summary collapse
-
#inline_destination ⇒ ::Google::Cloud::Chronicle::V1::InlineDestination
The data for the exported dashboards included directly in the response.
Instance Attribute Details
#inline_destination ⇒ ::Google::Cloud::Chronicle::V1::InlineDestination
Returns The data for the exported dashboards included directly in the response.
41 42 43 44 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 41 class ExportNativeDashboardsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |