Class: Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboardService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboardService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb
Overview
REST client for the FeaturedContentNativeDashboardService service.
This service provides functionality for managing FeaturedContentNativeDashboard.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the FeaturedContentNativeDashboardService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the FeaturedContentNativeDashboardService Client instance.
-
#get_featured_content_native_dashboard(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard
Get a native dashboard featured content.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new FeaturedContentNativeDashboardService REST client object.
-
#install_featured_content_native_dashboard(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::InstallFeaturedContentNativeDashboardResponse
Install a native dashboard featured content.
-
#list_featured_content_native_dashboards(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard>
List all native dashboards featured content.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#content_hub_path, #dashboard_chart_path, #dashboard_query_path, #featured_content_native_dashboard_path, #native_dashboard_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new FeaturedContentNativeDashboardService REST client object.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 137 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @featured_content_native_dashboard_service_stub = ::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboardService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @featured_content_native_dashboard_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the FeaturedContentNativeDashboardService Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_featured_content_native_dashboard.timeout = 60.0 default_config.rpcs.get_featured_content_native_dashboard.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_featured_content_native_dashboards.timeout = 60.0 default_config.rpcs.list_featured_content_native_dashboards.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the FeaturedContentNativeDashboardService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
107 108 109 110 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 107 def configure yield @config if block_given? @config end |
#get_featured_content_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard #get_featured_content_native_dashboard(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard
Get a native dashboard featured content.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 235 def get_featured_content_native_dashboard request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFeaturedContentNativeDashboardRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_featured_content_native_dashboard..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_featured_content_native_dashboard.timeout, metadata: , retry_policy: @config.rpcs.get_featured_content_native_dashboard.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @featured_content_native_dashboard_service_stub.get_featured_content_native_dashboard request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#install_featured_content_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::InstallFeaturedContentNativeDashboardResponse #install_featured_content_native_dashboard(name: nil, featured_content_native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::InstallFeaturedContentNativeDashboardResponse
Install a native dashboard featured content.
437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 437 def install_featured_content_native_dashboard request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::InstallFeaturedContentNativeDashboardRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.install_featured_content_native_dashboard..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.install_featured_content_native_dashboard.timeout, metadata: , retry_policy: @config.rpcs.install_featured_content_native_dashboard.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @featured_content_native_dashboard_service_stub.install_featured_content_native_dashboard request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_featured_content_native_dashboards(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard> #list_featured_content_native_dashboards(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard>
List all native dashboards featured content.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 353 def list_featured_content_native_dashboards request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_featured_content_native_dashboards..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_featured_content_native_dashboards.timeout, metadata: , retry_policy: @config.rpcs.list_featured_content_native_dashboards.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @featured_content_native_dashboard_service_stub.list_featured_content_native_dashboards request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @featured_content_native_dashboard_service_stub, :list_featured_content_native_dashboards, "featured_content_native_dashboards", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
184 185 186 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 184 def logger @featured_content_native_dashboard_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
117 118 119 |
# File 'lib/google/cloud/chronicle/v1/featured_content_native_dashboard_service/rest/client.rb', line 117 def universe_domain @featured_content_native_dashboard_service_stub.universe_domain end |