Class: Google::Cloud::Chronicle::V1::FindingsRefinementActivity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

The activity for a specific findings refinement.

Instance Attribute Summary collapse

Instance Attribute Details

#detection_exclusion_activity::Google::Cloud::Chronicle::V1::DetectionExclusionActivity

Returns The activity for the detection exclusion.

Returns:



127
128
129
130
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 127

class FindingsRefinementActivity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#findings_refinement::String

Returns Required. Full resource name for the findings refinement this activity corresponds to. Format: projects/{project}/locations/{region}/instances/{instance}/findingsRefinements/{findings_refinement}.

Returns:

  • (::String)

    Required. Full resource name for the findings refinement this activity corresponds to. Format: projects/{project}/locations/{region}/instances/{instance}/findingsRefinements/{findings_refinement}



127
128
129
130
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 127

class FindingsRefinementActivity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end