Class: Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

The FindingsRefinementDeployment resource represents the deployment state of a findings refinement.

Instance Attribute Summary collapse

Instance Attribute Details

#archived::Boolean

Returns The archive state of the findings refinement deployment. Cannot be set to true unless enabled is set to false. If currently set to true, enabled cannot be updated to true.

Returns:

  • (::Boolean)

    The archive state of the findings refinement deployment. Cannot be set to true unless enabled is set to false. If currently set to true, enabled cannot be updated to true.



85
86
87
88
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 85

class FindingsRefinementDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#detection_exclusion_application::Google::Cloud::Chronicle::V1::DetectionExclusionApplication

Returns The resources which the detection exclusion is applied to.

Returns:



85
86
87
88
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 85

class FindingsRefinementDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enabled::Boolean

Returns Whether the findings refinement is currently deployed continuously against incoming findings.

Returns:

  • (::Boolean)

    Whether the findings refinement is currently deployed continuously against incoming findings.



85
86
87
88
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 85

class FindingsRefinementDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The resource name of the findings refinement deployment. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment.

Returns:

  • (::String)

    Required. The resource name of the findings refinement deployment. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment



85
86
87
88
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 85

class FindingsRefinementDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the findings refinement deployment was last updated.

Returns:



85
86
87
88
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 85

class FindingsRefinementDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end