Module: Google::Cloud::Chronicle::V1::FindingsRefinementService

Defined in:
lib/google/cloud/chronicle/v1/findings_refinement_service.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/rest.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/paths.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/credentials.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb,
lib/google/cloud/chronicle/v1/findings_refinement_service/rest/service_stub.rb

Overview

FindingsRefinementService provides an interface for filtering out findings that are unlikely to be real threats to prevent them from triggering alerts or notifications.

To load this service and instantiate a REST client:

require "google/cloud/chronicle/v1/findings_refinement_service/rest"
client = ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Rest::Client.new

Defined Under Namespace

Modules: Paths, Rest Classes: Client, Credentials