Class: Google::Cloud::Chronicle::V1::FindingsRefinementService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb

Overview

Client for the FindingsRefinementService service.

FindingsRefinementService provides an interface for filtering out findings that are unlikely to be real threats to prevent them from triggering alerts or notifications.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#curated_rule_path, #curated_rule_set_path, #findings_refinement_deployment_path, #findings_refinement_path, #instance_path, #rule_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new FindingsRefinementService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the FindingsRefinementService client.

Yield Parameters:



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 168

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/findings_refinement_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @findings_refinement_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @findings_refinement_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the FindingsRefinementService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all FindingsRefinementService clients
::Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_findings_refinement.timeout = 60.0
    default_config.rpcs.get_findings_refinement.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_findings_refinements.timeout = 60.0
    default_config.rpcs.list_findings_refinements.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_findings_refinement.timeout = 60.0
    default_config.rpcs.create_findings_refinement.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_findings_refinement.timeout = 60.0
    default_config.rpcs.update_findings_refinement.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_findings_refinement_deployment.timeout = 120.0
    default_config.rpcs.get_findings_refinement_deployment.retry_policy = {
      initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_findings_refinement_deployment.timeout = 120.0

    default_config.rpcs.list_all_findings_refinement_deployments.timeout = 120.0
    default_config.rpcs.list_all_findings_refinement_deployments.retry_policy = {
      initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.compute_findings_refinement_activity.timeout = 600.0
    default_config.rpcs.compute_findings_refinement_activity.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.compute_all_findings_refinement_activities.timeout = 600.0
    default_config.rpcs.compute_all_findings_refinement_activities.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#compute_all_findings_refinement_activities(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse #compute_all_findings_refinement_activities(instance: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse

Returns findings refinement activity for all findings refinements.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesRequest.new

# Call the compute_all_findings_refinement_activities method.
result = client.compute_all_findings_refinement_activities request

# The returned object is of type Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 1029

def compute_all_findings_refinement_activities request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.compute_all_findings_refinement_activities..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.instance
    header_params["instance"] = request.instance
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.compute_all_findings_refinement_activities.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.compute_all_findings_refinement_activities.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :compute_all_findings_refinement_activities, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#compute_findings_refinement_activity(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse #compute_findings_refinement_activity(name: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse

Returns findings refinement activity for a specific findings refinement.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest.new

# Call the compute_findings_refinement_activity method.
result = client.compute_findings_refinement_activity request

# The returned object is of type Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse.
p result

Overloads:

  • #compute_findings_refinement_activity(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse

    Pass arguments to compute_findings_refinement_activity via a request object, either of type ComputeFindingsRefinementActivityRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #compute_findings_refinement_activity(name: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse

    Pass arguments to compute_findings_refinement_activity via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Full resource name for the findings refinement to fetch the activity for. Format: projects/{project}/locations/{region}/instances/{instance}/findingsRefinements/{findings_refinement}

    • interval (::Google::Type::Interval, ::Hash) (defaults to: nil)

      The time interval the activity is measured over.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 940

def compute_findings_refinement_activity request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.compute_findings_refinement_activity..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.compute_findings_refinement_activity.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.compute_findings_refinement_activity.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :compute_findings_refinement_activity, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the FindingsRefinementService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



138
139
140
141
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 138

def configure
  yield @config if block_given?
  @config
end

#create_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #create_findings_refinement(parent: nil, findings_refinement: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

Creates a new findings refinement.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest.new

# Call the create_findings_refinement method.
result = client.create_findings_refinement request

# The returned object is of type Google::Cloud::Chronicle::V1::FindingsRefinement.
p result

Overloads:

  • #create_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to create_findings_refinement via a request object, either of type CreateFindingsRefinementRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_findings_refinement(parent: nil, findings_refinement: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to create_findings_refinement via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this findings refinement will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • findings_refinement (::Google::Cloud::Chronicle::V1::FindingsRefinement, ::Hash) (defaults to: nil)

      Required. The findings refinement to create.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 466

def create_findings_refinement request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_findings_refinement..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_findings_refinement.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_findings_refinement.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :create_findings_refinement, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #get_findings_refinement(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

Gets a single findings refinement.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetFindingsRefinementRequest.new

# Call the get_findings_refinement method.
result = client.get_findings_refinement request

# The returned object is of type Google::Cloud::Chronicle::V1::FindingsRefinement.
p result

Overloads:

  • #get_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to get_findings_refinement via a request object, either of type GetFindingsRefinementRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetFindingsRefinementRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_findings_refinement(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to get_findings_refinement via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the findings refinement to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 276

def get_findings_refinement request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_findings_refinement..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_findings_refinement.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_findings_refinement.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :get_findings_refinement, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #get_findings_refinement_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

Gets a findings refinement deployment.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetFindingsRefinementDeploymentRequest.new

# Call the get_findings_refinement_deployment method.
result = client.get_findings_refinement_deployment request

# The returned object is of type Google::Cloud::Chronicle::V1::FindingsRefinementDeployment.
p result

Overloads:

  • #get_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

    Pass arguments to get_findings_refinement_deployment via a request object, either of type GetFindingsRefinementDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetFindingsRefinementDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_findings_refinement_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

    Pass arguments to get_findings_refinement_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the findings refinement to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 646

def get_findings_refinement_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_findings_refinement_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_findings_refinement_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_findings_refinement_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :get_findings_refinement_deployment, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_all_findings_refinement_deployments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment> #list_all_findings_refinement_deployments(instance: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>

Lists all findings refinement deployments.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest.new

# Call the list_all_findings_refinement_deployments method.
result = client.list_all_findings_refinement_deployments request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment.
  p item
end

Overloads:

  • #list_all_findings_refinement_deployments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>

    Pass arguments to list_all_findings_refinement_deployments via a request object, either of type ListAllFindingsRefinementDeploymentsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_all_findings_refinement_deployments(instance: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>

    Pass arguments to list_all_findings_refinement_deployments via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • instance (::String) (defaults to: nil)

      Required. The name of the parent resource, which is the SecOps instance to list all findings refinement deployments over. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of findings refinement deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListAllFindingsRefinementDeployments call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListAllFindingsRefinementDeployments must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      A filter that can be used to retrieve specific findings refinement deployments. Only the following filters are allowed: detection_exclusion_application.curated_rule_sets:""", detection_exclusion_application.curated_rules:""

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 849

def list_all_findings_refinement_deployments request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_all_findings_refinement_deployments..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.instance
    header_params["instance"] = request.instance
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_all_findings_refinement_deployments.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_all_findings_refinement_deployments.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :list_all_findings_refinement_deployments, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @findings_refinement_service_stub, :list_all_findings_refinement_deployments, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_findings_refinements(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement> #list_findings_refinements(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>

Lists a collection of findings refinements.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest.new

# Call the list_findings_refinements method.
result = client.list_findings_refinements request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::FindingsRefinement.
  p item
end

Overloads:

  • #list_findings_refinements(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>

    Pass arguments to list_findings_refinements via a request object, either of type ListFindingsRefinementsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_findings_refinements(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>

    Pass arguments to list_findings_refinements via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of findings refinements. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of findings refinements to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListFindingsRefinements call. Provide this to retrieve the subsequent page.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 375

def list_findings_refinements request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_findings_refinements..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_findings_refinements.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_findings_refinements.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :list_findings_refinements, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @findings_refinement_service_stub, :list_findings_refinements, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


224
225
226
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 224

def logger
  @findings_refinement_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


148
149
150
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 148

def universe_domain
  @findings_refinement_service_stub.universe_domain
end

#update_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #update_findings_refinement(findings_refinement: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

Updates a findings refinement.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest.new

# Call the update_findings_refinement method.
result = client.update_findings_refinement request

# The returned object is of type Google::Cloud::Chronicle::V1::FindingsRefinement.
p result

Overloads:

  • #update_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to update_findings_refinement via a request object, either of type UpdateFindingsRefinementRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_findings_refinement(findings_refinement: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement

    Pass arguments to update_findings_refinement via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • findings_refinement (::Google::Cloud::Chronicle::V1::FindingsRefinement, ::Hash) (defaults to: nil)

      Required. The findings refinement to update.

      The findings refinement's name field is used to identify the findings refinement to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Optional. The list of fields to update. If * is provided, all fields will be updated.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 559

def update_findings_refinement request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_findings_refinement..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.findings_refinement&.name
    header_params["findings_refinement.name"] = request.findings_refinement.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_findings_refinement.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_findings_refinement.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :update_findings_refinement, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #update_findings_refinement_deployment(findings_refinement_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

Updates a findings refinement deployment.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::FindingsRefinementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest.new

# Call the update_findings_refinement_deployment method.
result = client.update_findings_refinement_deployment request

# The returned object is of type Google::Cloud::Chronicle::V1::FindingsRefinementDeployment.
p result

Overloads:

  • #update_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

    Pass arguments to update_findings_refinement_deployment via a request object, either of type UpdateFindingsRefinementDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_findings_refinement_deployment(findings_refinement_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

    Pass arguments to update_findings_refinement_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • findings_refinement_deployment (::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment, ::Hash) (defaults to: nil)

      Required. The findings refinement deployment to update.

      The findings refinement deployment's name field is used to identify the findings refinement deployment to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The list of fields to update. If * is provided, all fields will be updated.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 739

def update_findings_refinement_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_findings_refinement_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.findings_refinement_deployment&.name
    header_params["findings_refinement_deployment.name"] = request.findings_refinement_deployment.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_findings_refinement_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_findings_refinement_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @findings_refinement_service_stub.call_rpc :update_findings_refinement_deployment, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end