Class: Google::Cloud::Chronicle::V1::GetRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::GetRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Request message for GetRule method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::Chronicle::V1::RuleView
The view field indicates the scope of fields to populate for the Rule being returned.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the rule to retrieve.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.
281 282 283 284 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 281 class GetRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::Chronicle::V1::RuleView
The view field indicates the scope of fields to populate for the Rule being returned. If unspecified, defaults to FULL.
281 282 283 284 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 281 class GetRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |