Class: Google::Cloud::Chronicle::V1::ImportExportStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

ImportExportStatus is a wrapper for dashboard name and status.

Instance Attribute Summary collapse

Instance Attribute Details

#dashboard::String

Returns The resource name of the dashboard if it was supplied in the request.

Returns:

  • (::String)

    The resource name of the dashboard if it was supplied in the request.



114
115
116
117
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 114

class ImportExportStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#status::Google::Rpc::Status (readonly)

Returns Output only. Status of the import/export operation.

Returns:



114
115
116
117
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 114

class ImportExportStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end