Class: Google::Cloud::Chronicle::V1::ImportNativeDashboardsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Request message to import dashboards.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}



78
79
80
81
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 78

class ImportNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source::Google::Cloud::Chronicle::V1::ImportNativeDashboardsInlineSource

Returns Required. The data will imported from this proto.

Returns:



78
79
80
81
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 78

class ImportNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end