Class: Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Response message for importing dashboards.

Instance Attribute Summary collapse

Instance Attribute Details

#results::Array<::Google::Cloud::Chronicle::V1::ImportExportStatus> (readonly)

Returns Output only. Represents the status of an import operation for multiple dashboards. Each dashboard's import status is tracked. A status of OK indicates the dashboard was ready for import. Otherwise, an appropriate error code and message are provided. Importantly, the import process is all-or-nothing: if even one dashboard fails to import, the entire import operation is aborted, and none of the dashboards are imported. The order of the statuses will be the same as in the import request.

Returns:

  • (::Array<::Google::Cloud::Chronicle::V1::ImportExportStatus>)

    Output only. Represents the status of an import operation for multiple dashboards. Each dashboard's import status is tracked. A status of OK indicates the dashboard was ready for import. Otherwise, an appropriate error code and message are provided. Importantly, the import process is all-or-nothing: if even one dashboard fails to import, the entire import operation is aborted, and none of the dashboards are imported. The order of the statuses will be the same as in the import request.



102
103
104
105
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 102

class ImportNativeDashboardsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end