Module: Google::Cloud::Chronicle::V1::LanguageFeature

Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

A language feature describes a specific capability or syntax of the query language used in a dashboard query, such as JOINS, STAGES, or DATA_TABLES.

Constant Summary collapse

LANGUAGE_FEATURE_UNSPECIFIED =

Language feature is unknown.

0
JOINS =

Language feature is joins.

1
STAGES =

Language feature is stages.

2
DATA_TABLES =

Language feature is data table.

3