Class: Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Request message for ListAllFindingsRefinementDeployments method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A filter that can be used to retrieve specific findings refinement deployments. Only the following filters are allowed: detection_exclusion_application.curated_rule_sets:""", detection_exclusion_application.curated_rules:"".

Returns:

  • (::String)

    A filter that can be used to retrieve specific findings refinement deployments. Only the following filters are allowed: detection_exclusion_application.curated_rule_sets:""", detection_exclusion_application.curated_rules:""



323
324
325
326
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323

class ListAllFindingsRefinementDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Required. The name of the parent resource, which is the SecOps instance to list all findings refinement deployments over. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The name of the parent resource, which is the SecOps instance to list all findings refinement deployments over. Format: projects/{project}/locations/{location}/instances/{instance}



323
324
325
326
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323

class ListAllFindingsRefinementDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of findings refinement deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of findings refinement deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



323
324
325
326
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323

class ListAllFindingsRefinementDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListAllFindingsRefinementDeployments call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListAllFindingsRefinementDeployments must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListAllFindingsRefinementDeployments call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListAllFindingsRefinementDeployments must match the call that provided the page token.



323
324
325
326
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323

class ListAllFindingsRefinementDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end