Class: Google::Cloud::Chronicle::V1::ListDataTableRowsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

Request to list data table rows.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter facilitating search over data table rows. This filter performs a case-insensitive substring match on the row values.

Returns:

  • (::String)

    Optional. Filter facilitating search over data table rows. This filter performs a case-insensitive substring match on the row values.



181
182
183
184
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 181

class ListDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Configures ordering of DataTables in the response. Note: Our implementation currently supports order by "create_time asc" only.

Returns:

  • (::String)

    Optional. Configures ordering of DataTables in the response. Note: Our implementation currently supports order by "create_time asc" only



181
182
183
184
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 181

class ListDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of data table rows to return. The service may return fewer than this value. If unspecified, at most 100 data table rows will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of data table rows to return. The service may return fewer than this value. If unspecified, at most 100 data table rows will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



181
182
183
184
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 181

class ListDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDataTableRows call.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDataTableRows call.



181
182
183
184
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 181

class ListDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource id of the data table. Format: projects/{project}/locations/{locations}/instances/{instance}/dataTables/{data_table}.

Returns:

  • (::String)

    Required. The resource id of the data table. Format: projects/{project}/locations/{locations}/instances/{instance}/dataTables/{data_table}



181
182
183
184
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 181

class ListDataTableRowsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end