Class: Google::Cloud::Chronicle::V1::ListDataTableRowsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataTableRowsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_table.rb
Overview
Response message for listing data table rows.
Instance Attribute Summary collapse
-
#data_table_rows ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataTableRow>
The list of the data table rows returned.
-
#next_page_token ⇒ ::String
Optional.
Instance Attribute Details
#data_table_rows ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataTableRow>
Returns The list of the data table rows returned.
194 195 196 197 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 194 class ListDataTableRowsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns Optional. A token, which can be sent as page_token to retrieve the next
page. If this field is omitted, there are no subsequent pages.
194 195 196 197 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 194 class ListDataTableRowsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |