Class: Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb

Overview

Response message for listing FeaturedContentNativeDashboards.

Instance Attribute Summary collapse

Instance Attribute Details

Returns The list of FeaturedContentNativeDashboards. Ordered by name by default.

Returns:



109
110
111
112
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 109

class ListFeaturedContentNativeDashboardsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



109
110
111
112
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 109

class ListFeaturedContentNativeDashboardsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end