Class: Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Request message for ListFindingsRefinements method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

The maximum number of findings refinements to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of findings refinements to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



216
217
218
219
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 216

class ListFindingsRefinementsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListFindingsRefinements call. Provide this to retrieve the subsequent page.

Returns:

  • (::String)

    A page token, received from a previous ListFindingsRefinements call. Provide this to retrieve the subsequent page.



216
217
218
219
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 216

class ListFindingsRefinementsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of findings refinements. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of findings refinements. Format: projects/{project}/locations/{location}/instances/{instance}



216
217
218
219
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 216

class ListFindingsRefinementsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end