Class: Google::Cloud::Chronicle::V1::ListFindingsRefinementsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Response message for ListFindingsRefinements method.

Instance Attribute Summary collapse

Instance Attribute Details

#findings_refinements::Array<::Google::Cloud::Chronicle::V1::FindingsRefinement>

Returns List of findings refinements.

Returns:



229
230
231
232
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 229

class ListFindingsRefinementsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



229
230
231
232
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 229

class ListFindingsRefinementsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end