Class: Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Request message to list dashboards.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Optional. The maximum number of dashboards to return. The service may return fewer than this value.

Returns:

  • (::Integer)

    Optional. The maximum number of dashboards to return. The service may return fewer than this value.



212
213
214
215
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 212

class ListNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListDashboards call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListDashboards must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListDashboards call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListDashboards must match the call that provided the page token.



212
213
214
215
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 212

class ListNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent owning this dashboard collection. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent owning this dashboard collection. Format: projects/{project}/locations/{location}/instances/{instance}



212
213
214
215
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 212

class ListNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#view::Google::Cloud::Chronicle::V1::NativeDashboardView

Returns Optional. View indicates the scope of fields to populate when returning the dashboard resource. If unspecified, defaults to the basic view.

Returns:



212
213
214
215
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 212

class ListNativeDashboardsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end