Class: Google::Cloud::Chronicle::V1::ListNativeDashboardsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Response message for listing dashboards.

Instance Attribute Summary collapse

Instance Attribute Details

#native_dashboards::Array<::Google::Cloud::Chronicle::V1::NativeDashboard>

Returns The dashboards from the specified chronicle instance.

Returns:



225
226
227
228
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 225

class ListNativeDashboardsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



225
226
227
228
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 225

class ListNativeDashboardsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end