Class: Google::Cloud::Chronicle::V1::ListRetrohuntsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Response message for ListRetrohunts method.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



472
473
474
475
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 472

class ListRetrohuntsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#retrohunts::Array<::Google::Cloud::Chronicle::V1::Retrohunt>

Returns The retrohunts from the specified rule.

Returns:



472
473
474
475
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 472

class ListRetrohuntsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end