Class: Google::Cloud::Chronicle::V1::ListRuleDeploymentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Request message for ListRuleDeployments.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A filter that can be used to retrieve specific rule deployments. The following fields are filterable: archived, name.

Returns:

  • (::String)

    A filter that can be used to retrieve specific rule deployments. The following fields are filterable: archived, name



513
514
515
516
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 513

class ListRuleDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

The maximum number of rule deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of rule deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



513
514
515
516
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 513

class ListRuleDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListRuleDeployments call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListRuleDeployments must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListRuleDeployments call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListRuleDeployments must match the call that provided the page token.



513
514
515
516
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 513

class ListRuleDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The collection of all parents which own all rule deployments. The "-" wildcard token must be used as the rule identifier in the resource path. Format: projects/{project}/locations/{location}/instances/{instance}/rules/-.

Returns:

  • (::String)

    Required. The collection of all parents which own all rule deployments. The "-" wildcard token must be used as the rule identifier in the resource path. Format: projects/{project}/locations/{location}/instances/{instance}/rules/-



513
514
515
516
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 513

class ListRuleDeploymentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end