Class: Google::Cloud::Chronicle::V1::ListRuleDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListRuleDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Response message for ListRuleDeployments.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#rule_deployments ⇒ ::Array<::Google::Cloud::Chronicle::V1::RuleDeployment>
The rule deployments from all rules.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
526 527 528 529 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 526 class ListRuleDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rule_deployments ⇒ ::Array<::Google::Cloud::Chronicle::V1::RuleDeployment>
Returns The rule deployments from all rules.
526 527 528 529 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 526 class ListRuleDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |