Class: Google::Cloud::Chronicle::V1::ListRuleExecutionErrorsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb

Overview

Request message for ListRuleExecutionErrors.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A filter that can be used to retrieve specific rule execution errors. Only the following filters are allowed:

  rule = "\\{Rule.name}"
  curated_rule = "\\{CuratedRule.name}"

The value for rule or curated_rule must be a valid rule resource name or a valid curated rule resource name specified in quotes.

For 'rule', an optional 'revision_id' can be specified which can be used to fetch errors for a given revision of the rule. A '-' is also allowed to fetch errors across all revisions of the rule. If unspecified, only errors corresponding to the most recent revision of the rule will be returned. So these variations are all allowed:

  rule = "\\{Rule.name}"
  rule = "\\{Rule.name}@\\{Rule.revision_id}"
  rule = "\\{Rule.name}@-"

Revision IDs are not supported for curated rules.

Returns:

  • (::String)

    A filter that can be used to retrieve specific rule execution errors. Only the following filters are allowed:

      rule = "\\{Rule.name}"
      curated_rule = "\\{CuratedRule.name}"
    

    The value for rule or curated_rule must be a valid rule resource name or a valid curated rule resource name specified in quotes.

    For 'rule', an optional 'revision_id' can be specified which can be used to fetch errors for a given revision of the rule. A '-' is also allowed to fetch errors across all revisions of the rule. If unspecified, only errors corresponding to the most recent revision of the rule will be returned. So these variations are all allowed:

      rule = "\\{Rule.name}"
      rule = "\\{Rule.name}@\\{Rule.revision_id}"
      rule = "\\{Rule.name}@-"
    

    Revision IDs are not supported for curated rules.



65
66
67
68
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 65

class ListRuleExecutionErrorsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

The maximum number of rule execution errors to return. The service may return fewer than this value. If unspecified, at most 1000 rule execution errors will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

Returns:

  • (::Integer)

    The maximum number of rule execution errors to return. The service may return fewer than this value. If unspecified, at most 1000 rule execution errors will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.



65
66
67
68
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 65

class ListRuleExecutionErrorsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListRuleExecutionErrors call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListRuleExecutionErrors must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListRuleExecutionErrors call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListRuleExecutionErrors must match the call that provided the page token.



65
66
67
68
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 65

class ListRuleExecutionErrorsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The instance to list rule execution errors from. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The instance to list rule execution errors from. Format: projects/{project}/locations/{location}/instances/{instance}



65
66
67
68
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 65

class ListRuleExecutionErrorsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end