Class: Google::Cloud::Chronicle::V1::ListRuleExecutionErrorsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb

Overview

Response message for ListRuleExecutionErrors.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



78
79
80
81
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 78

class ListRuleExecutionErrorsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_execution_errors::Array<::Google::Cloud::Chronicle::V1::RuleExecutionError>

Returns List of rule execution errors.

Returns:



78
79
80
81
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 78

class ListRuleExecutionErrorsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end