Class: Google::Cloud::Chronicle::V1::ListRulesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Request message for ListRules method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Only the following filters are allowed: "reference_lists:{reference_list_name}" "data_tables:{data_table_name}" "display_name:{display_name}".

Returns:

  • (::String)

    Only the following filters are allowed: "reference_lists:{reference_list_name}" "data_tables:{data_table_name}" "display_name:{display_name}"



314
315
316
317
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 314

class ListRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of rules to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of rules to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



314
315
316
317
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 314

class ListRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListRules call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListRules must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListRules call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListRules must match the call that provided the page token.



314
315
316
317
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 314

class ListRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of rules. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of rules. Format: projects/{project}/locations/{location}/instances/{instance}



314
315
316
317
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 314

class ListRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#view::Google::Cloud::Chronicle::V1::RuleView

Returns view indicates the scope of fields to populate for the Rule being returned. If unspecified, defaults to BASIC.

Returns:



314
315
316
317
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 314

class ListRulesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end