Class: Google::Cloud::Chronicle::V1::ListRulesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Response message for ListRules method.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



327
328
329
330
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 327

class ListRulesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rules::Array<::Google::Cloud::Chronicle::V1::Rule>

Returns The rules from the specified instance.

Returns:



327
328
329
330
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 327

class ListRulesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end