Class: Google::Cloud::Chronicle::V1::ListWatchlistsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/entity.rb

Overview

Request message for listing watchlists.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Which watchlist to return in aip.dev/160 form. Currently, only the following filters are supported:

  • watchlist_user_preferences.pinned=true
  • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE])
  • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE],[NAMESPACE]).

Returns:

  • (::String)

    Optional. Which watchlist to return in aip.dev/160 form. Currently, only the following filters are supported:

    • watchlist_user_preferences.pinned=true
    • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE])
    • has_entity([ENTITY_INDICATOR],[ENTITY_TYPE],[NAMESPACE])


138
139
140
141
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 138

class ListWatchlistsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of watchlists to return. The service may return fewer than this value. If unspecified, at most 200 watchlists will be returned. The maximum value is 200; values above 200 will be coerced to 200.

Returns:

  • (::Integer)

    Optional. The maximum number of watchlists to return. The service may return fewer than this value. If unspecified, at most 200 watchlists will be returned. The maximum value is 200; values above 200 will be coerced to 200.



138
139
140
141
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 138

class ListWatchlistsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListWatchlists call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListWatchlists must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListWatchlists call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListWatchlists must match the call that provided the page token.



138
139
140
141
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 138

class ListWatchlistsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of watchlists. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The parent, which owns this collection of watchlists. Format: projects/{project}/locations/{location}/instances/{instance}



138
139
140
141
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 138

class ListWatchlistsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end