Class: Google::Cloud::Chronicle::V1::ListWatchlistsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/entity.rb

Overview

Response message for listing watchlists.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns Optional. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    Optional. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



151
152
153
154
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 151

class ListWatchlistsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#watchlists::Array<::Google::Cloud::Chronicle::V1::Watchlist>

Returns Optional. The watchlists from the specified instance.

Returns:



151
152
153
154
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 151

class ListWatchlistsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end