Class: Google::Cloud::Chronicle::V1::NativeDashboard
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::NativeDashboard
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/native_dashboard.rb
Overview
NativeDashboard resource.
Instance Attribute Summary collapse
-
#access ⇒ ::Google::Cloud::Chronicle::V1::DashboardAccess
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#create_user_id ⇒ ::String
readonly
Output only.
-
#dashboard_user_data ⇒ ::Google::Cloud::Chronicle::V1::DashboardUserData
readonly
Output only.
-
#definition ⇒ ::Google::Cloud::Chronicle::V1::DashboardDefinition
Optional.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#etag ⇒ ::String
Optional.
-
#name ⇒ ::String
readonly
Output only.
-
#type ⇒ ::Google::Cloud::Chronicle::V1::DashboardType
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#update_user_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#access ⇒ ::Google::Cloud::Chronicle::V1::DashboardAccess (readonly)
Returns Output only. Access of the dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Creation time of dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_user_id ⇒ ::String (readonly)
Returns Output only. User who created the dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dashboard_user_data ⇒ ::Google::Cloud::Chronicle::V1::DashboardUserData (readonly)
Returns Output only. User Preferences for a dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#definition ⇒ ::Google::Cloud::Chronicle::V1::DashboardDefinition
Returns Optional. Definition of the dashboard like metadata, visualization and datasource configuration etc.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. Description of the dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. Dashboard display name/title visible to users.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#etag ⇒ ::String
Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. Name of the dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::Google::Cloud::Chronicle::V1::DashboardType (readonly)
Returns Output only. Whether it's an out of the box or custom created dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time the dashboard was last edited.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_user_id ⇒ ::String (readonly)
Returns Output only. User who last edited the dashboard.
159 160 161 162 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 159 class NativeDashboard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |