Class: Google::Cloud::Chronicle::V1::NativeDashboardService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb

Overview

Client for the NativeDashboardService service.

A service providing functionality for managing native dashboards.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#dashboard_chart_path, #dashboard_query_path, #instance_path, #native_dashboard_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new NativeDashboardService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the NativeDashboardService client.

Yield Parameters:



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 157

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/native_dashboard_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @native_dashboard_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::NativeDashboardService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @native_dashboard_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the NativeDashboardService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all NativeDashboardService clients
::Google::Cloud::Chronicle::V1::NativeDashboardService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_native_dashboard.timeout = 60.0

    default_config.rpcs.get_native_dashboard.timeout = 60.0
    default_config.rpcs.get_native_dashboard.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_native_dashboards.timeout = 60.0
    default_config.rpcs.list_native_dashboards.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_native_dashboard.timeout = 60.0

    default_config.rpcs.duplicate_native_dashboard.timeout = 60.0

    default_config.rpcs.delete_native_dashboard.timeout = 60.0

    default_config.rpcs.add_chart.timeout = 60.0

    default_config.rpcs.remove_chart.timeout = 60.0

    default_config.rpcs.edit_chart.timeout = 60.0

    default_config.rpcs.duplicate_chart.timeout = 60.0

    default_config.rpcs.export_native_dashboards.timeout = 60.0
    default_config.rpcs.export_native_dashboards.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.import_native_dashboards.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#add_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::AddChartResponse #add_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, chart_layout: nil) ⇒ ::Google::Cloud::Chronicle::V1::AddChartResponse

Add chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::AddChartRequest.new

# Call the add_chart method.
result = client.add_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::AddChartResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 830

def add_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::AddChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.add_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.add_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.add_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :add_chart, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the NativeDashboardService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



127
128
129
130
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 127

def configure
  yield @config if block_given?
  @config
end

#create_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #create_native_dashboard(parent: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Create a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest.new

# Call the create_native_dashboard method.
result = client.create_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #create_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to create_native_dashboard via a request object, either of type CreateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_native_dashboard(parent: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to create_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. The dashboard to create.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 266

def create_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :create_native_dashboard, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_native_dashboard(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_native_dashboard(name: nil) ⇒ ::Google::Protobuf::Empty

Delete a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest.new

# Call the delete_native_dashboard method.
result = client.delete_native_dashboard request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_native_dashboard(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_native_dashboard via a request object, either of type DeleteNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_native_dashboard(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to delete. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 737

def delete_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :delete_native_dashboard, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#duplicate_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse #duplicate_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

Duplicate chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DuplicateChartRequest.new

# Call the duplicate_chart method.
result = client.duplicate_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::DuplicateChartResponse.
p result

Overloads:

  • #duplicate_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

    Pass arguments to duplicate_chart via a request object, either of type DuplicateChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DuplicateChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #duplicate_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

    Pass arguments to duplicate_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name that involves chart duplication. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_chart (::String) (defaults to: nil)

      Required. The dashboard chart name to duplicate.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 1114

def duplicate_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DuplicateChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.duplicate_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.duplicate_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.duplicate_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :duplicate_chart, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#duplicate_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #duplicate_native_dashboard(name: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Duplicate a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest.new

# Call the duplicate_native_dashboard method.
result = client.duplicate_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #duplicate_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to duplicate_native_dashboard via a request object, either of type DuplicateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #duplicate_native_dashboard(name: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to duplicate_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to duplicate. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. Any fields that need modification can be passed through this like name, description etc.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 650

def duplicate_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.duplicate_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.duplicate_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.duplicate_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :duplicate_native_dashboard, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#edit_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse #edit_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, edit_mask: nil, language_features: nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

Edit chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::EditChartRequest.new

# Call the edit_chart method.
result = client.edit_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::EditChartResponse.
p result

Overloads:

  • #edit_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

    Pass arguments to edit_chart via a request object, either of type EditChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::EditChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #edit_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, edit_mask: nil, language_features: nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

    Pass arguments to edit_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to edit chart in. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_query (::Google::Cloud::Chronicle::V1::DashboardQuery, ::Hash) (defaults to: nil)

      Optional. Query for the edited chart.

    • dashboard_chart (::Google::Cloud::Chronicle::V1::DashboardChart, ::Hash) (defaults to: nil)

      Optional. Edited chart.

    • edit_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The list of fields to edit for chart and query. Supported paths in chart are - dashboard_chart.display_name dashboard_chart.description dashboard_chart.chart_datasource.data_sources dashboard_chart.visualization dashboard_chart.visualization.button dashboard_chart.visualization.markdown dashboard_chart.drill_down_config Supported paths in query are - dashboard_query.query dashboard_query.input

    • language_features (::Array<::Google::Cloud::Chronicle::V1::LanguageFeature>) (defaults to: nil)

      Optional. Language Features present in the query.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 1025

def edit_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::EditChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.edit_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.edit_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.edit_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :edit_chart, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#export_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse #export_native_dashboards(parent: nil, names: nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

Exports the dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest.new

# Call the export_native_dashboards method.
result = client.export_native_dashboards request

# The returned object is of type Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse.
p result

Overloads:

  • #export_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

    Pass arguments to export_native_dashboards via a request object, either of type ExportNativeDashboardsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #export_native_dashboards(parent: nil, names: nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

    Pass arguments to export_native_dashboards via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource that the dashboards to be exported belong to. Format: projects/{project}/locations/{location}/instances/{instance}

    • names (::Array<::String>) (defaults to: nil)

      Required. The resource names of the dashboards to export.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 1202

def export_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.export_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :export_native_dashboards, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #get_native_dashboard(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Get a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetNativeDashboardRequest.new

# Call the get_native_dashboard method.
result = client.get_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #get_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to get_native_dashboard via a request object, either of type GetNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_native_dashboard(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to get_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to fetch. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • view (::Google::Cloud::Chronicle::V1::NativeDashboardView) (defaults to: nil)

      Optional. View indicates the scope of fields to populate when returning the dashboard resource. If unspecified, defaults to the basic view.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 356

def get_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :get_native_dashboard, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#import_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse #import_native_dashboards(parent: nil, source: nil) ⇒ ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse

Imports the dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ImportNativeDashboardsRequest.new

# Call the import_native_dashboards method.
result = client.import_native_dashboards request

# The returned object is of type Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 1290

def import_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.import_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.import_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.import_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :import_native_dashboards, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_native_dashboards(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard> #list_native_dashboards(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

List all dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest.new

# Call the list_native_dashboards method.
result = client.list_native_dashboards request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::NativeDashboard.
  p item
end

Overloads:

  • #list_native_dashboards(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

    Pass arguments to list_native_dashboards via a request object, either of type ListNativeDashboardsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_native_dashboards(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

    Pass arguments to list_native_dashboards via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent owning this dashboard collection. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of dashboards to return. The service may return fewer than this value.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListDashboards call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListDashboards must match the call that provided the page token.

    • view (::Google::Cloud::Chronicle::V1::NativeDashboardView) (defaults to: nil)

      Optional. View indicates the scope of fields to populate when returning the dashboard resource. If unspecified, defaults to the basic view.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 458

def list_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :list_native_dashboards, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @native_dashboard_service_stub, :list_native_dashboards, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


213
214
215
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 213

def logger
  @native_dashboard_service_stub.logger
end

#remove_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #remove_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Remove chart from a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::RemoveChartRequest.new

# Call the remove_chart method.
result = client.remove_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #remove_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to remove_chart via a request object, either of type RemoveChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::RemoveChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #remove_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to remove_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to remove chart from. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_chart (::String) (defaults to: nil)

      Required. The dashboard chart name to remove.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 919

def remove_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::RemoveChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.remove_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.remove_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.remove_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :remove_chart, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


137
138
139
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 137

def universe_domain
  @native_dashboard_service_stub.universe_domain
end

#update_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #update_native_dashboard(native_dashboard: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Update a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest.new

# Call the update_native_dashboard method.
result = client.update_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #update_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to update_native_dashboard via a request object, either of type UpdateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_native_dashboard(native_dashboard: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to update_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. The dashboard to update.

      The dashboard's name field is used to identify the dashboard to update. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. LINT.IfChange(update_mask_values) The list of fields to update. Supported paths are - display_name description definition.filters definition.charts type access dashboard_user_data.is_pinned

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/client.rb', line 560

def update_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.native_dashboard&.name
    header_params["native_dashboard.name"] = request.native_dashboard.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.call_rpc :update_native_dashboard, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end