Class: Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb

Overview

REST client for the NativeDashboardService service.

A service providing functionality for managing native dashboards.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#dashboard_chart_path, #dashboard_query_path, #instance_path, #native_dashboard_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new NativeDashboardService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the NativeDashboardService client.

Yield Parameters:



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 159

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @native_dashboard_service_stub = ::Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @native_dashboard_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the NativeDashboardService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all NativeDashboardService clients
::Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_native_dashboard.timeout = 60.0

    default_config.rpcs.get_native_dashboard.timeout = 60.0
    default_config.rpcs.get_native_dashboard.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_native_dashboards.timeout = 60.0
    default_config.rpcs.list_native_dashboards.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_native_dashboard.timeout = 60.0

    default_config.rpcs.duplicate_native_dashboard.timeout = 60.0

    default_config.rpcs.delete_native_dashboard.timeout = 60.0

    default_config.rpcs.add_chart.timeout = 60.0

    default_config.rpcs.remove_chart.timeout = 60.0

    default_config.rpcs.edit_chart.timeout = 60.0

    default_config.rpcs.duplicate_chart.timeout = 60.0

    default_config.rpcs.export_native_dashboards.timeout = 60.0
    default_config.rpcs.export_native_dashboards.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.import_native_dashboards.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#add_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::AddChartResponse #add_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, chart_layout: nil) ⇒ ::Google::Cloud::Chronicle::V1::AddChartResponse

Add chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::AddChartRequest.new

# Call the add_chart method.
result = client.add_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::AddChartResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 780

def add_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::AddChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.add_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.add_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.add_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.add_chart request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#configure {|config| ... } ⇒ Client::Configuration

Configure the NativeDashboardService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



129
130
131
132
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 129

def configure
  yield @config if block_given?
  @config
end

#create_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #create_native_dashboard(parent: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Create a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest.new

# Call the create_native_dashboard method.
result = client.create_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #create_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to create_native_dashboard via a request object, either of type CreateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_native_dashboard(parent: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to create_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this dashboard will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. The dashboard to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 258

def create_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.create_native_dashboard request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_native_dashboard(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_native_dashboard(name: nil) ⇒ ::Google::Protobuf::Empty

Delete a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest.new

# Call the delete_native_dashboard method.
result = client.delete_native_dashboard request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_native_dashboard(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_native_dashboard via a request object, either of type DeleteNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_native_dashboard(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to delete. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 694

def delete_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.delete_native_dashboard request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#duplicate_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse #duplicate_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

Duplicate chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DuplicateChartRequest.new

# Call the duplicate_chart method.
result = client.duplicate_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::DuplicateChartResponse.
p result

Overloads:

  • #duplicate_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

    Pass arguments to duplicate_chart via a request object, either of type DuplicateChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DuplicateChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #duplicate_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::DuplicateChartResponse

    Pass arguments to duplicate_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name that involves chart duplication. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_chart (::String) (defaults to: nil)

      Required. The dashboard chart name to duplicate.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 1043

def duplicate_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DuplicateChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.duplicate_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.duplicate_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.duplicate_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.duplicate_chart request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#duplicate_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #duplicate_native_dashboard(name: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Duplicate a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest.new

# Call the duplicate_native_dashboard method.
result = client.duplicate_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #duplicate_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to duplicate_native_dashboard via a request object, either of type DuplicateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #duplicate_native_dashboard(name: nil, native_dashboard: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to duplicate_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to duplicate. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. Any fields that need modification can be passed through this like name, description etc.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 614

def duplicate_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DuplicateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.duplicate_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.duplicate_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.duplicate_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.duplicate_native_dashboard request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#edit_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse #edit_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, edit_mask: nil, language_features: nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

Edit chart in a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::EditChartRequest.new

# Call the edit_chart method.
result = client.edit_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::EditChartResponse.
p result

Overloads:

  • #edit_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

    Pass arguments to edit_chart via a request object, either of type EditChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::EditChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #edit_chart(name: nil, dashboard_query: nil, dashboard_chart: nil, edit_mask: nil, language_features: nil) ⇒ ::Google::Cloud::Chronicle::V1::EditChartResponse

    Pass arguments to edit_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to edit chart in. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_query (::Google::Cloud::Chronicle::V1::DashboardQuery, ::Hash) (defaults to: nil)

      Optional. Query for the edited chart.

    • dashboard_chart (::Google::Cloud::Chronicle::V1::DashboardChart, ::Hash) (defaults to: nil)

      Optional. Edited chart.

    • edit_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The list of fields to edit for chart and query. Supported paths in chart are - dashboard_chart.display_name dashboard_chart.description dashboard_chart.chart_datasource.data_sources dashboard_chart.visualization dashboard_chart.visualization.button dashboard_chart.visualization.markdown dashboard_chart.drill_down_config Supported paths in query are - dashboard_query.query dashboard_query.input

    • language_features (::Array<::Google::Cloud::Chronicle::V1::LanguageFeature>) (defaults to: nil)

      Optional. Language Features present in the query.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 961

def edit_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::EditChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.edit_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.edit_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.edit_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.edit_chart request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#export_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse #export_native_dashboards(parent: nil, names: nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

Exports the dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest.new

# Call the export_native_dashboards method.
result = client.export_native_dashboards request

# The returned object is of type Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse.
p result

Overloads:

  • #export_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

    Pass arguments to export_native_dashboards via a request object, either of type ExportNativeDashboardsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #export_native_dashboards(parent: nil, names: nil) ⇒ ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsResponse

    Pass arguments to export_native_dashboards via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource that the dashboards to be exported belong to. Format: projects/{project}/locations/{location}/instances/{instance}

    • names (::Array<::String>) (defaults to: nil)

      Required. The resource names of the dashboards to export.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 1124

def export_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ExportNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.export_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.export_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.export_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.export_native_dashboards request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #get_native_dashboard(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Get a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetNativeDashboardRequest.new

# Call the get_native_dashboard method.
result = client.get_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #get_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to get_native_dashboard via a request object, either of type GetNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_native_dashboard(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to get_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to fetch. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • view (::Google::Cloud::Chronicle::V1::NativeDashboardView) (defaults to: nil)

      Optional. View indicates the scope of fields to populate when returning the dashboard resource. If unspecified, defaults to the basic view.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 341

def get_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.get_native_dashboard request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#import_native_dashboards(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse #import_native_dashboards(parent: nil, source: nil) ⇒ ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse

Imports the dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ImportNativeDashboardsRequest.new

# Call the import_native_dashboards method.
result = client.import_native_dashboards request

# The returned object is of type Google::Cloud::Chronicle::V1::ImportNativeDashboardsResponse.
p result

Overloads:

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 1205

def import_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ImportNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.import_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.import_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.import_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.import_native_dashboards request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_native_dashboards(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard> #list_native_dashboards(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

List all dashboards.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest.new

# Call the list_native_dashboards method.
result = client.list_native_dashboards request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::NativeDashboard.
  p item
end

Overloads:

  • #list_native_dashboards(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

    Pass arguments to list_native_dashboards via a request object, either of type ListNativeDashboardsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_native_dashboards(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::NativeDashboard>

    Pass arguments to list_native_dashboards via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent owning this dashboard collection. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of dashboards to return. The service may return fewer than this value.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListDashboards call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListDashboards must match the call that provided the page token.

    • view (::Google::Cloud::Chronicle::V1::NativeDashboardView) (defaults to: nil)

      Optional. View indicates the scope of fields to populate when returning the dashboard resource. If unspecified, defaults to the basic view.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 436

def list_native_dashboards request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListNativeDashboardsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_native_dashboards..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_native_dashboards.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_native_dashboards.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.list_native_dashboards request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @native_dashboard_service_stub, :list_native_dashboards, "native_dashboards", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


206
207
208
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 206

def logger
  @native_dashboard_service_stub.logger
end

#remove_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #remove_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Remove chart from a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::RemoveChartRequest.new

# Call the remove_chart method.
result = client.remove_chart request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #remove_chart(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to remove_chart via a request object, either of type RemoveChartRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::RemoveChartRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #remove_chart(name: nil, dashboard_chart: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to remove_chart via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The dashboard name to remove chart from. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • dashboard_chart (::String) (defaults to: nil)

      Required. The dashboard chart name to remove.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 862

def remove_chart request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::RemoveChartRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.remove_chart..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.remove_chart.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.remove_chart.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.remove_chart request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


139
140
141
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 139

def universe_domain
  @native_dashboard_service_stub.universe_domain
end

#update_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard #update_native_dashboard(native_dashboard: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

Update a dashboard.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::NativeDashboardService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest.new

# Call the update_native_dashboard method.
result = client.update_native_dashboard request

# The returned object is of type Google::Cloud::Chronicle::V1::NativeDashboard.
p result

Overloads:

  • #update_native_dashboard(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to update_native_dashboard via a request object, either of type UpdateNativeDashboardRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_native_dashboard(native_dashboard: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::NativeDashboard

    Pass arguments to update_native_dashboard via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • native_dashboard (::Google::Cloud::Chronicle::V1::NativeDashboard, ::Hash) (defaults to: nil)

      Required. The dashboard to update.

      The dashboard's name field is used to identify the dashboard to update. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. LINT.IfChange(update_mask_values) The list of fields to update. Supported paths are - display_name description definition.filters definition.charts type access dashboard_user_data.is_pinned

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
# File 'lib/google/cloud/chronicle/v1/native_dashboard_service/rest/client.rb', line 531

def update_native_dashboard request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_native_dashboard..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_native_dashboard.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_native_dashboard.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @native_dashboard_service_stub.update_native_dashboard request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end