Class: Google::Cloud::Chronicle::V1::OutcomeFilter

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Outcome filter for the findings refinement. This is used to filter the findings refinement based on the outcome variable values.

Defined Under Namespace

Modules: Operator

Instance Attribute Summary collapse

Instance Attribute Details

#outcome_filter_operator::Google::Cloud::Chronicle::V1::OutcomeFilter::Operator

Returns Required. The operator to be applied to the outcome variable.

Returns:



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 352

class OutcomeFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operator to compare the outcome variable value with the outcome value
  # in the outcome filter.
  module Operator
    # The operator is unspecified.
    OPERATOR_UNSPECIFIED = 0

    # The outcome variable value must be equal to the outcome value in the
    # outcome filter.
    EQUAL = 1

    # The outcome variable value must contain the outcome value in the
    # outcome filter.
    CONTAINS = 2

    # The outcome variable value must match the outcome value regex in the
    # outcome filter.
    MATCHES_REGEX = 3

    # The outcome variable value must be a valid IP address in the outcome
    # filter value CIDR range.
    MATCHES_CIDR = 4
  end
end

#outcome_value::String

Returns Required. The value of the outcome variable to match.

Returns:

  • (::String)

    Required. The value of the outcome variable to match.



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 352

class OutcomeFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operator to compare the outcome variable value with the outcome value
  # in the outcome filter.
  module Operator
    # The operator is unspecified.
    OPERATOR_UNSPECIFIED = 0

    # The outcome variable value must be equal to the outcome value in the
    # outcome filter.
    EQUAL = 1

    # The outcome variable value must contain the outcome value in the
    # outcome filter.
    CONTAINS = 2

    # The outcome variable value must match the outcome value regex in the
    # outcome filter.
    MATCHES_REGEX = 3

    # The outcome variable value must be a valid IP address in the outcome
    # filter value CIDR range.
    MATCHES_CIDR = 4
  end
end

#outcome_variable::String

Returns Required. The outcome variable name.

Returns:

  • (::String)

    Required. The outcome variable name.



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 352

class OutcomeFilter
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The operator to compare the outcome variable value with the outcome value
  # in the outcome filter.
  module Operator
    # The operator is unspecified.
    OPERATOR_UNSPECIFIED = 0

    # The outcome variable value must be equal to the outcome value in the
    # outcome filter.
    EQUAL = 1

    # The outcome variable value must contain the outcome value in the
    # outcome filter.
    CONTAINS = 2

    # The outcome variable value must match the outcome value regex in the
    # outcome filter.
    MATCHES_REGEX = 3

    # The outcome variable value must be a valid IP address in the outcome
    # filter value CIDR range.
    MATCHES_CIDR = 4
  end
end