Class: Google::Cloud::Chronicle::V1::ReferenceList

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

A reference list. Reference lists are user-defined lists of values which users can use in multiple Rules.

Instance Attribute Summary collapse

Instance Attribute Details

#description::String

Returns Required. A user-provided description of the reference list.

Returns:

  • (::String)

    Required. A user-provided description of the reference list.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String (readonly)

Returns Output only. The unique display name of the reference list.

Returns:

  • (::String)

    Output only. The unique display name of the reference list.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#entries::Array<::Google::Cloud::Chronicle::V1::ReferenceListEntry>

Returns Required. The entries of the reference list. When listed, they are returned in the order that was specified at creation or update. The combined size of the values of the reference list may not exceed 6MB. This is returned only when the view is REFERENCE_LIST_VIEW_FULL.

Returns:

  • (::Array<::Google::Cloud::Chronicle::V1::ReferenceListEntry>)

    Required. The entries of the reference list. When listed, they are returned in the order that was specified at creation or update. The combined size of the values of the reference list may not exceed 6MB. This is returned only when the view is REFERENCE_LIST_VIEW_FULL.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the reference list. Format: projects/{project}/locations/{location}/instances/{instance}/referenceLists/{reference_list}.

Returns:

  • (::String)

    Identifier. The resource name of the reference list. Format: projects/{project}/locations/{location}/instances/{instance}/referenceLists/{reference_list}



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#revision_create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the reference list was last updated.

Returns:



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_associations_count::Integer (readonly)

Returns Output only. The count of self-authored rules using the reference list.

Returns:

  • (::Integer)

    Output only. The count of self-authored rules using the reference list.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rules::Array<::String> (readonly)

Returns Output only. The resource names for the associated self-authored Rules that use this reference list. This is returned only when the view is REFERENCE_LIST_VIEW_FULL.

Returns:

  • (::Array<::String>)

    Output only. The resource names for the associated self-authored Rules that use this reference list. This is returned only when the view is REFERENCE_LIST_VIEW_FULL.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_info::Google::Cloud::Chronicle::V1::ScopeInfo

Returns The scope info of the reference list. During reference list creation, if this field is not set, the reference list without scopes (an unscoped list) will be created for an unscoped user. For a scoped user, this field must be set. During reference list update, if scope_info is requested to be updated, this field must be set.

Returns:

  • (::Google::Cloud::Chronicle::V1::ScopeInfo)

    The scope info of the reference list. During reference list creation, if this field is not set, the reference list without scopes (an unscoped list) will be created for an unscoped user. For a scoped user, this field must be set. During reference list update, if scope_info is requested to be updated, this field must be set.



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#syntax_type::Google::Cloud::Chronicle::V1::ReferenceListSyntaxType

Returns Required. The syntax type indicating how list entries should be validated.

Returns:



183
184
185
186
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 183

class ReferenceList
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end