Class: Google::Cloud::Chronicle::V1::ReferenceListScope

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

ReferenceListScope specifies the list of scope names of the reference list.

Instance Attribute Summary collapse

Instance Attribute Details

#scope_names::Array<::String>

Returns Optional. The list of scope names of the reference list. The scope names should be full resource names and should be of the format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}.

Returns:

  • (::Array<::String>)

    Optional. The list of scope names of the reference list. The scope names should be full resource names and should be of the format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{scope_name}.



40
41
42
43
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 40

class ReferenceListScope
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end