Class: Google::Cloud::Chronicle::V1::ReferenceListService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/reference_list_service/client.rb

Overview

Client for the ReferenceListService service.

ReferenceListService provides an interface for managing reference lists.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path, #reference_list_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new ReferenceListService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::ReferenceListService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::ReferenceListService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the ReferenceListService client.

Yield Parameters:



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 138

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/reference_list_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @reference_list_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::ReferenceListService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @reference_list_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the ReferenceListService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all ReferenceListService clients
::Google::Cloud::Chronicle::V1::ReferenceListService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_reference_list.timeout = 60.0
    default_config.rpcs.get_reference_list.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_reference_lists.timeout = 60.0
    default_config.rpcs.list_reference_lists.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_reference_list.timeout = 60.0

    default_config.rpcs.update_reference_list.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the ReferenceListService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



108
109
110
111
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 108

def configure
  yield @config if block_given?
  @config
end

#create_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList #create_reference_list(parent: nil, reference_list: nil, reference_list_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

Creates a new reference list.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::ReferenceListService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateReferenceListRequest.new

# Call the create_reference_list method.
result = client.create_reference_list request

# The returned object is of type Google::Cloud::Chronicle::V1::ReferenceList.
p result

Overloads:

  • #create_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to create_reference_list via a request object, either of type CreateReferenceListRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateReferenceListRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_reference_list(parent: nil, reference_list: nil, reference_list_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to create_reference_list via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this reference list will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • reference_list (::Google::Cloud::Chronicle::V1::ReferenceList, ::Hash) (defaults to: nil)

      Required. The reference list to create.

    • reference_list_id (::String) (defaults to: nil)

      Required. The ID to use for the reference list. This is also the display name for the reference list. It must satisfy the following requirements:

      • Starts with letter.
      • Contains only letters, numbers and underscore.
      • Has length less than 256.
      • Must be unique.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 450

def create_reference_list request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateReferenceListRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_reference_list..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_reference_list.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_reference_list.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @reference_list_service_stub.call_rpc :create_reference_list, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList #get_reference_list(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

Gets a single reference list.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::ReferenceListService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetReferenceListRequest.new

# Call the get_reference_list method.
result = client.get_reference_list request

# The returned object is of type Google::Cloud::Chronicle::V1::ReferenceList.
p result

Overloads:

  • #get_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to get_reference_list via a request object, either of type GetReferenceListRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetReferenceListRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_reference_list(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to get_reference_list via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the reference list to retrieve. Format: projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}

    • view (::Google::Cloud::Chronicle::V1::ReferenceListView) (defaults to: nil)

      How much of the ReferenceList to view. Defaults to REFERENCE_LIST_VIEW_FULL.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 249

def get_reference_list request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetReferenceListRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_reference_list..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_reference_list.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_reference_list.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @reference_list_service_stub.call_rpc :get_reference_list, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_reference_lists(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::ReferenceList> #list_reference_lists(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::ReferenceList>

Lists a collection of reference lists.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::ReferenceListService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListReferenceListsRequest.new

# Call the list_reference_lists method.
result = client.list_reference_lists request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::ReferenceList.
  p item
end

Overloads:

  • #list_reference_lists(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::ReferenceList>

    Pass arguments to list_reference_lists via a request object, either of type ListReferenceListsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListReferenceListsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_reference_lists(parent: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::ReferenceList>

    Pass arguments to list_reference_lists via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of reference lists. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of reference lists to return. The service may return fewer than this value. If unspecified, at most 100 reference lists will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListReferenceLists call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListReferenceLists must match the call that provided the page token.

    • view (::Google::Cloud::Chronicle::V1::ReferenceListView) (defaults to: nil)

      How much of each ReferenceList to view. Defaults to REFERENCE_LIST_VIEW_BASIC.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 353

def list_reference_lists request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListReferenceListsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_reference_lists..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_reference_lists.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_reference_lists.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @reference_list_service_stub.call_rpc :list_reference_lists, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @reference_list_service_stub, :list_reference_lists, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


194
195
196
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 194

def logger
  @reference_list_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


118
119
120
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 118

def universe_domain
  @reference_list_service_stub.universe_domain
end

#update_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList #update_reference_list(reference_list: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

Updates an existing reference list.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::ReferenceListService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateReferenceListRequest.new

# Call the update_reference_list method.
result = client.update_reference_list request

# The returned object is of type Google::Cloud::Chronicle::V1::ReferenceList.
p result

Overloads:

  • #update_reference_list(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to update_reference_list via a request object, either of type UpdateReferenceListRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateReferenceListRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_reference_list(reference_list: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::ReferenceList

    Pass arguments to update_reference_list via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • reference_list (::Google::Cloud::Chronicle::V1::ReferenceList, ::Hash) (defaults to: nil)

      Required. The reference list to update.

      The reference list's name field is used to identify the reference list to update. Format: projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      The list of fields to update. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/google/cloud/chronicle/v1/reference_list_service/client.rb', line 544

def update_reference_list request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateReferenceListRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_reference_list..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.reference_list&.name
    header_params["reference_list.name"] = request.reference_list.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_reference_list.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_reference_list.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @reference_list_service_stub.call_rpc :update_reference_list, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end