Module: Google::Cloud::Chronicle::V1::ReferenceListView

Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

ReferenceListView is a mechanism for viewing partial responses of the ReferenceList resource.

Constant Summary collapse

REFERENCE_LIST_VIEW_UNSPECIFIED =

The default / unset value. The API will default to the BASIC view for ListReferenceLists. The API will default to the FULL view for methods that return a single ReferenceList resource.

0
REFERENCE_LIST_VIEW_BASIC =

Include metadata about the ReferenceList. This is the default view for ListReferenceLists.

1
REFERENCE_LIST_VIEW_FULL =

Include all details about the ReferenceList: metadata, content lines, associated rule counts. This is the default view for GetReferenceList.

2