Class: Google::Cloud::Chronicle::V1::Retrohunt

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Retrohunt is an execution of a Rule over a time range in the past.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#execution_interval::Google::Type::Interval (readonly)

Returns Output only. The start and end time of the retrohunt execution. If the retrohunt is not yet finished, the end time of the interval will not be populated.

Returns:

  • (::Google::Type::Interval)

    Output only. The start and end time of the retrohunt execution. If the retrohunt is not yet finished, the end time of the interval will not be populated.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 235

class Retrohunt
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible states a retrohunt can be in.
  module State
    # Unspecified or unknown retrohunt state.
    STATE_UNSPECIFIED = 0

    # Running state.
    RUNNING = 1

    # Done state.
    DONE = 2

    # Cancelled state.
    CANCELLED = 3

    # Failed state.
    FAILED = 4
  end
end

#name::String

Returns The resource name of the retrohunt. Retrohunt is the child of a rule revision. {rule} in the format below is structured as {rule_id@revision_id}. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/retrohunts/{retrohunt}.

Returns:

  • (::String)

    The resource name of the retrohunt. Retrohunt is the child of a rule revision. {rule} in the format below is structured as {rule_id@revision_id}. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/retrohunts/{retrohunt}



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 235

class Retrohunt
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible states a retrohunt can be in.
  module State
    # Unspecified or unknown retrohunt state.
    STATE_UNSPECIFIED = 0

    # Running state.
    RUNNING = 1

    # Done state.
    DONE = 2

    # Cancelled state.
    CANCELLED = 3

    # Failed state.
    FAILED = 4
  end
end

#process_interval::Google::Type::Interval

Returns Required. The start and end time of the event time range this retrohunt processes.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 235

class Retrohunt
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible states a retrohunt can be in.
  module State
    # Unspecified or unknown retrohunt state.
    STATE_UNSPECIFIED = 0

    # Running state.
    RUNNING = 1

    # Done state.
    DONE = 2

    # Cancelled state.
    CANCELLED = 3

    # Failed state.
    FAILED = 4
  end
end

#progress_percentage::Float (readonly)

Returns Output only. Percent progress of the retrohunt towards completion, from 0.00 to 100.00.

Returns:

  • (::Float)

    Output only. Percent progress of the retrohunt towards completion, from 0.00 to 100.00.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 235

class Retrohunt
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible states a retrohunt can be in.
  module State
    # Unspecified or unknown retrohunt state.
    STATE_UNSPECIFIED = 0

    # Running state.
    RUNNING = 1

    # Done state.
    DONE = 2

    # Cancelled state.
    CANCELLED = 3

    # Failed state.
    FAILED = 4
  end
end

#state::Google::Cloud::Chronicle::V1::Retrohunt::State (readonly)

Returns Output only. The state of the retrohunt.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 235

class Retrohunt
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible states a retrohunt can be in.
  module State
    # Unspecified or unknown retrohunt state.
    STATE_UNSPECIFIED = 0

    # Running state.
    RUNNING = 1

    # Done state.
    DONE = 2

    # Cancelled state.
    CANCELLED = 3

    # Failed state.
    FAILED = 4
  end
end