Class: Google::Cloud::Chronicle::V1::RuleDeployment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

The RuleDeployment resource represents the deployment state of a Rule.

Defined Under Namespace

Modules: ExecutionState

Instance Attribute Summary collapse

Instance Attribute Details

#alerting::Boolean

Returns Whether detections resulting from this deployment should be considered alerts.

Returns:

  • (::Boolean)

    Whether detections resulting from this deployment should be considered alerts.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#archive_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the rule deployment archive state was last set to true. If the rule deployment's current archive state is not set to true, the field will be empty.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The timestamp when the rule deployment archive state was last set to true. If the rule deployment's current archive state is not set to true, the field will be empty.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#archived::Boolean

Returns The archive state of the rule deployment. Cannot be set to true unless enabled is set to false. If set to true, alerting will automatically be set to false. If currently set to true, enabled, alerting, and run_frequency cannot be updated.

Returns:

  • (::Boolean)

    The archive state of the rule deployment. Cannot be set to true unless enabled is set to false. If set to true, alerting will automatically be set to false. If currently set to true, enabled, alerting, and run_frequency cannot be updated.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#consumer_rules::Array<::String> (readonly)

Returns Output only. The names of the associated/chained consumer rules. Rules are considered consumers of this rule if their rule text explicitly filters on this rule's ruleid. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.

Returns:

  • (::Array<::String>)

    Output only. The names of the associated/chained consumer rules. Rules are considered consumers of this rule if their rule text explicitly filters on this rule's ruleid. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#enabled::Boolean

Returns Whether the rule is currently deployed continuously against incoming data.

Returns:

  • (::Boolean)

    Whether the rule is currently deployed continuously against incoming data.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#execution_state::Google::Cloud::Chronicle::V1::RuleDeployment::ExecutionState (readonly)

Returns Output only. The execution state of the rule deployment.

Returns:



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#last_alert_status_change_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the rule deployment alert state was lastly changed. This is filled regardless of the current alert state. E.g. if the current alert status is false, this timestamp will be the timestamp when the alert status was changed to false.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The timestamp when the rule deployment alert state was lastly changed. This is filled regardless of the current alert state. E.g. if the current alert status is false, this timestamp will be the timestamp when the alert status was changed to false.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#name::String

Returns Required. The resource name of the rule deployment. Note that RuleDeployment is a child of the overall Rule, not any individual revision, so the resource ID segment for the Rule resource must not reference a specific revision. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment.

Returns:

  • (::String)

    Required. The resource name of the rule deployment. Note that RuleDeployment is a child of the overall Rule, not any individual revision, so the resource ID segment for the Rule resource must not reference a specific revision. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#producer_rules::Array<::String> (readonly)

Returns Output only. The names of the associated/chained producer rules. Rules are considered producers for this rule if this rule explicitly filters on their ruleid. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.

Returns:

  • (::Array<::String>)

    Output only. The names of the associated/chained producer rules. Rules are considered producers for this rule if this rule explicitly filters on their ruleid. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end

#run_frequency::Google::Cloud::Chronicle::V1::RunFrequency

Returns The run frequency of the rule deployment.

Returns:



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 191

class RuleDeployment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible execution states the rule deployment can be in.
  module ExecutionState
    # Unspecified or unknown execution state.
    EXECUTION_STATE_UNSPECIFIED = 0

    # Default execution state.
    DEFAULT = 1

    # Rules in limited state may not have their executions guaranteed.
    LIMITED = 2

    # Paused rules are not executed at all.
    PAUSED = 3
  end
end