Class: Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb

Overview

Client for the RuleExecutionErrorService service.

RuleExecutionErrorService contains endpoints related to rule execution errors.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#instance_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new RuleExecutionErrorService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the RuleExecutionErrorService client.

Yield Parameters:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 130

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/chronicle/v1/rule_execution_error_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @rule_execution_error_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @rule_execution_error_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the RuleExecutionErrorService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all RuleExecutionErrorService clients
::Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_rule_execution_errors.timeout = 600.0
    default_config.rpcs.list_rule_execution_errors.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the RuleExecutionErrorService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



100
101
102
103
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 100

def configure
  yield @config if block_given?
  @config
end

#list_rule_execution_errors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleExecutionError> #list_rule_execution_errors(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleExecutionError>

Lists rule execution errors.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleExecutionErrorService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListRuleExecutionErrorsRequest.new

# Call the list_rule_execution_errors method.
result = client.list_rule_execution_errors request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::RuleExecutionError.
  p item
end

Overloads:

  • #list_rule_execution_errors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleExecutionError>

    Pass arguments to list_rule_execution_errors via a request object, either of type ListRuleExecutionErrorsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListRuleExecutionErrorsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_rule_execution_errors(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleExecutionError>

    Pass arguments to list_rule_execution_errors via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The instance to list rule execution errors from. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of rule execution errors to return. The service may return fewer than this value. If unspecified, at most 1000 rule execution errors will be returned. The maximum value is 10000; values above 10000 will be coerced to 10000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListRuleExecutionErrors call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListRuleExecutionErrors must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      A filter that can be used to retrieve specific rule execution errors. Only the following filters are allowed:

        rule = "\\{Rule.name}"
        curated_rule = "\\{CuratedRule.name}"
      

      The value for rule or curated_rule must be a valid rule resource name or a valid curated rule resource name specified in quotes.

      For 'rule', an optional 'revision_id' can be specified which can be used to fetch errors for a given revision of the rule. A '-' is also allowed to fetch errors across all revisions of the rule. If unspecified, only errors corresponding to the most recent revision of the rule will be returned. So these variations are all allowed:

        rule = "\\{Rule.name}"
        rule = "\\{Rule.name}@\\{Rule.revision_id}"
        rule = "\\{Rule.name}@-"
      

      Revision IDs are not supported for curated rules.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 274

def list_rule_execution_errors request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListRuleExecutionErrorsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_rule_execution_errors..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_rule_execution_errors.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_rule_execution_errors.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_execution_error_service_stub.call_rpc :list_rule_execution_errors, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @rule_execution_error_service_stub, :list_rule_execution_errors, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


186
187
188
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 186

def logger
  @rule_execution_error_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


110
111
112
# File 'lib/google/cloud/chronicle/v1/rule_execution_error_service/client.rb', line 110

def universe_domain
  @rule_execution_error_service_stub.universe_domain
end