Class: Google::Cloud::Chronicle::V1::RuleService::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/chronicle/v1/rule_service/rest/client.rb

Overview

REST client for the RuleService service.

RuleService provides interface for user-created rules.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#data_access_scope_path, #instance_path, #reference_list_path, #retrohunt_path, #rule_deployment_path, #rule_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new RuleService REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the RuleService client.

Yield Parameters:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 171

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Cloud::Chronicle::V1::RuleService::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @rule_service_stub = ::Google::Cloud::Chronicle::V1::RuleService::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @rule_service_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Instance Attribute Details

#operations_client::Google::Cloud::Chronicle::V1::RuleService::Rest::Operations (readonly)

Get the associated client for long-running operations.



225
226
227
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 225

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the RuleService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all RuleService clients
::Google::Cloud::Chronicle::V1::RuleService::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Chronicle", "V1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_rule.timeout = 60.0

    default_config.rpcs.get_rule.timeout = 60.0
    default_config.rpcs.get_rule.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_rules.timeout = 600.0
    default_config.rpcs.list_rules.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_rule.timeout = 600.0

    default_config.rpcs.delete_rule.timeout = 60.0

    default_config.rpcs.list_rule_revisions.timeout = 600.0
    default_config.rpcs.list_rule_revisions.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_retrohunt.timeout = 600.0

    default_config.rpcs.get_retrohunt.timeout = 60.0
    default_config.rpcs.get_retrohunt.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_retrohunts.timeout = 60.0
    default_config.rpcs.list_retrohunts.retry_policy = {
      initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_rule_deployment.timeout = 600.0
    default_config.rpcs.get_rule_deployment.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_rule_deployments.timeout = 600.0
    default_config.rpcs.list_rule_deployments.retry_policy = {
      initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_rule_deployment.timeout = 600.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the RuleService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



141
142
143
144
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 141

def configure
  yield @config if block_given?
  @config
end

#create_retrohunt(request, options = nil) ⇒ ::Gapic::Operation #create_retrohunt(parent: nil, retrohunt: nil) ⇒ ::Gapic::Operation

Create a Retrohunt.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateRetrohuntRequest.new

# Call the create_retrohunt method.
result = client.create_retrohunt request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_retrohunt(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_retrohunt via a request object, either of type CreateRetrohuntRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateRetrohuntRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_retrohunt(parent: nil, retrohunt: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_retrohunt via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of retrohunt, which is a rule. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • retrohunt (::Google::Cloud::Chronicle::V1::Retrohunt, ::Hash) (defaults to: nil)

      Required. The retrohunt to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 833

def create_retrohunt request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateRetrohuntRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_retrohunt..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_retrohunt.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_retrohunt.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.create_retrohunt request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#create_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule #create_rule(parent: nil, rule: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

Creates a new Rule.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::CreateRuleRequest.new

# Call the create_rule method.
result = client.create_rule request

# The returned object is of type Google::Cloud::Chronicle::V1::Rule.
p result

Overloads:

  • #create_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to create_rule via a request object, either of type CreateRuleRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::CreateRuleRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_rule(parent: nil, rule: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to create_rule via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this rule will be created. Format: projects/{project}/locations/{location}/instances/{instance}

    • rule (::Google::Cloud::Chronicle::V1::Rule, ::Hash) (defaults to: nil)

      Required. The rule to create.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 284

def create_rule request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateRuleRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_rule..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_rule.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_rule.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.create_rule request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_rule(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_rule(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

Deletes a Rule.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::DeleteRuleRequest.new

# Call the delete_rule method.
result = client.delete_rule request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_rule(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_rule via a request object, either of type DeleteRuleRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::DeleteRuleRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_rule(name: nil, force: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_rule via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the rule to delete. A rule revision timestamp cannot be specified as part of the name, as deleting specific revisions is not supported. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • force (::Boolean) (defaults to: nil)

      Optional. If set to true, any retrohunts and any detections associated with the rule will also be deleted. If set to false, the call will only succeed if the rule has no associated retrohunts, including completed retrohunts, and no associated detections. Regardless of this field's value, the rule deployment associated with this rule will also be deleted.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 644

def delete_rule request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteRuleRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_rule..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_rule.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_rule.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.delete_rule request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_retrohunt(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Retrohunt #get_retrohunt(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::Retrohunt

Get a Retrohunt.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetRetrohuntRequest.new

# Call the get_retrohunt method.
result = client.get_retrohunt request

# The returned object is of type Google::Cloud::Chronicle::V1::Retrohunt.
p result

Overloads:

  • #get_retrohunt(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Retrohunt

    Pass arguments to get_retrohunt via a request object, either of type GetRetrohuntRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetRetrohuntRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_retrohunt(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::Retrohunt

    Pass arguments to get_retrohunt via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the retrohunt to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/retrohunts/{retrohunt}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 915

def get_retrohunt request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetRetrohuntRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_retrohunt..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_retrohunt.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_retrohunt.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.get_retrohunt request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule #get_rule(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

Gets a Rule.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetRuleRequest.new

# Call the get_rule method.
result = client.get_rule request

# The returned object is of type Google::Cloud::Chronicle::V1::Rule.
p result

Overloads:

  • #get_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to get_rule via a request object, either of type GetRuleRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetRuleRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_rule(name: nil, view: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to get_rule via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the rule to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • view (::Google::Cloud::Chronicle::V1::RuleView) (defaults to: nil)

      The view field indicates the scope of fields to populate for the Rule being returned. If unspecified, defaults to FULL.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 367

def get_rule request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetRuleRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_rule..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_rule.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_rule.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.get_rule request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_rule_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment #get_rule_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

Gets a RuleDeployment.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::GetRuleDeploymentRequest.new

# Call the get_rule_deployment method.
result = client.get_rule_deployment request

# The returned object is of type Google::Cloud::Chronicle::V1::RuleDeployment.
p result

Overloads:

  • #get_rule_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

    Pass arguments to get_rule_deployment via a request object, either of type GetRuleDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::GetRuleDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_rule_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

    Pass arguments to get_rule_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the rule deployment to retrieve. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 1096

def get_rule_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetRuleDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_rule_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_rule_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_rule_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.get_rule_deployment request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_retrohunts(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Retrohunt> #list_retrohunts(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Retrohunt>

List Retrohunts.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListRetrohuntsRequest.new

# Call the list_retrohunts method.
result = client.list_retrohunts request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::Retrohunt.
  p item
end

Overloads:

  • #list_retrohunts(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Retrohunt>

    Pass arguments to list_retrohunts via a request object, either of type ListRetrohuntsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListRetrohuntsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_retrohunts(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Retrohunt>

    Pass arguments to list_retrohunts via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The rule that the retrohunts belong to. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of retrohunt to return. The service may return fewer than this value. If unspecified, at most 100 retrohunts will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListRetrohunts call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListRetrohunts must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      A filter that can be used to retrieve specific rule deployments. The following fields are filterable: state

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 1014

def list_retrohunts request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListRetrohuntsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_retrohunts..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_retrohunts.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_retrohunts.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.list_retrohunts request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @rule_service_stub, :list_retrohunts, "retrohunts", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_rule_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleDeployment> #list_rule_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleDeployment>

Lists RuleDeployments across all Rules.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListRuleDeploymentsRequest.new

# Call the list_rule_deployments method.
result = client.list_rule_deployments request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::RuleDeployment.
  p item
end

Overloads:

  • #list_rule_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleDeployment>

    Pass arguments to list_rule_deployments via a request object, either of type ListRuleDeploymentsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListRuleDeploymentsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_rule_deployments(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::RuleDeployment>

    Pass arguments to list_rule_deployments via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The collection of all parents which own all rule deployments. The "-" wildcard token must be used as the rule identifier in the resource path. Format: projects/{project}/locations/{location}/instances/{instance}/rules/-

    • page_size (::Integer) (defaults to: nil)

      The maximum number of rule deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListRuleDeployments call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListRuleDeployments must match the call that provided the page token.

    • filter (::String) (defaults to: nil)

      A filter that can be used to retrieve specific rule deployments. The following fields are filterable: archived, name

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 1196

def list_rule_deployments request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListRuleDeploymentsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_rule_deployments..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_rule_deployments.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_rule_deployments.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.list_rule_deployments request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @rule_service_stub, :list_rule_deployments, "rule_deployments", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_rule_revisions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule> #list_rule_revisions(name: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

Lists all revisions of the rule.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListRuleRevisionsRequest.new

# Call the list_rule_revisions method.
result = client.list_rule_revisions request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::Rule.
  p item
end

Overloads:

  • #list_rule_revisions(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

    Pass arguments to list_rule_revisions via a request object, either of type ListRuleRevisionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListRuleRevisionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_rule_revisions(name: nil, page_size: nil, page_token: nil, view: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

    Pass arguments to list_rule_revisions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the rule to list revisions for. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of revisions to return per page. The service may return fewer than this value. If unspecified, at most 100 revisions will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      The page token, received from a previous ListRuleRevisions call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListRuleRevisions must match the call that provided the page token.

    • view (::Google::Cloud::Chronicle::V1::RuleView) (defaults to: nil)

      The view field indicates the scope of fields to populate for the revision being returned. If unspecified, defaults to BASIC.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 742

def list_rule_revisions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListRuleRevisionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_rule_revisions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_rule_revisions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_rule_revisions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.list_rule_revisions request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @rule_service_stub, :list_rule_revisions, "rules", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_rules(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule> #list_rules(parent: nil, page_size: nil, page_token: nil, view: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

Lists Rules.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::ListRulesRequest.new

# Call the list_rules method.
result = client.list_rules request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Chronicle::V1::Rule.
  p item
end

Overloads:

  • #list_rules(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

    Pass arguments to list_rules via a request object, either of type ListRulesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::ListRulesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_rules(parent: nil, page_size: nil, page_token: nil, view: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::Rule>

    Pass arguments to list_rules via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent, which owns this collection of rules. Format: projects/{project}/locations/{location}/instances/{instance}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of rules to return. The service may return fewer than this value. If unspecified, at most 100 rules will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListRules call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListRules must match the call that provided the page token.

    • view (::Google::Cloud::Chronicle::V1::RuleView) (defaults to: nil)

      view indicates the scope of fields to populate for the Rule being returned. If unspecified, defaults to BASIC.

    • filter (::String) (defaults to: nil)

      Only the following filters are allowed: "reference_lists:{reference_list_name}" "data_tables:{data_table_name}" "display_name:{display_name}"

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 469

def list_rules request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListRulesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_rules..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_rules.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_rules.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.list_rules request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @rule_service_stub, :list_rules, "rules", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


232
233
234
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 232

def logger
  @rule_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


151
152
153
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 151

def universe_domain
  @rule_service_stub.universe_domain
end

#update_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule #update_rule(rule: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

Updates a Rule.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateRuleRequest.new

# Call the update_rule method.
result = client.update_rule request

# The returned object is of type Google::Cloud::Chronicle::V1::Rule.
p result

Overloads:

  • #update_rule(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to update_rule via a request object, either of type UpdateRuleRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateRuleRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_rule(rule: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::Rule

    Pass arguments to update_rule via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • rule (::Google::Cloud::Chronicle::V1::Rule, ::Hash) (defaults to: nil)

      Required. The rule to update.

      The rule's name field is used to identify the rule to update. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      The list of fields to update. If not included, all fields with a non-empty value will be overwritten.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 556

def update_rule request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateRuleRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_rule..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_rule.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_rule.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.update_rule request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_rule_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment #update_rule_deployment(rule_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

Updates a RuleDeployment. Failures are not necessarily atomic. If there is a request to update multiple fields, and any update to a single field fails, an error will be returned, but other fields may remain successfully updated.

Examples:

Basic example

require "google/cloud/chronicle/v1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Chronicle::V1::RuleService::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Chronicle::V1::UpdateRuleDeploymentRequest.new

# Call the update_rule_deployment method.
result = client.update_rule_deployment request

# The returned object is of type Google::Cloud::Chronicle::V1::RuleDeployment.
p result

Overloads:

  • #update_rule_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

    Pass arguments to update_rule_deployment via a request object, either of type UpdateRuleDeploymentRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::Chronicle::V1::UpdateRuleDeploymentRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_rule_deployment(rule_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::RuleDeployment

    Pass arguments to update_rule_deployment via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • rule_deployment (::Google::Cloud::Chronicle::V1::RuleDeployment, ::Hash) (defaults to: nil)

      Required. The rule deployment to update.

      The rule deployment's name field is used to identify the rule deployment to update. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/deployment

    • update_mask (::Google::Protobuf::FieldMask, ::Hash) (defaults to: nil)

      Required. The list of fields to update.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
# File 'lib/google/cloud/chronicle/v1/rule_service/rest/client.rb', line 1285

def update_rule_deployment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateRuleDeploymentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_rule_deployment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Chronicle::V1::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_rule_deployment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_rule_deployment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @rule_service_stub.update_rule_deployment request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end