Class: Google::Cloud::Chronicle::V1::ScopeInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

ScopeInfo specifies the scope info of the reference list.

Instance Attribute Summary collapse

Instance Attribute Details

#reference_list_scope::Google::Cloud::Chronicle::V1::ReferenceListScope

Returns Required. The list of scope names of the reference list, if the list is empty the reference list is treated as unscoped.

Returns:



29
30
31
32
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 29

class ScopeInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end