Class: Google::Cloud::Chronicle::V1::Severity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Severity represents the severity level of the rule.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns The display name of the severity level. Extracted from the meta section of the rule text.

Returns:

  • (::String)

    The display name of the severity level. Extracted from the meta section of the rule text.



606
607
608
609
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 606

class Severity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end