Class: Google::Cloud::Chronicle::V1::TimestampMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/dashboard_query.rb

Overview

Metadata of the timestamp column.

Instance Attribute Summary collapse

Instance Attribute Details

#is_interpolable::Boolean

Returns Whether the timestamp column is interpolable in UI.

Returns:

  • (::Boolean)

    Whether the timestamp column is interpolable in UI.



520
521
522
523
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 520

class TimestampMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#is_sortable::Boolean

Returns Whether the timestamp column is sortable in UI.

Returns:

  • (::Boolean)

    Whether the timestamp column is sortable in UI.



520
521
522
523
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 520

class TimestampMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_format::String

Returns Time format of the timestamp column.

Returns:

  • (::String)

    Time format of the timestamp column.



520
521
522
523
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 520

class TimestampMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_granularity::String

Returns Time granularity of the timestamp column.

Returns:

  • (::String)

    Time granularity of the timestamp column.



520
521
522
523
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 520

class TimestampMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#time_zone::String

Returns Time zone of the timestamp column.

Returns:

  • (::String)

    Time zone of the timestamp column.



520
521
522
523
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 520

class TimestampMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end