Class: Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_access_control.rb

Overview

Request message for UpdateDataAccessLabel method.

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_label::Google::Cloud::Chronicle::V1::DataAccessLabel

Returns Required. The data access label to update.

The label's name field is used to identify the label to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessLabels/{data_access_label}.

Returns:

  • (::Google::Cloud::Chronicle::V1::DataAccessLabel)

    Required. The data access label to update.

    The label's name field is used to identify the label to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessLabels/{data_access_label}



108
109
110
111
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 108

class UpdateDataAccessLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description and definition fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.

Returns:

  • (::Google::Protobuf::FieldMask)

    The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description and definition fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.



108
109
110
111
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 108

class UpdateDataAccessLabelRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end