Class: Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_access_control.rb

Overview

Request message for UpdateDataAccessScope method.

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_scope::Google::Cloud::Chronicle::V1::DataAccessScope

Returns Required. The data access scope to update.

The scope's name field is used to identify the scope to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}.

Returns:

  • (::Google::Cloud::Chronicle::V1::DataAccessScope)

    Required. The data access scope to update.

    The scope's name field is used to identify the scope to update. Format: projects/{project}/locations/{location}/instances/{instance}/dataAccessScopes/{data_access_scope}



211
212
213
214
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 211

class UpdateDataAccessScopeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description, the allowed and denied labels list fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.

Returns:

  • (::Google::Protobuf::FieldMask)

    The list of fields to update. If not included, all fields with a non-empty value will be overwritten. Currently, only the description, the allowed and denied labels list fields are supported for update; an update call that attempts to update any other fields will return INVALID_ARGUMENT.



211
212
213
214
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 211

class UpdateDataAccessScopeRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end