Class: Google::Cloud::Chronicle::V1::UpdateDataTableRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

A request to update details of data table.

Instance Attribute Summary collapse

Instance Attribute Details

#data_table::Google::Cloud::Chronicle::V1::DataTable

Returns Required. This field is used to identify the datatable to update. Format: projects/{project}/locations/{locations}/instances/{instance}/dataTables/{data_table}.

Returns:

  • (::Google::Cloud::Chronicle::V1::DataTable)

    Required. This field is used to identify the datatable to update. Format: projects/{project}/locations/{locations}/instances/{instance}/dataTables/{data_table}



67
68
69
70
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 67

class UpdateDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of metadata fields to update. Currently data tables only support updating the description, row_time_to_live and scope_info fields. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. The list of metadata fields to update. Currently data tables only support updating the description, row_time_to_live and scope_info fields. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.



67
68
69
70
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 67

class UpdateDataTableRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end