Class: Google::Cloud::Chronicle::V1::UpdateDataTableRowRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/data_table.rb

Overview

Request to update data table row.

Instance Attribute Summary collapse

Instance Attribute Details

#data_table_row::Google::Cloud::Chronicle::V1::DataTableRow

Returns Required. Format: projects/{project}/locations/{location}/instances/{instance}/dataTables/{data_table}/dataTableRows/{data_table_row}.

Returns:



153
154
155
156
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 153

class UpdateDataTableRowRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update. Currently data table rows only support updating the values field. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. The list of fields to update. Currently data table rows only support updating the values field. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.



153
154
155
156
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 153

class UpdateDataTableRowRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end