Class: Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Request message for UpdateFindingsRefinementDeployment method.

Instance Attribute Summary collapse

Instance Attribute Details

#findings_refinement_deployment::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment

Returns Required. The findings refinement deployment to update.

The findings refinement deployment's name field is used to identify the findings refinement deployment to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment.

Returns:

  • (::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment)

    Required. The findings refinement deployment to update.

    The findings refinement deployment's name field is used to identify the findings refinement deployment to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}/deployment



290
291
292
293
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 290

class UpdateFindingsRefinementDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. The list of fields to update. If * is provided, all fields will be updated.

Returns:



290
291
292
293
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 290

class UpdateFindingsRefinementDeploymentRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end