Class: Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/findings_refinement.rb

Overview

Request message for UpdateFindingsRefinement method.

Instance Attribute Summary collapse

Instance Attribute Details

#findings_refinement::Google::Cloud::Chronicle::V1::FindingsRefinement

Returns Required. The findings refinement to update.

The findings refinement's name field is used to identify the findings refinement to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}.

Returns:

  • (::Google::Cloud::Chronicle::V1::FindingsRefinement)

    Required. The findings refinement to update.

    The findings refinement's name field is used to identify the findings refinement to update. Format: projects/{project}/locations/{location}/instances/{instance}/findingsRefinements/{findings_refinement}



261
262
263
264
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 261

class UpdateFindingsRefinementRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update. If * is provided, all fields will be updated.

Returns:



261
262
263
264
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 261

class UpdateFindingsRefinementRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end