Class: Google::Cloud::Chronicle::V1::UpdateNativeDashboardRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/native_dashboard.rb

Overview

Request message to update a dashboard.

Instance Attribute Summary collapse

Instance Attribute Details

#native_dashboard::Google::Cloud::Chronicle::V1::NativeDashboard

Returns Required. The dashboard to update.

The dashboard's name field is used to identify the dashboard to update. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}.

Returns:

  • (::Google::Cloud::Chronicle::V1::NativeDashboard)

    Required. The dashboard to update.

    The dashboard's name field is used to identify the dashboard to update. Format: projects/{project}/locations/{location}/instances/{instance}/nativeDashboards/{dashboard}



250
251
252
253
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 250

class UpdateNativeDashboardRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. LINT.IfChange(update_mask_values) The list of fields to update. Supported paths are - display_name description definition.filters definition.charts type access dashboard_user_data.is_pinned.

Returns:

  • (::Google::Protobuf::FieldMask)

    Required. LINT.IfChange(update_mask_values) The list of fields to update. Supported paths are - display_name description definition.filters definition.charts type access dashboard_user_data.is_pinned



250
251
252
253
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 250

class UpdateNativeDashboardRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end