Class: Google::Cloud::Chronicle::V1::UpdateReferenceListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

A request to update a reference list.

Instance Attribute Summary collapse

Instance Attribute Details

#reference_list::Google::Cloud::Chronicle::V1::ReferenceList

Returns Required. The reference list to update.

The reference list's name field is used to identify the reference list to update. Format: projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}.

Returns:

  • (::Google::Cloud::Chronicle::V1::ReferenceList)

    Required. The reference list to update.

    The reference list's name field is used to identify the reference list to update. Format: projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}



136
137
138
139
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 136

class UpdateReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns The list of fields to update. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.

Returns:

  • (::Google::Protobuf::FieldMask)

    The list of fields to update. When no field mask is supplied, all non-empty fields will be updated. A field mask of "*" will update all fields, whether empty or not.



136
137
138
139
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 136

class UpdateReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end