Class: Google::Cloud::Chronicle::V1::UpdateWatchlistRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/entity.rb

Overview

Request message for updating watchlist.

Instance Attribute Summary collapse

Instance Attribute Details

#update_mask::Google::Protobuf::FieldMask

Returns Optional. The list of fields to update.

Returns:



187
188
189
190
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 187

class UpdateWatchlistRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#watchlist::Google::Cloud::Chronicle::V1::Watchlist

Returns Required. The watchlist to update.

The watchlist's name field is used to identify the watchlist to update. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}.

Returns:

  • (::Google::Cloud::Chronicle::V1::Watchlist)

    Required. The watchlist to update.

    The watchlist's name field is used to identify the watchlist to update. Format: projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}



187
188
189
190
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 187

class UpdateWatchlistRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end