Class: Google::Cloud::Chronicle::V1::VerifyReferenceListRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/reference_list.rb

Overview

VerifyReferenceList request message.

Instance Attribute Summary collapse

Instance Attribute Details

#entries::Array<::Google::Cloud::Chronicle::V1::ReferenceListEntry>

Returns Required. The entries of the reference list. Each line may be either an item in the list or a comment.

Returns:



154
155
156
157
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 154

class VerifyReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance::String

Returns Required. The name of the parent resource, which is the SecOps instance associated with the request. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The name of the parent resource, which is the SecOps instance associated with the request. Format: projects/{project}/locations/{location}/instances/{instance}



154
155
156
157
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 154

class VerifyReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#syntax_type::Google::Cloud::Chronicle::V1::ReferenceListSyntaxType

Returns Required. Type (format) of list lines.

Returns:



154
155
156
157
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 154

class VerifyReferenceListRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end