Class: Google::Cloud::Chronicle::V1::VerifyRuleTextRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Request message for VerifyRuleText method.

Instance Attribute Summary collapse

Instance Attribute Details

#instance::String

Returns Required. The name of the parent resource, which is the SecOps instance associated with the request. Format: projects/{project}/locations/{location}/instances/{instance}.

Returns:

  • (::String)

    Required. The name of the parent resource, which is the SecOps instance associated with the request. Format: projects/{project}/locations/{location}/instances/{instance}



378
379
380
381
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 378

class VerifyRuleTextRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rule_text::String

Returns Required. The rule text to verify as a UTF-8 string.

Returns:

  • (::String)

    Required. The rule text to verify as a UTF-8 string.



378
379
380
381
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 378

class VerifyRuleTextRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end