Class: Google::Cloud::Chronicle::V1::VerifyRuleTextResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::VerifyRuleTextResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Response message for VerifyRuleText method.
Instance Attribute Summary collapse
-
#compilation_diagnostics ⇒ ::Array<::Google::Cloud::Chronicle::V1::CompilationDiagnostic>
A list of a rule's corresponding compilation diagnostic messages such as compilation errors and compilation warnings.
-
#success ⇒ ::Boolean
Whether or not the rule text was successfully verified.
Instance Attribute Details
#compilation_diagnostics ⇒ ::Array<::Google::Cloud::Chronicle::V1::CompilationDiagnostic>
Returns A list of a rule's corresponding compilation diagnostic messages such as compilation errors and compilation warnings.
391 392 393 394 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 391 class VerifyRuleTextResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#success ⇒ ::Boolean
Returns Whether or not the rule text was successfully verified.
391 392 393 394 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 391 class VerifyRuleTextResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |