Class: Google::Cloud::Chronicle::V1::AdvancedFilterConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::AdvancedFilterConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_query.rb
Overview
Advanced filter configuration for the filter widget.
Defined Under Namespace
Classes: ManualOptions, QueryOptions, ValueSource
Instance Attribute Summary collapse
-
#default_values ⇒ ::Array<::String>
Optional.
-
#multiple_allowed ⇒ ::Boolean
Optional.
-
#prefix ⇒ ::String
Optional.
-
#separator ⇒ ::String
Optional.
-
#skip_default_affixes ⇒ ::Boolean
Optional.
-
#suffix ⇒ ::String
Optional.
-
#token ⇒ ::String
Required.
-
#value_source ⇒ ::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ValueSource
Required.
Instance Attribute Details
#default_values ⇒ ::Array<::String>
Returns Optional. Default values to use if no value is selected/provided.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multiple_allowed ⇒ ::Boolean
Returns Optional. Whether to allow selection of multiple values.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#prefix ⇒ ::String
Returns Optional. String to prepend to the final replaced value (e.g., "/", "^(", "\"").
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#separator ⇒ ::String
Returns Optional. Delimiter to join multiple selected values (e.g., "|", " OR field = ").
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#skip_default_affixes ⇒ ::Boolean
Returns Optional. Whether to skip the configured prefix and suffix when using default values. If true, default values are inserted raw (joined by the separator).
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#suffix ⇒ ::String
Returns Optional. String to append to the final replaced value (e.g., "/", ")$", "\"").
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#token ⇒ ::String
Returns Required. The token name to look for in the query (e.g., "hostname"). The system will automatically wrap this in '$' (e.g., "$hostname$").
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#value_source ⇒ ::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ValueSource
Returns Required. Source of the values for the filter.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 401 class AdvancedFilterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Source of the values for the filter. # @!attribute [rw] manual_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::ManualOptions] # Optional. Manual options provided by the user. # # Note: The following fields are mutually exclusive: `manual_options`, `query_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] query_options # @return [::Google::Cloud::Chronicle::V1::AdvancedFilterConfig::QueryOptions] # Optional. Query options to fetch the values from the query engine. # This is used for the filter's population query. # # Note: The following fields are mutually exclusive: `query_options`, `manual_options`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ValueSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Manual options provided by the user. # @!attribute [rw] options # @return [::Array<::String>] # Optional. The options provided by the user. # The max number of options is limited to 10000. class ManualOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Query options to fetch the values from the query engine. # This is used for the filter's population query. # @!attribute [rw] query # @return [::String] # Required. The query to execute to fetch the values. # @!attribute [rw] column # @return [::String] # Required. The column name to use for the values. # @!attribute [rw] global_time_filter_enabled # @return [::Boolean] # Optional. Enable global time filter # @!attribute [rw] input # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input] # Optional. Time range input specifically for the filter's population # query. class QueryOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |