Class: Google::Cloud::Chronicle::V1::BatchGetDashboardChartsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::BatchGetDashboardChartsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
Request message to get dashboard charts in batch.
Instance Attribute Summary collapse
-
#names ⇒ ::Array<::String>
Required.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#names ⇒ ::Array<::String>
Returns Required. The names of the dashboard charts to get.
714 715 716 717 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 714 class BatchGetDashboardChartsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource shared by all dashboard charts being
retrieved. Format:
projects/{project}/locations/{location}/instances/{instance} If this is
set, the parent of all of the dashboard charts specified in names must
match this field.
714 715 716 717 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 714 class BatchGetDashboardChartsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |