Class: Google::Cloud::Chronicle::V1::BigQueryExport
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::BigQueryExport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/big_query_export.rb
Overview
This resource represents the BigQuery export configuration for a Chronicle instance which includes Google Cloud Platform resources like Cloud Storage buckets, BigQuery datasets etc and the export settings for each data source.
Instance Attribute Summary collapse
-
#big_query_export_package ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExportPackage
readonly
Output only.
-
#entity_graph_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Optional.
-
#ioc_matches_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Optional.
-
#name ⇒ ::String
Identifier.
-
#provisioned ⇒ ::Boolean
readonly
Output only.
-
#rule_detections_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Optional.
-
#udm_events_aggregates_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Optional.
-
#udm_events_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Optional.
Instance Attribute Details
#big_query_export_package ⇒ ::Google::Cloud::Chronicle::V1::BigQueryExportPackage (readonly)
Returns Output only. The BigQueryExportPackage entitled for the Chronicle instance.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entity_graph_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Returns Optional. The export settings for the Entity Graph data source.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ioc_matches_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Returns Optional. The export settings for the IOC Matches data source.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The resource name of the BigQueryExport. Format: projects/{project}/locations/{location}/instances/{instance}/bigQueryExport.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#provisioned ⇒ ::Boolean (readonly)
Returns Output only. Whether the BigQueryExport has been provisioned for the Chronicle instance.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rule_detections_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Returns Optional. The export settings for the Rule Detections data source.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#udm_events_aggregates_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Returns Optional. The export settings for the UDM Events Aggregates data source.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#udm_events_settings ⇒ ::Google::Cloud::Chronicle::V1::DataSourceExportSettings
Returns Optional. The export settings for the UDM Events data source.
54 55 56 57 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 54 class BigQueryExport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |