Class: Google::Cloud::Chronicle::V1::CompilationDiagnostic
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::CompilationDiagnostic
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
CompilationDiagnostic represents a compilation diagnostic generated during a rule's compilation, such as a compilation error or a compilation warning.
Defined Under Namespace
Modules: Severity
Instance Attribute Summary collapse
-
#message ⇒ ::String
readonly
Output only.
-
#position ⇒ ::Google::Cloud::Chronicle::V1::CompilationPosition
readonly
Output only.
-
#severity ⇒ ::Google::Cloud::Chronicle::V1::CompilationDiagnostic::Severity
readonly
Output only.
-
#uri ⇒ ::String
readonly
Output only.
Instance Attribute Details
#message ⇒ ::String (readonly)
Returns Output only. The diagnostic message.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 584 class CompilationDiagnostic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity level of the compilation diagnostic. module Severity # An unspecified severity level. SEVERITY_UNSPECIFIED = 0 # A compilation warning. WARNING = 1 # A compilation error. ERROR = 2 end end |
#position ⇒ ::Google::Cloud::Chronicle::V1::CompilationPosition (readonly)
Returns Output only. The approximate position in the rule text associated with the compilation diagnostic. Compilation Position may be empty.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 584 class CompilationDiagnostic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity level of the compilation diagnostic. module Severity # An unspecified severity level. SEVERITY_UNSPECIFIED = 0 # A compilation warning. WARNING = 1 # A compilation error. ERROR = 2 end end |
#severity ⇒ ::Google::Cloud::Chronicle::V1::CompilationDiagnostic::Severity (readonly)
Returns Output only. The severity of a rule's compilation diagnostic.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 584 class CompilationDiagnostic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity level of the compilation diagnostic. module Severity # An unspecified severity level. SEVERITY_UNSPECIFIED = 0 # A compilation warning. WARNING = 1 # A compilation error. ERROR = 2 end end |
#uri ⇒ ::String (readonly)
Returns Output only. Link to documentation that describes a diagnostic in more detail.
584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 584 class CompilationDiagnostic include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The severity level of the compilation diagnostic. module Severity # An unspecified severity level. SEVERITY_UNSPECIFIED = 0 # A compilation warning. WARNING = 1 # A compilation error. ERROR = 2 end end |