Class: Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Request message for ComputeFindingsRefinementActivity method.
Instance Attribute Summary collapse
-
#interval ⇒ ::Google::Type::Interval
The time interval the activity is measured over.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#interval ⇒ ::Google::Type::Interval
Returns The time interval the activity is measured over.
389 390 391 392 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 389 class ComputeFindingsRefinementActivityRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Full resource name for the findings refinement to fetch the activity for. Format: projects/{project}/locations/{region}/instances/{instance}/findingsRefinements/{findings_refinement}.
389 390 391 392 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 389 class ComputeFindingsRefinementActivityRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |