Class: Google::Cloud::Chronicle::V1::CreateWatchlistRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::CreateWatchlistRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/entity.rb
Overview
Request message for creating watchlist.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#watchlist ⇒ ::Google::Cloud::Chronicle::V1::Watchlist
Required.
-
#watchlist_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent resource where this watchlist will be created.
Format: projects/{project}/locations/{location}/instances/{instance}.
171 172 173 174 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 171 class CreateWatchlistRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#watchlist ⇒ ::Google::Cloud::Chronicle::V1::Watchlist
Returns Required. The watchlist to create.
171 172 173 174 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 171 class CreateWatchlistRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#watchlist_id ⇒ ::String
Returns Optional. The ID to use for the watchlist, which will become the final component of the watchlist's resource name.
This value should be 4-63 characters, and valid characters are /[a-z][0-9]-/.
171 172 173 174 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 171 class CreateWatchlistRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |