Class: Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
Drill down configuration.
Defined Under Namespace
Classes: DrillDown
Instance Attribute Summary collapse
-
#left_drill_downs ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown>
Required.
-
#right_drill_downs ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown>
Required.
Instance Attribute Details
#left_drill_downs ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown>
Returns Required. Left click drill downs.
537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 537 class DrillDownConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down config. # @!attribute [rw] default_settings # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::DefaultDrillDownSettings] # Default drill down settings. # # Note: The following fields are mutually exclusive: `default_settings`, `custom_settings`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] custom_settings # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings] # Custom drill down settings. # # Note: The following fields are mutually exclusive: `custom_settings`, `default_settings`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] id # @return [::String] # Required. ID of the drill down. # @!attribute [rw] display_name # @return [::String] # Required. Display name of the drill down. class DrillDown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default drill down settings. # @!attribute [rw] enabled # @return [::Boolean] # Required. Whether the default drill down is enabled. class DefaultDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Custom drill down settings. # @!attribute [rw] query # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownQuery] # Drill down query action config. # # Note: The following fields are mutually exclusive: `query`, `filter`, `external_link`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] filter # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter] # Drill down filter action config. # # Note: The following fields are mutually exclusive: `filter`, `query`, `external_link`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] external_link # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownExternalLink] # Drill down external link action config. # # Note: The following fields are mutually exclusive: `external_link`, `query`, `filter`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] new_tab # @return [::Boolean] # Required. Whether to open the drill down action in a new tab. # @!attribute [rw] left_click_column # @return [::String] # Optional. Table chart column name to associate the custom drill down # action on left click. class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#right_drill_downs ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown>
Returns Required. Right click drill downs.
537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 537 class DrillDownConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down config. # @!attribute [rw] default_settings # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::DefaultDrillDownSettings] # Default drill down settings. # # Note: The following fields are mutually exclusive: `default_settings`, `custom_settings`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] custom_settings # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings] # Custom drill down settings. # # Note: The following fields are mutually exclusive: `custom_settings`, `default_settings`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] id # @return [::String] # Required. ID of the drill down. # @!attribute [rw] display_name # @return [::String] # Required. Display name of the drill down. class DrillDown include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Default drill down settings. # @!attribute [rw] enabled # @return [::Boolean] # Required. Whether the default drill down is enabled. class DefaultDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Custom drill down settings. # @!attribute [rw] query # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownQuery] # Drill down query action config. # # Note: The following fields are mutually exclusive: `query`, `filter`, `external_link`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] filter # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter] # Drill down filter action config. # # Note: The following fields are mutually exclusive: `filter`, `query`, `external_link`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] external_link # @return [::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownExternalLink] # Drill down external link action config. # # Note: The following fields are mutually exclusive: `external_link`, `query`, `filter`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] new_tab # @return [::Boolean] # Required. Whether to open the drill down action in a new tab. # @!attribute [rw] left_click_column # @return [::String] # Optional. Table chart column name to associate the custom drill down # action on left click. class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |