Class: Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
Custom drill down settings.
Defined Under Namespace
Classes: DrillDownExternalLink, DrillDownFilter, DrillDownQuery
Instance Attribute Summary collapse
-
#external_link ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownExternalLink
Drill down external link action config.
-
#filter ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter
Drill down filter action config.
-
#left_click_column ⇒ ::String
Optional.
-
#new_tab ⇒ ::Boolean
Required.
-
#query ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownQuery
Drill down query action config.
Instance Attribute Details
#external_link ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownExternalLink
Returns Drill down external link action config.
Note: The following fields are mutually exclusive: external_link, query, filter. If a field in that set is populated, all other fields in the set will automatically be cleared.
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 594 class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#filter ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter
Returns Drill down filter action config.
Note: The following fields are mutually exclusive: filter, query, external_link. If a field in that set is populated, all other fields in the set will automatically be cleared.
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 594 class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#left_click_column ⇒ ::String
Returns Optional. Table chart column name to associate the custom drill down action on left click.
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 594 class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#new_tab ⇒ ::Boolean
Returns Required. Whether to open the drill down action in a new tab.
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 594 class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#query ⇒ ::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownQuery
Returns Drill down query action config.
Note: The following fields are mutually exclusive: query, filter, external_link. If a field in that set is populated, all other fields in the set will automatically be cleared.
594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 594 class CustomDrillDownSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down query config. # @!attribute [rw] query # @return [::String] # Required. Search query to be executed on drill down. class DrillDownQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Drill down filter config. # @!attribute [rw] dashboard_filters # @return [::Array<::Google::Cloud::Chronicle::V1::DashboardChart::DrillDownConfig::DrillDown::CustomDrillDownSettings::DrillDownFilter::DrillDownDashboardFilter>] # Required. Dashboard filters to be applied on drill down. class DrillDownFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Drill down dashboard filter config. # @!attribute [rw] dashboard_filter_id # @return [::String] # Required. ID of the dashboard filter. # @!attribute [rw] filter_operator_and_values # @return [::Array<::Google::Cloud::Chronicle::V1::FilterOperatorAndValues>] # Required. Filter operator and field values for the dashboard # filter. class DrillDownDashboardFilter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Drill down external link config. # @!attribute [rw] link # @return [::String] # Required. External link the drill down action should redirect to. # @!attribute [rw] description # @return [::String] # Optional. Description of the external link. class DrillDownExternalLink include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |