Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::Series::MetricTrendConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::Visualization::Series::MetricTrendConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
Metric trend config for displaying trend value in Metrics chart
Instance Attribute Summary collapse
-
#metric_display_trend ⇒ ::Google::Cloud::Chronicle::V1::MetricDisplayTrend
Optional.
-
#metric_format ⇒ ::Google::Cloud::Chronicle::V1::MetricFormat
Optional.
-
#metric_trend_type ⇒ ::Google::Cloud::Chronicle::V1::MetricTrendType
Optional.
-
#show_metric_trend ⇒ ::Boolean
Optional.
Instance Attribute Details
#metric_display_trend ⇒ ::Google::Cloud::Chronicle::V1::MetricDisplayTrend
Returns Optional. Metric chart configuration to display the trend value.
331 332 333 334 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 331 class MetricTrendConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_format ⇒ ::Google::Cloud::Chronicle::V1::MetricFormat
Returns Optional. Metric chart configuration to display metric trend.
331 332 333 334 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 331 class MetricTrendConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_trend_type ⇒ ::Google::Cloud::Chronicle::V1::MetricTrendType
Returns Optional. Metric chart configuration to display trend type whether regular or inverse.
331 332 333 334 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 331 class MetricTrendConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#show_metric_trend ⇒ ::Boolean
Returns Optional. Metric chart configuration to toggle the trend value display.
331 332 333 334 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 331 class MetricTrendConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |