Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
Conveys what range of values should be rendered in what color. This field is used when threshold_coloring_enabled is true.
Defined Under Namespace
Classes: VisualMapPiece
Instance Attribute Summary collapse
-
#pieces ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap::VisualMapPiece>
Optional.
-
#visual_map_type ⇒ ::Google::Cloud::Chronicle::V1::VisualMapType
Optional.
Instance Attribute Details
#pieces ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap::VisualMapPiece>
Returns Optional. Pieces of the visual map.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 504 class VisualMap include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An ECharts visual map of type 'piecewise' contain many pieces. Each # piece has a min, max, and color with which it's rendered. # @!attribute [rw] min # @return [::Integer] # Optional. Minimum value for the piece. # @!attribute [rw] max # @return [::Integer] # Optional. Minimum value for the piece. # @!attribute [rw] color # @return [::String] # Optional. Color to render the piece in when the value is between min # and max. # @!attribute [rw] label # @return [::String] # Optional. Label used in visual map controller. class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#visual_map_type ⇒ ::Google::Cloud::Chronicle::V1::VisualMapType
Returns Optional. Contains one of the valid visual map types such as 'continuous' or 'piecewise'.
504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 504 class VisualMap include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An ECharts visual map of type 'piecewise' contain many pieces. Each # piece has a min, max, and color with which it's rendered. # @!attribute [rw] min # @return [::Integer] # Optional. Minimum value for the piece. # @!attribute [rw] max # @return [::Integer] # Optional. Minimum value for the piece. # @!attribute [rw] color # @return [::String] # Optional. Color to render the piece in when the value is between min # and max. # @!attribute [rw] label # @return [::String] # Optional. Label used in visual map controller. class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |