Class: Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap::VisualMapPiece
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardChart::Visualization::VisualMap::VisualMapPiece
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb
Overview
An ECharts visual map of type 'piecewise' contain many pieces. Each piece has a min, max, and color with which it's rendered.
Instance Attribute Summary collapse
-
#color ⇒ ::String
Optional.
-
#label ⇒ ::String
Optional.
-
#max ⇒ ::Integer
Optional.
-
#min ⇒ ::Integer
Optional.
Instance Attribute Details
#color ⇒ ::String
Returns Optional. Color to render the piece in when the value is between min and max.
523 524 525 526 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 523 class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#label ⇒ ::String
Returns Optional. Label used in visual map controller.
523 524 525 526 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 523 class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max ⇒ ::Integer
Returns Optional. Minimum value for the piece.
523 524 525 526 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 523 class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min ⇒ ::Integer
Returns Optional. Minimum value for the piece.
523 524 525 526 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_chart.rb', line 523 class VisualMapPiece include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |