Class: Google::Cloud::Chronicle::V1::DashboardDefinition
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardDefinition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/native_dashboard.rb
Overview
Definition of the dashboard including filters, layout, charts' configurations.
Defined Under Namespace
Classes: ChartConfig
Instance Attribute Summary collapse
-
#charts ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardDefinition::ChartConfig>
Charts in the dashboard.
-
#filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardFilter>
Filters for the dashboard.
-
#fingerprint ⇒ ::String
Fingerprint of the dashboard definition.
Instance Attribute Details
#charts ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardDefinition::ChartConfig>
Returns Charts in the dashboard.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 422 class DashboardDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of the chart including chart reference, layout and filters. # @!attribute [r] dashboard_chart # @return [::String] # @!attribute [rw] chart_layout # @return [::Google::Cloud::Chronicle::V1::DashboardDefinition::ChartConfig::ChartLayout] # @!attribute [rw] filters_ids # @return [::Array<::String>] # Dashboard filters applied to the chart. class ChartConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Layout of the chart. # @!attribute [rw] start_x # @return [::Integer] # @!attribute [rw] span_x # @return [::Integer] # @!attribute [rw] start_y # @return [::Integer] # @!attribute [rw] span_y # @return [::Integer] class ChartLayout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardFilter>
Returns Filters for the dashboard.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 422 class DashboardDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of the chart including chart reference, layout and filters. # @!attribute [r] dashboard_chart # @return [::String] # @!attribute [rw] chart_layout # @return [::Google::Cloud::Chronicle::V1::DashboardDefinition::ChartConfig::ChartLayout] # @!attribute [rw] filters_ids # @return [::Array<::String>] # Dashboard filters applied to the chart. class ChartConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Layout of the chart. # @!attribute [rw] start_x # @return [::Integer] # @!attribute [rw] span_x # @return [::Integer] # @!attribute [rw] start_y # @return [::Integer] # @!attribute [rw] span_y # @return [::Integer] class ChartLayout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#fingerprint ⇒ ::String
Returns Fingerprint of the dashboard definition.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'proto_docs/google/cloud/chronicle/v1/native_dashboard.rb', line 422 class DashboardDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of the chart including chart reference, layout and filters. # @!attribute [r] dashboard_chart # @return [::String] # @!attribute [rw] chart_layout # @return [::Google::Cloud::Chronicle::V1::DashboardDefinition::ChartConfig::ChartLayout] # @!attribute [rw] filters_ids # @return [::Array<::String>] # Dashboard filters applied to the chart. class ChartConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Layout of the chart. # @!attribute [rw] start_x # @return [::Integer] # @!attribute [rw] span_x # @return [::Integer] # @!attribute [rw] start_y # @return [::Integer] # @!attribute [rw] span_y # @return [::Integer] class ChartLayout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |