Class: Google::Cloud::Chronicle::V1::DashboardQuery
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DashboardQuery
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_query.rb
Overview
DashboardQuery resource.
Defined Under Namespace
Classes: Input
Instance Attribute Summary collapse
-
#dashboard_chart ⇒ ::String
readonly
Output only.
-
#etag ⇒ ::String
Optional.
-
#input ⇒ ::Google::Cloud::Chronicle::V1::DashboardQuery::Input
Required.
-
#name ⇒ ::String
readonly
Output only.
-
#query ⇒ ::String
Required.
Instance Attribute Details
#dashboard_chart ⇒ ::String (readonly)
Returns Output only. DashboardChart this query belongs to.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 42 class DashboardQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input to the query like time window. # @!attribute [rw] time_window # @return [::Google::Type::Interval] # time range to fetch the data for. # # Note: The following fields are mutually exclusive: `time_window`, `relative_time`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] relative_time # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime] # time range for last x units. # # Note: The following fields are mutually exclusive: `relative_time`, `time_window`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Input include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # time representation for last x units. # @!attribute [rw] time_unit # @return [::Google::Cloud::Chronicle::V1::TimeUnit] # @!attribute [rw] start_time_val # @return [::Integer] class RelativeTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#etag ⇒ ::String
Returns Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 42 class DashboardQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input to the query like time window. # @!attribute [rw] time_window # @return [::Google::Type::Interval] # time range to fetch the data for. # # Note: The following fields are mutually exclusive: `time_window`, `relative_time`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] relative_time # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime] # time range for last x units. # # Note: The following fields are mutually exclusive: `relative_time`, `time_window`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Input include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # time representation for last x units. # @!attribute [rw] time_unit # @return [::Google::Cloud::Chronicle::V1::TimeUnit] # @!attribute [rw] start_time_val # @return [::Integer] class RelativeTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#input ⇒ ::Google::Cloud::Chronicle::V1::DashboardQuery::Input
Returns Required. Inputs to the query.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 42 class DashboardQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input to the query like time window. # @!attribute [rw] time_window # @return [::Google::Type::Interval] # time range to fetch the data for. # # Note: The following fields are mutually exclusive: `time_window`, `relative_time`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] relative_time # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime] # time range for last x units. # # Note: The following fields are mutually exclusive: `relative_time`, `time_window`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Input include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # time representation for last x units. # @!attribute [rw] time_unit # @return [::Google::Cloud::Chronicle::V1::TimeUnit] # @!attribute [rw] start_time_val # @return [::Integer] class RelativeTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#name ⇒ ::String (readonly)
Returns Output only. Name of the dashboardQuery.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 42 class DashboardQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input to the query like time window. # @!attribute [rw] time_window # @return [::Google::Type::Interval] # time range to fetch the data for. # # Note: The following fields are mutually exclusive: `time_window`, `relative_time`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] relative_time # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime] # time range for last x units. # # Note: The following fields are mutually exclusive: `relative_time`, `time_window`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Input include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # time representation for last x units. # @!attribute [rw] time_unit # @return [::Google::Cloud::Chronicle::V1::TimeUnit] # @!attribute [rw] start_time_val # @return [::Integer] class RelativeTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#query ⇒ ::String
Returns Required. Search query string.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 42 class DashboardQuery include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Input to the query like time window. # @!attribute [rw] time_window # @return [::Google::Type::Interval] # time range to fetch the data for. # # Note: The following fields are mutually exclusive: `time_window`, `relative_time`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] relative_time # @return [::Google::Cloud::Chronicle::V1::DashboardQuery::Input::RelativeTime] # time range for last x units. # # Note: The following fields are mutually exclusive: `relative_time`, `time_window`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Input include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # time representation for last x units. # @!attribute [rw] time_unit # @return [::Google::Cloud::Chronicle::V1::TimeUnit] # @!attribute [rw] start_time_val # @return [::Integer] class RelativeTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |