Class: Google::Cloud::Chronicle::V1::DataAccessControlService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataAccessControlService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/data_access_control_service/client.rb
Overview
Client for the DataAccessControlService service.
DataAccessControlService exposes resources and endpoints related to data access control.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client instance.
-
#create_data_access_label(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Creates a data access label.
-
#create_data_access_scope(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Creates a data access scope.
-
#delete_data_access_label(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a data access label.
-
#delete_data_access_scope(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a data access scope.
-
#get_data_access_label(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Gets a data access label.
-
#get_data_access_scope(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Retrieves an existing data access scope.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new DataAccessControlService client object.
-
#list_data_access_labels(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>
Lists all data access labels for the customer.
-
#list_data_access_scopes(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>
Lists all existing data access scopes for the customer.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_data_access_label(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Updates a data access label.
-
#update_data_access_scope(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Updates a data access scope.
Methods included from Paths
#data_access_label_path, #data_access_scope_path, #instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new DataAccessControlService client object.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 157 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/chronicle/v1/data_access_control_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @data_access_control_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Chronicle::V1::DataAccessControlService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @data_access_control_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client class.
See Configuration for a description of the configuration fields.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_data_access_label.timeout = 60.0 default_config.rpcs.get_data_access_label.timeout = 60.0 default_config.rpcs.get_data_access_label.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_data_access_labels.timeout = 60.0 default_config.rpcs.list_data_access_labels.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_access_label.timeout = 60.0 default_config.rpcs.delete_data_access_label.timeout = 60.0 default_config.rpcs.create_data_access_scope.timeout = 60.0 default_config.rpcs.get_data_access_scope.timeout = 60.0 default_config.rpcs.get_data_access_scope.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_data_access_scopes.timeout = 60.0 default_config.rpcs.list_data_access_scopes.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_access_scope.timeout = 60.0 default_config.rpcs.delete_data_access_scope.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
127 128 129 130 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 127 def configure yield @config if block_given? @config end |
#create_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #create_data_access_label(parent: nil, data_access_label: nil, data_access_label_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Creates a data access label. Data access labels are applied to incoming event data and selected in data access scopes (another resource), and only users with scopes containing the label can see data with that label. Currently, the data access label resource only includes custom labels, which are labels that correspond to UDM queries over event data.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 276 def create_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.create_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :create_data_access_label, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#create_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #create_data_access_scope(parent: nil, data_access_scope: nil, data_access_scope_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Creates a data access scope. Data access scope is a combination of allowed and denied labels attached to a permission group. If a scope has allowed labels A and B and denied labels C and D, then the group of people attached to the scope will have permissions to see all events labeled with A or B (or both) and not labeled with either C or D.
749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 749 def create_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.create_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :create_data_access_scope, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_access_label(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_label(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a data access label. When a label is deleted, new data that enters in the system will not receive the label, but the label will not be removed from old data that still refers to it.
652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 652 def delete_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.delete_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :delete_data_access_label, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_access_scope(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_scope(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a data access scope.
1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 1124 def delete_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.delete_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :delete_data_access_scope, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #get_data_access_label(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Gets a data access label.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 363 def get_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.get_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :get_data_access_label, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #get_data_access_scope(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Retrieves an existing data access scope.
836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 836 def get_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.get_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :get_data_access_scope, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_access_labels(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel> #list_data_access_labels(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>
Lists all data access labels for the customer.
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 467 def list_data_access_labels request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_access_labels..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_data_access_labels.timeout, metadata: , retry_policy: @config.rpcs.list_data_access_labels.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :list_data_access_labels, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_labels, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_access_scopes(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope> #list_data_access_scopes(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>
Lists all existing data access scopes for the customer.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 940 def list_data_access_scopes request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessScopesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_access_scopes..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_data_access_scopes.timeout, metadata: , retry_policy: @config.rpcs.list_data_access_scopes.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :list_data_access_scopes, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_scopes, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
213 214 215 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 213 def logger @data_access_control_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
137 138 139 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 137 def universe_domain @data_access_control_service_stub.universe_domain end |
#update_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #update_data_access_label(data_access_label: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Updates a data access label.
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 563 def update_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.data_access_label&.name header_params["data_access_label.name"] = request.data_access_label.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.update_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :update_data_access_label, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #update_data_access_scope(data_access_scope: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Updates a data access scope.
1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/client.rb', line 1037 def update_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.data_access_scope&.name header_params["data_access_scope.name"] = request.data_access_scope.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.update_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.call_rpc :update_data_access_scope, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |