Class: Google::Cloud::Chronicle::V1::DataAccessControlService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataAccessControlService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb
Overview
REST client for the DataAccessControlService service.
DataAccessControlService exposes resources and endpoints related to data access control.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client instance.
-
#create_data_access_label(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Creates a data access label.
-
#create_data_access_scope(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Creates a data access scope.
-
#delete_data_access_label(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a data access label.
-
#delete_data_access_scope(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes a data access scope.
-
#get_data_access_label(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Gets a data access label.
-
#get_data_access_scope(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Retrieves an existing data access scope.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new DataAccessControlService REST client object.
-
#list_data_access_labels(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>
Lists all data access labels for the customer.
-
#list_data_access_scopes(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>
Lists all existing data access scopes for the customer.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_data_access_label(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Updates a data access label.
-
#update_data_access_scope(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Updates a data access scope.
Methods included from Paths
#data_access_label_path, #data_access_scope_path, #instance_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new DataAccessControlService REST client object.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 159 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @data_access_control_service_stub = ::Google::Cloud::Chronicle::V1::DataAccessControlService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @data_access_control_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_data_access_label.timeout = 60.0 default_config.rpcs.get_data_access_label.timeout = 60.0 default_config.rpcs.get_data_access_label.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_data_access_labels.timeout = 60.0 default_config.rpcs.list_data_access_labels.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_access_label.timeout = 60.0 default_config.rpcs.delete_data_access_label.timeout = 60.0 default_config.rpcs.create_data_access_scope.timeout = 60.0 default_config.rpcs.get_data_access_scope.timeout = 60.0 default_config.rpcs.get_data_access_scope.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_data_access_scopes.timeout = 60.0 default_config.rpcs.list_data_access_scopes.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_data_access_scope.timeout = 60.0 default_config.rpcs.delete_data_access_scope.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the DataAccessControlService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
129 130 131 132 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 129 def configure yield @config if block_given? @config end |
#create_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #create_data_access_label(parent: nil, data_access_label: nil, data_access_label_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Creates a data access label. Data access labels are applied to incoming event data and selected in data access scopes (another resource), and only users with scopes containing the label can see data with that label. Currently, the data access label resource only includes custom labels, which are labels that correspond to UDM queries over event data.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 268 def create_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.create_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.create_data_access_label request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#create_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #create_data_access_scope(parent: nil, data_access_scope: nil, data_access_scope_id: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Creates a data access scope. Data access scope is a combination of allowed and denied labels attached to a permission group. If a scope has allowed labels A and B and denied labels C and D, then the group of people attached to the scope will have permissions to see all events labeled with A or B (or both) and not labeled with either C or D.
706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 706 def create_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.create_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.create_data_access_scope request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_access_label(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_label(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a data access label. When a label is deleted, new data that enters in the system will not receive the label, but the label will not be removed from old data that still refers to it.
616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 616 def delete_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.delete_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.delete_data_access_label request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_data_access_scope(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_data_access_scope(name: nil) ⇒ ::Google::Protobuf::Empty
Deletes a data access scope.
1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 1053 def delete_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::DeleteDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.delete_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.delete_data_access_scope request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #get_data_access_label(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Gets a data access label.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 348 def get_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.get_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.get_data_access_label request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #get_data_access_scope(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Retrieves an existing data access scope.
786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 786 def get_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.get_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.get_data_access_scope request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_access_labels(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel> #list_data_access_labels(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessLabel>
Lists all data access labels for the customer.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 445 def list_data_access_labels request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_access_labels..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_data_access_labels.timeout, metadata: , retry_policy: @config.rpcs.list_data_access_labels.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.list_data_access_labels request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_labels, "data_access_labels", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_data_access_scopes(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope> #list_data_access_scopes(parent: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::DataAccessScope>
Lists all existing data access scopes for the customer.
883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 883 def list_data_access_scopes request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListDataAccessScopesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_data_access_scopes..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_data_access_scopes.timeout, metadata: , retry_policy: @config.rpcs.list_data_access_scopes.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.list_data_access_scopes request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @data_access_control_service_stub, :list_data_access_scopes, "data_access_scopes", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
206 207 208 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 206 def logger @data_access_control_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
139 140 141 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 139 def universe_domain @data_access_control_service_stub.universe_domain end |
#update_data_access_label(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel #update_data_access_label(data_access_label: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessLabel
Updates a data access label.
534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 534 def update_data_access_label request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessLabelRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_access_label..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_data_access_label.timeout, metadata: , retry_policy: @config.rpcs.update_data_access_label.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.update_data_access_label request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_data_access_scope(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope #update_data_access_scope(data_access_scope: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::DataAccessScope
Updates a data access scope.
973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/google/cloud/chronicle/v1/data_access_control_service/rest/client.rb', line 973 def update_data_access_scope request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateDataAccessScopeRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_data_access_scope..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_data_access_scope.timeout, metadata: , retry_policy: @config.rpcs.update_data_access_scope.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @data_access_control_service_stub.update_data_access_scope request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |