Class: Google::Cloud::Chronicle::V1::DataAccessLabel
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataAccessLabel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
A DataAccessLabel is a label on events to define user access to data.
Instance Attribute Summary collapse
-
#author ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
readonly
Output only.
-
#last_editor ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
The unique resource name of the data access label.
-
#udm_query ⇒ ::String
A UDM query over event data.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#author ⇒ ::String (readonly)
Returns Output only. The user who created the data access label.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the data access label was created.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#description ⇒ ::String
Returns Optional. A description of the data access label for a human reader.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String (readonly)
Returns Output only. The short name displayed for the label as it appears on event data.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_editor ⇒ ::String (readonly)
Returns Output only. The user who last updated the data access label.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns The unique resource name of the data access label.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#udm_query ⇒ ::String
Returns A UDM query over event data.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time at which the data access label was last updated.
253 254 255 256 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 253 class DataAccessLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |