Class: Google::Cloud::Chronicle::V1::DataSourceExportSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataSourceExportSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/big_query_export.rb
Overview
The export settings for a data source.
Instance Attribute Summary collapse
-
#data_freshness_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#data_volume ⇒ ::Integer
readonly
Output only.
-
#enabled ⇒ ::Boolean
Required.
-
#latest_export_job_state ⇒ ::Google::Cloud::Chronicle::V1::LatestExportJobState
readonly
Output only.
-
#retention_days ⇒ ::Integer
Required.
Instance Attribute Details
#data_freshness_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The data freshness of the given export which represents the time bucket at which the latest event was exported.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 76 class DataSourceExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_volume ⇒ ::Integer (readonly)
Returns Output only. The stored data volume of all the exports.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 76 class DataSourceExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enabled ⇒ ::Boolean
Returns Required. Whether the data source is enabled for export.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 76 class DataSourceExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#latest_export_job_state ⇒ ::Google::Cloud::Chronicle::V1::LatestExportJobState (readonly)
Returns Output only. The state of the latest data source export job.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 76 class DataSourceExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#retention_days ⇒ ::Integer
Returns Required. The retention period for the data source in days.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/big_query_export.rb', line 76 class DataSourceExportSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |