Class: Google::Cloud::Chronicle::V1::DataTableColumnInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DataTableColumnInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_table.rb
Overview
DataTableColumnInfo represents the column metadata of the datatable. The column_index represents the ordering of the values in DataTableRow.
Defined Under Namespace
Modules: DataTableColumnType
Instance Attribute Summary collapse
-
#column_index ⇒ ::Integer
Required.
-
#column_type ⇒ ::Google::Cloud::Chronicle::V1::DataTableColumnInfo::DataTableColumnType
Column type can be STRING, CIDR (Ex- 10.1.1.0/24), REGEX.
-
#key_column ⇒ ::Boolean
Optional.
-
#mapped_column_path ⇒ ::String
Entity proto field path that the column is mapped to.
-
#original_column ⇒ ::String
Required.
-
#repeated_values ⇒ ::Boolean
Optional.
Instance Attribute Details
#column_index ⇒ ::Integer
Returns Required. Column Index. 0,1,2...
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |
#column_type ⇒ ::Google::Cloud::Chronicle::V1::DataTableColumnInfo::DataTableColumnType
Returns Column type can be STRING, CIDR (Ex- 10.1.1.0/24), REGEX
Note: The following fields are mutually exclusive: column_type, mapped_column_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |
#key_column ⇒ ::Boolean
Returns Optional. Whether to include this column in the calculation of the row ID. If no columns have key_column = true, all columns will be included in the calculation of the row ID.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |
#mapped_column_path ⇒ ::String
Returns Entity proto field path that the column is mapped to
Note: The following fields are mutually exclusive: mapped_column_path, column_type. If a field in that set is populated, all other fields in the set will automatically be cleared.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |
#original_column ⇒ ::String
Returns Required. Original column name of the Data Table (present in the CSV header in case of creation of data tables using file uploads). It must satisfy the following requirements:
- Starts with letter.
- Contains only letters, numbers and underscore.
- Must be unique and has length < 256.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |
#repeated_values ⇒ ::Boolean
Returns Optional. Whether the column is a repeated values column.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 445 class DataTableColumnInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # DataTableColumnType denotes the type of the column to be referenced in the # rule. module DataTableColumnType # The default Data Table Column Type. DATA_TABLE_COLUMN_TYPE_UNSPECIFIED = 0 # Denotes the type of the column as STRING. STRING = 1 # Denotes the type of the column as REGEX. REGEX = 2 # Denotes the type of the column as CIDR. CIDR = 3 # Denotes the type of the column as NUMBER (includes int and float). NUMBER = 4 end end |