Class: Google::Cloud::Chronicle::V1::DeleteRuleRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DeleteRuleRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Request message for the DeleteRule method.
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. If set to true, any retrohunts and any detections associated with the rule will also be deleted. If set to false, the call will only succeed if the rule has no associated retrohunts, including completed retrohunts, and no associated detections. Regardless of this field's value, the rule deployment associated with this rule will also be deleted.
364 365 366 367 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 364 class DeleteRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the rule to delete. A rule revision timestamp cannot
be specified as part of the name, as deleting specific revisions is not
supported.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.
364 365 366 367 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 364 class DeleteRuleRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |