Class: Google::Cloud::Chronicle::V1::DetectionExclusionActivity::DetectionExclusionDetectorActivity
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DetectionExclusionActivity::DetectionExclusionDetectorActivity
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
The activity for a findings refinement that is a detection exclusion broken down for one specific detector.
Instance Attribute Summary collapse
-
#curated_rule ⇒ ::String
Full resource name for the curated rule this activity corresponds to.
-
#curated_rule_set ⇒ ::String
Full resource name for the curated rule set this activity corresponds to.
-
#deleted_curated_rule_set ⇒ ::String
Full resource name for the deleted curated rule set this activity corresponds to.
-
#excluded_detection_count ⇒ ::Integer
The number of detections for the detector that were excluded by the detection exclusion.
-
#rule ⇒ ::String
Full resource name for the rule this activity corresponds to.
-
#total_detection_count ⇒ ::Integer
The total number of detections found by the detector.
Instance Attribute Details
#curated_rule ⇒ ::String
Returns Full resource name for the curated rule this activity corresponds to. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRules/{rule}
Note: The following fields are mutually exclusive: curated_rule, curated_rule_set, rule, deleted_curated_rule_set. If a field in that set is populated, all other fields in the set will automatically be cleared.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#curated_rule_set ⇒ ::String
Returns Full resource name for the curated rule set this activity corresponds to. This field will only be set if the customer has access to the curated rule set the exclusion is applied to. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRuleSetCategories/{curated_rule_set_category}/curatedRuleSets/{curated_rule_set}
Note: The following fields are mutually exclusive: curated_rule_set, curated_rule, rule, deleted_curated_rule_set. If a field in that set is populated, all other fields in the set will automatically be cleared.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deleted_curated_rule_set ⇒ ::String
Returns Full resource name for the deleted curated rule set this activity corresponds to. This field will only be set if the customer does not have access to the curated rule set the exclusion is applied to. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRuleSetCategories/{curated_rule_set_category}/curatedRuleSets/{curated_rule_set}
Note: The following fields are mutually exclusive: deleted_curated_rule_set, curated_rule, curated_rule_set, rule. If a field in that set is populated, all other fields in the set will automatically be cleared.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#excluded_detection_count ⇒ ::Integer
Returns The number of detections for the detector that were excluded by the detection exclusion.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rule ⇒ ::String
Returns Full resource name for the rule this activity corresponds to. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}
Note: The following fields are mutually exclusive: rule, curated_rule, curated_rule_set, deleted_curated_rule_set. If a field in that set is populated, all other fields in the set will automatically be cleared.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_detection_count ⇒ ::Integer
Returns The total number of detections found by the detector. This includes both excluded detections and non-excluded detections.
183 184 185 186 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 183 class DetectionExclusionDetectorActivity include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |