Class: Google::Cloud::Chronicle::V1::DetectionExclusionApplication
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::DetectionExclusionApplication
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Describes the detectors a detection exclusion is applied to.
Instance Attribute Summary collapse
-
#curated_rule_sets ⇒ ::Array<::String>
The CuratedRuleSets this detection exclusion applies to.
-
#curated_rules ⇒ ::Array<::String>
The CuratedRules this detection exclusion applies to.
-
#deleted_curated_rule_sets ⇒ ::Array<::String>
readonly
Output only.
-
#rules ⇒ ::Array<::String>
Optional.
Instance Attribute Details
#curated_rule_sets ⇒ ::Array<::String>
Returns The CuratedRuleSets this detection exclusion applies to. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRuleSetCategories/{category}/curatedRuleSets/{rule_set}.
113 114 115 116 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 113 class DetectionExclusionApplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#curated_rules ⇒ ::Array<::String>
Returns The CuratedRules this detection exclusion applies to. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRules/{rule}.
113 114 115 116 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 113 class DetectionExclusionApplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deleted_curated_rule_sets ⇒ ::Array<::String> (readonly)
Returns Output only. The deleted CuratedRuleSets this detection exclusion applies to. Indicates to the customer that the detection exclusion no longer applies to the rule sets, so the detection exclusion should be updated. Format: projects/{project}/locations/{location}/instances/{instance}/curatedRuleSetCategories/{category}/curatedRuleSets/{rule_set}.
113 114 115 116 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 113 class DetectionExclusionApplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rules ⇒ ::Array<::String>
Returns Optional. The Rules this detection exclusion applies to. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.
113 114 115 116 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 113 class DetectionExclusionApplication include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |