Class: Google::Cloud::Chronicle::V1::ExecuteDashboardQueryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ExecuteDashboardQueryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_query.rb
Overview
Request message to execute a dashboard query.
Instance Attribute Summary collapse
-
#clear_cache ⇒ ::Boolean
Optional.
-
#filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardFilter>
Optional.
-
#parent ⇒ ::String
Required.
-
#query ⇒ ::Google::Cloud::Chronicle::V1::DashboardQuery
Required.
-
#use_previous_time_range ⇒ ::Boolean
Optional.
Instance Attribute Details
#clear_cache ⇒ ::Boolean
Returns Optional. When true, the backend would read from the database, rather than fetching data directly from the cache.
106 107 108 109 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 106 class ExecuteDashboardQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::DashboardFilter>
Returns Optional. Dashboard level filters other than query string.
106 107 108 109 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 106 class ExecuteDashboardQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, under which to run this dashboardQuery. Format: projects/{project}/locations/{location}/instances/{instance}.
106 107 108 109 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 106 class ExecuteDashboardQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::Google::Cloud::Chronicle::V1::DashboardQuery
Returns Required. The query to execute and get results back for. QueryID or 'query', 'input.time_window' fields will be used. Use 'native_dashboard' and 'dashboard_chart' fields if it is an in-dashboard query.
106 107 108 109 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 106 class ExecuteDashboardQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_previous_time_range ⇒ ::Boolean
Returns Optional. When true, the backend will execute the query against the previous time range of the query.
106 107 108 109 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 106 class ExecuteDashboardQueryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |