Class: Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/dashboard_query.rb
Overview
Response message for executing a dashboard query.
Defined Under Namespace
Classes: ColumnData, ColumnType, ColumnValue
Instance Attribute Summary collapse
-
#data_sources ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataSource>
Datasource of the query and results.
-
#language_features ⇒ ::Array<::Google::Cloud::Chronicle::V1::LanguageFeature>
Optional.
-
#last_backend_cache_refreshed_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#query_runtime_errors ⇒ ::Array<::Google::Cloud::Chronicle::V1::QueryRuntimeError>
Runtime errors.
-
#results ⇒ ::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnData>
Result rows that are queried.
-
#time_window ⇒ ::Google::Type::Interval
Time window against which query was executed.
Instance Attribute Details
#data_sources ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataSource>
Returns Datasource of the query and results.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#language_features ⇒ ::Array<::Google::Cloud::Chronicle::V1::LanguageFeature>
Returns Optional. Language features found in the query.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#last_backend_cache_refreshed_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Last time the cache was refreshed. This would be used by the UI to show the last updated time.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#query_runtime_errors ⇒ ::Array<::Google::Cloud::Chronicle::V1::QueryRuntimeError>
Returns Runtime errors.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#results ⇒ ::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnData>
Returns Result rows that are queried.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#time_window ⇒ ::Google::Type::Interval
Returns Time window against which query was executed.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'proto_docs/google/cloud/chronicle/v1/dashboard_query.rb', line 200 class ExecuteDashboardQueryResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LINT.IfChange(stats_data) # Value of the column based on data type. # @!attribute [rw] null_val # @return [::Boolean] # True if the value is NULL. # # Note: The following fields are mutually exclusive: `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bool_val # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `bool_val`, `null_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] bytes_val # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `bytes_val`, `null_val`, `bool_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] double_val # @return [::Float] # Double value. # # Note: The following fields are mutually exclusive: `double_val`, `null_val`, `bool_val`, `bytes_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] int64_val # @return [::Integer] # Integer value (signed). # # Note: The following fields are mutually exclusive: `int64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] uint64_val # @return [::Integer] # Un-signed integer value. # # Note: The following fields are mutually exclusive: `uint64_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `string_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] string_val # @return [::String] # String value. Enum values are returned as strings. # # Note: The following fields are mutually exclusive: `string_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `timestamp_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp values. Does not handle `interval`. # # Note: The following fields are mutually exclusive: `timestamp_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `date_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] date_val # @return [::Google::Type::Date] # Date values. # # Note: The following fields are mutually exclusive: `date_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `proto_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] proto_val # @return [::Google::Protobuf::Any] # For any proto values that are not any of the above. # # Note: The following fields are mutually exclusive: `proto_val`, `null_val`, `bool_val`, `bytes_val`, `double_val`, `int64_val`, `uint64_val`, `string_val`, `timestamp_val`, `date_val`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue::ValueMetadata] class ColumnValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] links # @return [::Array<::Google::Cloud::Chronicle::V1::InAppLink>] # "Auto" generated In-app links. # @!attribute [rw] field_paths # @return [::Array<::String>] # @!attribute [rw] timestamp_val # @return [::Google::Protobuf::Timestamp] # Timestamp value to store the timestamp for the case of the date and # time data type. class ValueMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Singular vs list of values in a column. # @!attribute [rw] value # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue] # Single value in a column. # # Note: The following fields are mutually exclusive: `value`, `list`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] list # @return [::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType::List] # List of values in a column e.g. IPs # # Note: The following fields are mutually exclusive: `list`, `value`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ColumnType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Store list of values in a column. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnValue>] class List include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] column # @return [::String] # Used to store column names. # @!attribute [rw] values # @return [::Array<::Google::Cloud::Chronicle::V1::ExecuteDashboardQueryResponse::ColumnType>] # To store column data. # @!attribute [rw] metadata # @return [::Google::Cloud::Chronicle::V1::ColumnMetadata] # To store column metadata. class ColumnData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |