Class: Google::Cloud::Chronicle::V1::FeaturedContentMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::FeaturedContentMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb
Overview
FeaturedContentMetadata holds metadata about the Featured Content.
Defined Under Namespace
Modules: ContentSourceType
Instance Attribute Summary collapse
-
#author ⇒ ::String
readonly
Output only.
-
#categories ⇒ ::Array<::String>
readonly
Output only.
-
#certified ⇒ ::Boolean
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
readonly
Output only.
-
#id ⇒ ::String
Required.
-
#source_type ⇒ ::Google::Cloud::Chronicle::V1::FeaturedContentMetadata::ContentSourceType
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#verified ⇒ ::Boolean
readonly
Output only.
-
#version ⇒ ::String
readonly
Output only.
Instance Attribute Details
#author ⇒ ::String (readonly)
Returns Output only. Content item author full name.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#categories ⇒ ::Array<::String> (readonly)
Returns Output only. Categories the content is associated with.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#certified ⇒ ::Boolean (readonly)
Returns Output only. Determine if this content item is officially certified by Google or created by the community.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp indicating when the item was created.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#description ⇒ ::String (readonly)
Returns Output only. The description of the content item.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#display_name ⇒ ::String (readonly)
Returns Output only. The display name of the featured content.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#id ⇒ ::String
Returns Required. Unique identifier of the featured content.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#source_type ⇒ ::Google::Cloud::Chronicle::V1::FeaturedContentMetadata::ContentSourceType (readonly)
Returns Output only. The source type of the content.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp indicating when the item was updated.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#verified ⇒ ::Boolean (readonly)
Returns Output only. Whether the content is verified by Google (applicable for 3rd party content).
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |
#version ⇒ ::String (readonly)
Returns Output only. Featured content version (Major.Minor.Patch).
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_metadata.rb', line 60 class FeaturedContentMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # ContentSourceType specifying the content source of origin module ContentSourceType # Unspecified content source type CONTENT_SOURCE_TYPE_UNSPECIFIED = 0 # Certified Google content source type GOOGLE = 1 # Community content source type COMMUNITY = 2 # Partner content source type PARTNER = 3 end end |