Class: Google::Cloud::Chronicle::V1::FindingsRefinement
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::FindingsRefinement
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Represents a set of logic conditions used to refine various types of findings such as curated rule detections.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Display name of the findings refinement.
-
#name ⇒ ::String
Full resource name for the findings refinement.
-
#outcome_filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::OutcomeFilter>
Optional.
-
#query ⇒ ::String
The query for the findings refinement.
-
#type ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementType
The type of findings refinement.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the findings refinement was created.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Display name of the findings refinement.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Full resource name for the findings refinement. Format: projects/{project}/locations/{region}/instances/{instance}/findingsRefinements/{findings_refinement}.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#outcome_filters ⇒ ::Array<::Google::Cloud::Chronicle::V1::OutcomeFilter>
Returns Optional. The outcome filters for the findings refinement. These allow you to specify filters that are applied to the outcome variables in the detection. All filters must be true for a detection to match the findings refinement.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::String
Returns The query for the findings refinement. Works in conjunction with the type field to determine the findings refinement behavior. The syntax of this query is the same as a UDM search string. See the following for more information: https://cloud.google.com/chronicle/docs/investigation/udm-search.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementType
Returns The type of findings refinement.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the findings refinement was last updated.
57 58 59 60 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 57 class FindingsRefinement include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |