Class: Google::Cloud::Chronicle::V1::FindingsRefinementService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::FindingsRefinementService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb
Overview
Client for the FindingsRefinementService service.
FindingsRefinementService provides an interface for filtering out findings that are unlikely to be real threats to prevent them from triggering alerts or notifications.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client class.
Instance Method Summary collapse
-
#compute_all_findings_refinement_activities(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse
Returns findings refinement activity for all findings refinements.
-
#compute_findings_refinement_activity(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse
Returns findings refinement activity for a specific findings refinement.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client instance.
-
#create_findings_refinement(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Creates a new findings refinement.
-
#get_findings_refinement(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Gets a single findings refinement.
-
#get_findings_refinement_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Gets a findings refinement deployment.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new FindingsRefinementService client object.
-
#list_all_findings_refinement_deployments(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
Lists all findings refinement deployments.
-
#list_findings_refinements(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>
Lists a collection of findings refinements.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_findings_refinement(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Updates a findings refinement.
-
#update_findings_refinement_deployment(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Updates a findings refinement deployment.
Methods included from Paths
#curated_rule_path, #curated_rule_set_path, #findings_refinement_deployment_path, #findings_refinement_path, #instance_path, #rule_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new FindingsRefinementService client object.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 168 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/chronicle/v1/findings_refinement_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @findings_refinement_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @findings_refinement_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client class.
See Configuration for a description of the configuration fields.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 64 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_findings_refinement.timeout = 60.0 default_config.rpcs.get_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_findings_refinements.timeout = 60.0 default_config.rpcs.list_findings_refinements.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_findings_refinement.timeout = 60.0 default_config.rpcs.create_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_findings_refinement.timeout = 60.0 default_config.rpcs.update_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_findings_refinement_deployment.timeout = 120.0 default_config.rpcs.get_findings_refinement_deployment.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_findings_refinement_deployment.timeout = 120.0 default_config.rpcs.list_all_findings_refinement_deployments.timeout = 120.0 default_config.rpcs.list_all_findings_refinement_deployments.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.compute_findings_refinement_activity.timeout = 600.0 default_config.rpcs.compute_findings_refinement_activity.retry_policy = { initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.compute_all_findings_refinement_activities.timeout = 600.0 default_config.rpcs.compute_all_findings_refinement_activities.retry_policy = { initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#compute_all_findings_refinement_activities(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse #compute_all_findings_refinement_activities(instance: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse
Returns findings refinement activity for all findings refinements.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 1029 def compute_all_findings_refinement_activities request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.compute_all_findings_refinement_activities..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.instance header_params["instance"] = request.instance end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.compute_all_findings_refinement_activities.timeout, metadata: , retry_policy: @config.rpcs.compute_all_findings_refinement_activities.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :compute_all_findings_refinement_activities, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#compute_findings_refinement_activity(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse #compute_findings_refinement_activity(name: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse
Returns findings refinement activity for a specific findings refinement.
940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 940 def compute_findings_refinement_activity request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.compute_findings_refinement_activity..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.compute_findings_refinement_activity.timeout, metadata: , retry_policy: @config.rpcs.compute_findings_refinement_activity.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :compute_findings_refinement_activity, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
138 139 140 141 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 138 def configure yield @config if block_given? @config end |
#create_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #create_findings_refinement(parent: nil, findings_refinement: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Creates a new findings refinement.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 466 def create_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.create_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :create_findings_refinement, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #get_findings_refinement(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Gets a single findings refinement.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 276 def get_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.get_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :get_findings_refinement, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #get_findings_refinement_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Gets a findings refinement deployment.
646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 646 def get_findings_refinement_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_findings_refinement_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_findings_refinement_deployment.timeout, metadata: , retry_policy: @config.rpcs.get_findings_refinement_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :get_findings_refinement_deployment, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_all_findings_refinement_deployments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment> #list_all_findings_refinement_deployments(instance: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
Lists all findings refinement deployments.
849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 849 def list_all_findings_refinement_deployments request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_all_findings_refinement_deployments..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.instance header_params["instance"] = request.instance end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_all_findings_refinement_deployments.timeout, metadata: , retry_policy: @config.rpcs.list_all_findings_refinement_deployments.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :list_all_findings_refinement_deployments, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @findings_refinement_service_stub, :list_all_findings_refinement_deployments, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_findings_refinements(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement> #list_findings_refinements(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>
Lists a collection of findings refinements.
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 375 def list_findings_refinements request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_findings_refinements..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_findings_refinements.timeout, metadata: , retry_policy: @config.rpcs.list_findings_refinements.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :list_findings_refinements, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @findings_refinement_service_stub, :list_findings_refinements, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
224 225 226 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 224 def logger @findings_refinement_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
148 149 150 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 148 def universe_domain @findings_refinement_service_stub.universe_domain end |
#update_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #update_findings_refinement(findings_refinement: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Updates a findings refinement.
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 559 def update_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.findings_refinement&.name header_params["findings_refinement.name"] = request.findings_refinement.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.update_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :update_findings_refinement, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #update_findings_refinement_deployment(findings_refinement_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Updates a findings refinement deployment.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/client.rb', line 739 def update_findings_refinement_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_findings_refinement_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.findings_refinement_deployment&.name header_params["findings_refinement_deployment.name"] = request.findings_refinement_deployment.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_findings_refinement_deployment.timeout, metadata: , retry_policy: @config.rpcs.update_findings_refinement_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.call_rpc :update_findings_refinement_deployment, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |