Class: Google::Cloud::Chronicle::V1::FindingsRefinementService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::FindingsRefinementService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb
Overview
REST client for the FindingsRefinementService service.
FindingsRefinementService provides an interface for filtering out findings that are unlikely to be real threats to prevent them from triggering alerts or notifications.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client class.
Instance Method Summary collapse
-
#compute_all_findings_refinement_activities(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse
Returns findings refinement activity for all findings refinements.
-
#compute_findings_refinement_activity(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse
Returns findings refinement activity for a specific findings refinement.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client instance.
-
#create_findings_refinement(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Creates a new findings refinement.
-
#get_findings_refinement(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Gets a single findings refinement.
-
#get_findings_refinement_deployment(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Gets a findings refinement deployment.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new FindingsRefinementService REST client object.
-
#list_all_findings_refinement_deployments(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
Lists all findings refinement deployments.
-
#list_findings_refinements(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>
Lists a collection of findings refinements.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_findings_refinement(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Updates a findings refinement.
-
#update_findings_refinement_deployment(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Updates a findings refinement deployment.
Methods included from Paths
#curated_rule_path, #curated_rule_set_path, #findings_refinement_deployment_path, #findings_refinement_path, #instance_path, #rule_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new FindingsRefinementService REST client object.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 170 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @findings_refinement_service_stub = ::Google::Cloud::Chronicle::V1::FindingsRefinementService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @findings_refinement_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client class.
See Configuration for a description of the configuration fields.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 66 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Chronicle", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_findings_refinement.timeout = 60.0 default_config.rpcs.get_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_findings_refinements.timeout = 60.0 default_config.rpcs.list_findings_refinements.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.create_findings_refinement.timeout = 60.0 default_config.rpcs.create_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_findings_refinement.timeout = 60.0 default_config.rpcs.update_findings_refinement.retry_policy = { initial_delay: 1.0, max_delay: 60.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.get_findings_refinement_deployment.timeout = 120.0 default_config.rpcs.get_findings_refinement_deployment.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.update_findings_refinement_deployment.timeout = 120.0 default_config.rpcs.list_all_findings_refinement_deployments.timeout = 120.0 default_config.rpcs.list_all_findings_refinement_deployments.retry_policy = { initial_delay: 1.0, max_delay: 120.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.compute_findings_refinement_activity.timeout = 600.0 default_config.rpcs.compute_findings_refinement_activity.retry_policy = { initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.compute_all_findings_refinement_activities.timeout = 600.0 default_config.rpcs.compute_all_findings_refinement_activities.retry_policy = { initial_delay: 1.0, max_delay: 600.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#compute_all_findings_refinement_activities(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse #compute_all_findings_refinement_activities(instance: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesResponse
Returns findings refinement activity for all findings refinements.
965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 965 def compute_all_findings_refinement_activities request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeAllFindingsRefinementActivitiesRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.compute_all_findings_refinement_activities..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.compute_all_findings_refinement_activities.timeout, metadata: , retry_policy: @config.rpcs.compute_all_findings_refinement_activities.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.compute_all_findings_refinement_activities request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#compute_findings_refinement_activity(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse #compute_findings_refinement_activity(name: nil, interval: nil) ⇒ ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityResponse
Returns findings refinement activity for a specific findings refinement.
883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 883 def compute_findings_refinement_activity request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ComputeFindingsRefinementActivityRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.compute_findings_refinement_activity..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.compute_findings_refinement_activity.timeout, metadata: , retry_policy: @config.rpcs.compute_findings_refinement_activity.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.compute_findings_refinement_activity request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the FindingsRefinementService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
140 141 142 143 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 140 def configure yield @config if block_given? @config end |
#create_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #create_findings_refinement(parent: nil, findings_refinement: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Creates a new findings refinement.
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 444 def create_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::CreateFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.create_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.create_findings_refinement request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #get_findings_refinement(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Gets a single findings refinement.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 268 def get_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.get_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.get_findings_refinement request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #get_findings_refinement_deployment(name: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Gets a findings refinement deployment.
610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 610 def get_findings_refinement_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::GetFindingsRefinementDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_findings_refinement_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_findings_refinement_deployment.timeout, metadata: , retry_policy: @config.rpcs.get_findings_refinement_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.get_findings_refinement_deployment request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_all_findings_refinement_deployments(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment> #list_all_findings_refinement_deployments(instance: nil, page_size: nil, page_token: nil, filter: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
Lists all findings refinement deployments.
799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 799 def list_all_findings_refinement_deployments request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_all_findings_refinement_deployments..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_all_findings_refinement_deployments.timeout, metadata: , retry_policy: @config.rpcs.list_all_findings_refinement_deployments.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.list_all_findings_refinement_deployments request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @findings_refinement_service_stub, :list_all_findings_refinement_deployments, "all_findings_refinement_deployments", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_findings_refinements(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement> #list_findings_refinements(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Chronicle::V1::FindingsRefinement>
Lists a collection of findings refinements.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 360 def list_findings_refinements request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::ListFindingsRefinementsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_findings_refinements..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_findings_refinements.timeout, metadata: , retry_policy: @config.rpcs.list_findings_refinements.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.list_findings_refinements request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @findings_refinement_service_stub, :list_findings_refinements, "findings_refinements", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
217 218 219 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 217 def logger @findings_refinement_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
150 151 152 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 150 def universe_domain @findings_refinement_service_stub.universe_domain end |
#update_findings_refinement(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement #update_findings_refinement(findings_refinement: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinement
Updates a findings refinement.
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 530 def update_findings_refinement request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_findings_refinement..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_findings_refinement.timeout, metadata: , retry_policy: @config.rpcs.update_findings_refinement.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.update_findings_refinement request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_findings_refinement_deployment(request, options = nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment #update_findings_refinement_deployment(findings_refinement_deployment: nil, update_mask: nil) ⇒ ::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment
Updates a findings refinement deployment.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'lib/google/cloud/chronicle/v1/findings_refinement_service/rest/client.rb', line 696 def update_findings_refinement_deployment request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Chronicle::V1::UpdateFindingsRefinementDeploymentRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_findings_refinement_deployment..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Chronicle::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_findings_refinement_deployment.timeout, metadata: , retry_policy: @config.rpcs.update_findings_refinement_deployment.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @findings_refinement_service_stub.update_findings_refinement_deployment request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |