Module: Google::Cloud::Chronicle::V1::FindingsRefinementType
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
The type of findings refinement, which determines what the findings refinement runs over and the mechanism by which it runs.
Constant Summary collapse
- FINDINGS_REFINEMENT_TYPE_UNSPECIFIED =
The findings refinement type is unspecified.
0- DETECTION_EXCLUSION =
Indicates that the findings refinement is a detection exclusion and should exclude matching detections.
1