Class: Google::Cloud::Chronicle::V1::GetDataTableRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::GetDataTableRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_table.rb
Overview
A request to get details about a data table.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the data table to retrieve. Format: projects/{project}/locations/{location}/instances/{instances}/dataTables/{data_table}.
50 51 52 53 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 50 class GetDataTableRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |