Class: Google::Cloud::Chronicle::V1::GetReferenceListRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::GetReferenceListRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/reference_list.rb
Overview
A request to get details about a reference list.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::Chronicle::V1::ReferenceListView
How much of the ReferenceList to view.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The resource name of the reference list to retrieve.
Format:
projects/{project}/locations/{locations}/instances/{instance}/referenceLists/{reference_list}.
55 56 57 58 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 55 class GetReferenceListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::Chronicle::V1::ReferenceListView
Returns How much of the ReferenceList to view. Defaults to REFERENCE_LIST_VIEW_FULL.
55 56 57 58 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 55 class GetReferenceListRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |