Class: Google::Cloud::Chronicle::V1::IngestionLabel
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::IngestionLabel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
Representation of an ingestion label type.
Instance Attribute Summary collapse
-
#ingestion_label_key ⇒ ::String
Required.
-
#ingestion_label_value ⇒ ::String
Optional.
Instance Attribute Details
#ingestion_label_key ⇒ ::String
Returns Required. The key of the ingestion label. Always required.
357 358 359 360 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 357 class IngestionLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ingestion_label_value ⇒ ::String
Returns Optional. The value of the ingestion label. Optional. An object with no provided value and some key provided would match against the given key and ANY value.
357 358 359 360 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 357 class IngestionLabel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |