Class: Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Request message for ListAllFindingsRefinementDeployments method.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
A filter that can be used to retrieve specific findings refinement deployments.
-
#instance ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
The maximum number of findings refinement deployments to return.
-
#page_token ⇒ ::String
A page token, received from a previous
ListAllFindingsRefinementDeploymentscall.
Instance Attribute Details
#filter ⇒ ::String
Returns A filter that can be used to retrieve specific findings refinement
deployments.
Only the following filters are allowed:
detection_exclusion_application.curated_rule_sets:"
323 324 325 326 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323 class ListAllFindingsRefinementDeploymentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance ⇒ ::String
Returns Required. The name of the parent resource, which is the SecOps instance to list all findings refinement deployments over. Format: projects/{project}/locations/{location}/instances/{instance}.
323 324 325 326 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323 class ListAllFindingsRefinementDeploymentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns The maximum number of findings refinement deployments to return. The service may return fewer than this value. If unspecified, at most 100 rule deployments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
323 324 325 326 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323 class ListAllFindingsRefinementDeploymentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous
ListAllFindingsRefinementDeployments call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
ListAllFindingsRefinementDeployments must match the call that provided
the page token.
323 324 325 326 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 323 class ListAllFindingsRefinementDeploymentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |