Class: Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListAllFindingsRefinementDeploymentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Response message for ListAllFindingsRefinementDeployments method.
Instance Attribute Summary collapse
-
#all_findings_refinement_deployments ⇒ ::Array<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
List of all findings refinement deployments.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#all_findings_refinement_deployments ⇒ ::Array<::Google::Cloud::Chronicle::V1::FindingsRefinementDeployment>
Returns List of all findings refinement deployments.
336 337 338 339 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 336 class ListAllFindingsRefinementDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page. If
this field is omitted, there are no subsequent pages.
336 337 338 339 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 336 class ListAllFindingsRefinementDeploymentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |