Class: Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataAccessLabelsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
Request message for ListDataAccessLabels.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
The maximum number of data access labels to return.
-
#page_token ⇒ ::String
A page token, received from a previous
ListDataAccessLabelsRequestcall. -
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. A filter which should follow the guidelines of AIP-160. Supports filtering on all fieds of DataAccessLabel and all operations as mentioned in https://google.aip.dev/160. example filter: "create_time greater than \"2023-04-21T11:30:00-04:00\" OR display_name:\"-21-1\"".
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 76 class ListDataAccessLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns The maximum number of data access labels to return. The service may return fewer than this value. If unspecified, at most 100 data access labels will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 76 class ListDataAccessLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous ListDataAccessLabelsRequest call.
Provide this to retrieve the subsequent page.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 76 class ListDataAccessLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this data access label will be created.
Format: projects/{project}/locations/{location}/instances/{instance}.
76 77 78 79 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 76 class ListDataAccessLabelsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |