Class: Google::Cloud::Chronicle::V1::ListDataAccessLabelsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataAccessLabelsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
Response message for ListDataAccessLabels.
Instance Attribute Summary collapse
-
#data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabel>
List of data access labels.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#data_access_labels ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessLabel>
Returns List of data access labels.
89 90 91 92 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 89 class ListDataAccessLabelsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
89 90 91 92 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 89 class ListDataAccessLabelsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |