Class: Google::Cloud::Chronicle::V1::ListDataAccessScopesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataAccessScopesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_access_control.rb
Overview
Response message for ListDataAccessScopes.
Instance Attribute Summary collapse
-
#data_access_scopes ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessScope>
List of data access scopes.
-
#global_data_access_scope_granted ⇒ ::Boolean
Whether or not global scope is granted to the user.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#data_access_scopes ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataAccessScope>
Returns List of data access scopes.
191 192 193 194 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 191 class ListDataAccessScopesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#global_data_access_scope_granted ⇒ ::Boolean
Returns Whether or not global scope is granted to the user.
191 192 193 194 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 191 class ListDataAccessScopesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
191 192 193 194 |
# File 'proto_docs/google/cloud/chronicle/v1/data_access_control.rb', line 191 class ListDataAccessScopesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |