Class: Google::Cloud::Chronicle::V1::ListDataTablesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataTablesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_table.rb
Overview
A request for a list of data tables.
Instance Attribute Summary collapse
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#order_by ⇒ ::String
Returns Optional. Configures ordering of DataTables in the response. Note: Our implementation currently supports order by "create_time asc" only.
94 95 96 97 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 94 class ListDataTablesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Optional. The maximum number of data tables to return. The service may return fewer than this value. If unspecified, at most 100 data tables will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
94 95 96 97 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 94 class ListDataTablesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListDataTables call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
ListDataTables must match the call that provided the page
token.
94 95 96 97 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 94 class ListDataTablesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent resource where this data table will be created. Format: projects/{project}/locations/{location}/instances/{instance}.
94 95 96 97 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 94 class ListDataTablesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |