Class: Google::Cloud::Chronicle::V1::ListDataTablesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListDataTablesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/data_table.rb
Overview
Response message for listing data tables.
Instance Attribute Summary collapse
-
#data_tables ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataTable>
The list of the data tables returned.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#data_tables ⇒ ::Array<::Google::Cloud::Chronicle::V1::DataTable>
Returns The list of the data tables returned.
123 124 125 126 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 123 class ListDataTablesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
123 124 125 126 |
# File 'proto_docs/google/cloud/chronicle/v1/data_table.rb', line 123 class ListDataTablesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |