Class: Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb
Overview
Request message to list FeaturedContentNativeDashboards.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. The filter to apply to list the FeaturedContentNativeDashboards.
The filter syntax follows Google Cloud syntax: https://google.aip.dev/160.
Supported fields for filtering:
-
name: The resource name of the featured content. -
content_metadata.description: The description of the featured content.
When a literal value is provided without a field, it will perform a
substring search across both name and content_metadata.description.
Examples:
-
"test": Matches featured content where either the name or description contains "test" as a substring. -
name="test": Matches featured content where the name contains "test". -
content_metadata.description="test": Matches featured content where the description contains "test".
95 96 97 98 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 95 class ListFeaturedContentNativeDashboardsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. The maximum number of FeaturedContentNativeDashboards to return. The service may return fewer than this value. If unspecified, at most 100 FeaturedContentNativeDashboards will be returned. The maximum value is 100; values above 100 will be coerced to 100.
95 96 97 98 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 95 class ListFeaturedContentNativeDashboardsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous
ListFeaturedContentNativeDashboards call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
ListFeaturedContentNativeDashboards must match the call that provided the
page token.
95 96 97 98 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 95 class ListFeaturedContentNativeDashboardsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of FeaturedContentNativeDashboards. Format: projects/{project}/locations/{location}/instances/{instance}/contentHub.
95 96 97 98 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 95 class ListFeaturedContentNativeDashboardsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |