Class: Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListFeaturedContentNativeDashboardsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb
Overview
Response message for listing FeaturedContentNativeDashboards.
Instance Attribute Summary collapse
-
#featured_content_native_dashboards ⇒ ::Array<::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard>
The list of FeaturedContentNativeDashboards.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#featured_content_native_dashboards ⇒ ::Array<::Google::Cloud::Chronicle::V1::FeaturedContentNativeDashboard>
Returns The list of FeaturedContentNativeDashboards. Ordered by name by default.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 109 class ListFeaturedContentNativeDashboardsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/featured_content_native_dashboard.rb', line 109 class ListFeaturedContentNativeDashboardsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |