Class: Google::Cloud::Chronicle::V1::ListFindingsRefinementsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListFindingsRefinementsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/findings_refinement.rb
Overview
Response message for ListFindingsRefinements method.
Instance Attribute Summary collapse
-
#findings_refinements ⇒ ::Array<::Google::Cloud::Chronicle::V1::FindingsRefinement>
List of findings refinements.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#findings_refinements ⇒ ::Array<::Google::Cloud::Chronicle::V1::FindingsRefinement>
Returns List of findings refinements.
229 230 231 232 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 229 class ListFindingsRefinementsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page. If
this field is omitted, there are no subsequent pages.
229 230 231 232 |
# File 'proto_docs/google/cloud/chronicle/v1/findings_refinement.rb', line 229 class ListFindingsRefinementsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |