Class: Google::Cloud::Chronicle::V1::ListReferenceListsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListReferenceListsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/reference_list.rb
Overview
A request for a list of reference lists.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
The maximum number of reference lists to return.
-
#page_token ⇒ ::String
A page token, received from a previous
ListReferenceListscall. -
#parent ⇒ ::String
Required.
-
#view ⇒ ::Google::Cloud::Chronicle::V1::ReferenceListView
How much of each ReferenceList to view.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns The maximum number of reference lists to return. The service may return fewer than this value. If unspecified, at most 100 reference lists will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
82 83 84 85 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 82 class ListReferenceListsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A page token, received from a previous ListReferenceLists call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListReferenceLists must
match the call that provided the page token.
82 83 84 85 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 82 class ListReferenceListsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent, which owns this collection of reference lists.
Format:
projects/{project}/locations/{location}/instances/{instance}.
82 83 84 85 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 82 class ListReferenceListsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::Chronicle::V1::ReferenceListView
Returns How much of each ReferenceList to view. Defaults to REFERENCE_LIST_VIEW_BASIC.
82 83 84 85 |
# File 'proto_docs/google/cloud/chronicle/v1/reference_list.rb', line 82 class ListReferenceListsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |