Class: Google::Cloud::Chronicle::V1::ListRetrohuntsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/chronicle/v1/rule.rb

Overview

Request message for ListRetrohunts method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns A filter that can be used to retrieve specific rule deployments. The following fields are filterable: state.

Returns:

  • (::String)

    A filter that can be used to retrieve specific rule deployments. The following fields are filterable: state



459
460
461
462
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 459

class ListRetrohuntsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of retrohunt to return. The service may return fewer than this value. If unspecified, at most 100 retrohunts will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    The maximum number of retrohunt to return. The service may return fewer than this value. If unspecified, at most 100 retrohunts will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



459
460
461
462
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 459

class ListRetrohuntsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A page token, received from a previous ListRetrohunts call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListRetrohunts must match the call that provided the page token.

Returns:

  • (::String)

    A page token, received from a previous ListRetrohunts call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListRetrohunts must match the call that provided the page token.



459
460
461
462
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 459

class ListRetrohuntsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The rule that the retrohunts belong to. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.

Returns:

  • (::String)

    Required. The rule that the retrohunts belong to. Format: projects/{project}/locations/{location}/instances/{instance}/rules/{rule}



459
460
461
462
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 459

class ListRetrohuntsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end