Class: Google::Cloud::Chronicle::V1::ListRuleRevisionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListRuleRevisionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Request message for ListRuleRevisions method.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
The maximum number of revisions to return per page.
-
#page_token ⇒ ::String
The page token, received from a previous
ListRuleRevisionscall. -
#view ⇒ ::Google::Cloud::Chronicle::V1::RuleView
The view field indicates the scope of fields to populate for the revision being returned.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The name of the rule to list revisions for.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}.
392 393 394 395 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 392 class ListRuleRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
The maximum number of revisions to return per page. The service may return fewer than this value. If unspecified, at most 100 revisions will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
392 393 394 395 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 392 class ListRuleRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns The page token, received from a previous ListRuleRevisions call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListRuleRevisions
must match the call that provided the page token.
392 393 394 395 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 392 class ListRuleRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#view ⇒ ::Google::Cloud::Chronicle::V1::RuleView
Returns The view field indicates the scope of fields to populate for the revision being returned. If unspecified, defaults to BASIC.
392 393 394 395 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 392 class ListRuleRevisionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |