Class: Google::Cloud::Chronicle::V1::ListRuleRevisionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::ListRuleRevisionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Response message for ListRuleRevisions method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page. -
#rules ⇒ ::Array<::Google::Cloud::Chronicle::V1::Rule>
The revisions of the rule.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
405 406 407 408 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 405 class ListRuleRevisionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rules ⇒ ::Array<::Google::Cloud::Chronicle::V1::Rule>
Returns The revisions of the rule.
405 406 407 408 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 405 class ListRuleRevisionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |