Module: Google::Cloud::Chronicle::V1::NativeDashboardView
- Defined in:
- proto_docs/google/cloud/chronicle/v1/native_dashboard.rb
Overview
NativeDashboardView indicates the scope of fields to populate when returning the dashboard resource.
Constant Summary collapse
- NATIVE_DASHBOARD_VIEW_UNSPECIFIED =
Defaults to basic.
0- NATIVE_DASHBOARD_VIEW_BASIC =
Include basic metadata about the dashboard without full definition.
1- NATIVE_DASHBOARD_VIEW_FULL =
Include everything.
2