Class: Google::Cloud::Chronicle::V1::RetrohuntMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::RetrohuntMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
Operation Metadata for Retrohunts.
Instance Attribute Summary collapse
-
#execution_interval ⇒ ::Google::Type::Interval
The start and end time of the retrohunt execution.
-
#progress_percentage ⇒ ::Float
Percent progress of the retrohunt towards completion, from 0.00 to 100.00.
-
#retrohunt ⇒ ::String
The name of the retrohunt.
Instance Attribute Details
#execution_interval ⇒ ::Google::Type::Interval
Returns The start and end time of the retrohunt execution. If the retrohunt is not yet finished, the end time of the interval will not be filled.
624 625 626 627 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 624 class RetrohuntMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#progress_percentage ⇒ ::Float
Returns Percent progress of the retrohunt towards completion, from 0.00 to 100.00.
624 625 626 627 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 624 class RetrohuntMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#retrohunt ⇒ ::String
Returns The name of the retrohunt.
Format:
projects/{project}/locations/{location}/instances/{instance}/rules/{rule}/retrohunts/{retrohunt}.
624 625 626 627 |
# File 'proto_docs/google/cloud/chronicle/v1/rule.rb', line 624 class RetrohuntMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |