Module: Google::Cloud::Chronicle::V1::RuleDeployment::ExecutionState
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
The possible execution states the rule deployment can be in.
Constant Summary collapse
- EXECUTION_STATE_UNSPECIFIED =
Unspecified or unknown execution state.
0- DEFAULT =
Default execution state.
1- LIMITED =
Rules in limited state may not have their executions guaranteed.
2- PAUSED =
Paused rules are not executed at all.
3