Class: Google::Cloud::Chronicle::V1::RuleExecutionError
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::RuleExecutionError
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb
Overview
The RuleExecutionError resource represents an error generated from running/deploying a rule.
Instance Attribute Summary collapse
-
#curated_rule ⇒ ::String
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#name ⇒ ::String
readonly
Output only.
-
#rule ⇒ ::String
readonly
Output only.
-
#time_range ⇒ ::Google::Type::Interval
readonly
Output only.
Instance Attribute Details
#curated_rule ⇒ ::String (readonly)
Returns Output only. The resource name of the curated rule that generated the rule execution error.
Note: The following fields are mutually exclusive: curated_rule, rule. If a field in that set is populated, all other fields in the set will automatically be cleared.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 109 class RuleExecutionError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The error status corresponding with the rule execution error.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 109 class RuleExecutionError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String (readonly)
Returns Output only. The resource name of the rule execution error. Format: projects/{project}/locations/{location}/instances/{instance}/ruleExecutionErrors/{rule_execution_error}.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 109 class RuleExecutionError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rule ⇒ ::String (readonly)
Returns Output only. The resource name of the rule that generated the rule execution error.
Note: The following fields are mutually exclusive: rule, curated_rule. If a field in that set is populated, all other fields in the set will automatically be cleared.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 109 class RuleExecutionError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#time_range ⇒ ::Google::Type::Interval (readonly)
Returns Output only. The event time range that the rule execution error corresponds with.
109 110 111 112 |
# File 'proto_docs/google/cloud/chronicle/v1/rule_execution_error.rb', line 109 class RuleExecutionError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |