Module: Google::Cloud::Chronicle::V1::RuleView
- Defined in:
- proto_docs/google/cloud/chronicle/v1/rule.rb
Overview
RuleView indicates the scope of fields to populate when returning the Rule resource.
Constant Summary collapse
- RULE_VIEW_UNSPECIFIED =
The default/unset value. The API will default to the BASIC view for ListRules/ListRuleRevisions. The API will default to the FULL view for GetRule.
0- BASIC =
Include basic metadata about the rule, but not the full contents. Returned fields include: revision_id, revision_create_time, display_name, author, severity, type, allowed_run_frequency, near_real_time_live_rule_eligible, etag, and scope. This is the default value for ListRules and ListRuleRevisions.
1- FULL =
Include all fields. This is the default value for GetRule.
2- REVISION_METADATA_ONLY =
Include basic metadata about the rule's revision only. Returned fields include: revision_id and revision_create_time.
3