Class: Google::Cloud::Chronicle::V1::Watchlist
- Inherits:
-
Object
- Object
- Google::Cloud::Chronicle::V1::Watchlist
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/chronicle/v1/entity.rb
Overview
A watchlist is a list of entities that allows for bulk operations over the included entities.
Defined Under Namespace
Classes: EntityCount, EntityPopulationMechanism
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
-
#entity_count ⇒ ::Google::Cloud::Chronicle::V1::Watchlist::EntityCount
readonly
Output only.
-
#entity_population_mechanism ⇒ ::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism
Required.
-
#multiplying_factor ⇒ ::Float
Optional.
-
#name ⇒ ::String
Identifier.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#watchlist_user_preferences ⇒ ::Google::Cloud::Chronicle::V1::WatchlistUserPreferences
Optional.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time the watchlist was created.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
Returns Optional. Description of the watchlist.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Required. Display name of the watchlist. Note that it must be at least one character and less than 63 characters (https://google.aip.dev/148).
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entity_count ⇒ ::Google::Cloud::Chronicle::V1::Watchlist::EntityCount (readonly)
Returns Output only. Entity count in the watchlist.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#entity_population_mechanism ⇒ ::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism
Returns Required. Mechanism to populate entities in the watchlist.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#multiplying_factor ⇒ ::Float
Returns Optional. Weight applied to the risk score for entities in this watchlist. The default is 1.0 if it is not specified.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. Resource name of the watchlist.
Format:
projects/{project}/locations/{location}/instances/{instance}/watchlists/{watchlist}.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time the watchlist was last updated.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#watchlist_user_preferences ⇒ ::Google::Cloud::Chronicle::V1::WatchlistUserPreferences
Returns Optional. User preferences for watchlist configuration.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'proto_docs/google/cloud/chronicle/v1/entity.rb', line 59 class Watchlist include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mechanism to populate entities in the watchlist. # @!attribute [rw] manual # @return [::Google::Cloud::Chronicle::V1::Watchlist::EntityPopulationMechanism::Manual] # Optional. Entities are added manually. class EntityPopulationMechanism include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Entities are added manually. class Manual include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Count of different types of entities in the watchlist. # @!attribute [r] user # @return [::Integer] # Output only. Count of user type entities in the watchlist. # @!attribute [r] asset # @return [::Integer] # Output only. Count of asset type entities in the watchlist. class EntityCount include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |